@@ -1,10 +1,13 @@
 <?php
 /**
  * See deferred.txt
+ * @file
+ * @ingroup Cache
  */
 
 /**
- *
+ * Handles purging appropriate Squid URLs given a title (or titles)
+ * @ingroup Cache
  */
 class SquidUpdate {
 	var $urlArr, $mMaxTitles;
@@ -81,7 +84,7 @@ class SquidUpdate {
 			echo implode("<br />\n", $urlArr) . "<br />\n";
 			return;
 		}*/
-		
+
 		if( empty( $urlArr ) ) {
 			return;
 		}
@@ -148,8 +151,9 @@ class SquidUpdate {
 					/* open the remaining sockets for this server */
 					list($server, $port) = explode(':', $wgSquidServers[$ss]);
 					if(!isset($port)) $port = 80;
-					$sockets[$so+1] = @fsockopen($server, $port, $error, $errstr, 2);
-					@stream_set_blocking($sockets[$so+1],false);
+					$socket = @fsockopen($server, $port, $error, $errstr, 2);
+					@stream_set_blocking($socket,false);
+					$sockets[] = $socket;
 				}
 				$so++;
 			}
@@ -219,10 +223,10 @@ class SquidUpdate {
 
 			foreach ( $urlArr as $url ) {
 				if( !is_string( $url ) ) {
-					wfDebugDieBacktrace( 'Bad purge URL' );
+					throw new MWException( 'Bad purge URL' );
 				}
 				$url = SquidUpdate::expand( $url );
-				
+
 				// Construct a minimal HTCP request diagram
 				// as per RFC 2756
 				// Opcode 'CLR', no response desired, no auth
@@ -260,7 +264,7 @@ class SquidUpdate {
 			wfDebug( $text );
 		}
 	}
-	
+
 	/**
 	 * Expand local URLs to fully-qualified URLs using the internal protocol
 	 * and host defined in $wgInternalServer. Input that's already fully-
@@ -282,4 +286,3 @@ class SquidUpdate {
 		return $url;
 	}
 }
-
