@@ -29,7 +29,7 @@ if (!defined('MEDIAWIKI')) {
 }
 
 /**
- * @addtogroup API
+ * @ingroup API
  */
 class ApiOpenSearch extends ApiBase {
 
@@ -45,11 +45,12 @@ class ApiOpenSearch extends ApiBase {
 		$params = $this->extractRequestParams();
 		$search = $params['search'];
 		$limit = $params['limit'];
-
+		$namespaces = $params['namespace'];
+		
 		// Open search results may be stored for a very long time
 		$this->getMain()->setCacheMaxAge(1200);
-		
-		$srchres = PrefixSearch::titleSearch( $search, $limit );
+
+		$srchres = PrefixSearch::titleSearch( $search, $limit, $namespaces );
 
 		// Set top level elements
 		$result = $this->getResult();
@@ -66,14 +67,20 @@ class ApiOpenSearch extends ApiBase {
 				ApiBase :: PARAM_MIN => 1,
 				ApiBase :: PARAM_MAX => 100,
 				ApiBase :: PARAM_MAX2 => 100
-			)
+			),
+			'namespace' => array(
+				ApiBase :: PARAM_DFLT => NS_MAIN,
+				ApiBase :: PARAM_TYPE => 'namespace',
+				ApiBase :: PARAM_ISMULTI => true
+			),
 		);
 	}
 
 	public function getParamDescription() {
 		return array (
 			'search' => 'Search string',
-			'limit' => 'Maximum amount of results to return'
+			'limit' => 'Maximum amount of results to return',
+			'namespace' => 'Namespaces to search',
 		);
 	}
 
@@ -88,7 +95,6 @@ class ApiOpenSearch extends ApiBase {
 	}
 
 	public function getVersion() {
-		return __CLASS__ . ': $Id: ApiOpenSearch.php 30275 2008-01-30 01:07:49Z brion $';
+		return __CLASS__ . ': $Id: ApiOpenSearch.php 35098 2008-05-20 17:13:28Z ialex $';
 	}
 }
-
