@@ -29,7 +29,7 @@ if (!defined('MEDIAWIKI')) {
 }
 
 /**
- * @addtogroup API
+ * @ingroup API
  */
 class ApiParamInfo extends ApiBase {
 
@@ -55,7 +55,7 @@ class ApiParamInfo extends ApiBase {
 				$obj = new $modArr[$m]($this->getMain(), $m);
 				$a = $this->getClassInfo($obj);
 				$a['name'] = $m;
-				$r['modules'][] = $a;				
+				$r['modules'][] = $a;
 			}
 			$result->setIndexedTagName($r['modules'], 'module');
 		}
@@ -86,12 +86,12 @@ class ApiParamInfo extends ApiBase {
 		$retval['classname'] = get_class($obj);
 		$retval['description'] = (is_array($obj->getDescription()) ? implode("\n", $obj->getDescription()) : $obj->getDescription());
 		$retval['prefix'] = $obj->getModulePrefix();
-		$allowedParams = $obj->getAllowedParams();
+		$allowedParams = $obj->getFinalParams();
 		if(!is_array($allowedParams))
 			return $retval;
 		$retval['parameters'] = array();
-		$paramDesc = $obj->getParamDescription();
-		foreach($obj->getAllowedParams() as $n => $p)
+		$paramDesc = $obj->getFinalParamDescription();
+		foreach($allowedParams as $n => $p)
 		{
 			$a = array('name' => $n);
 			if(!is_array($p))
@@ -106,12 +106,20 @@ class ApiParamInfo extends ApiBase {
 				$retval['parameters'][] = $a;
 				continue;
 			}
-					
+
 			if(isset($p[ApiBase::PARAM_DFLT]))
 				$a['default'] = $p[ApiBase::PARAM_DFLT];
 			if(isset($p[ApiBase::PARAM_ISMULTI]))
 				if($p[ApiBase::PARAM_ISMULTI])
+				{
 					$a['multi'] = '';
+					$a['limit'] = $this->getMain()->canApiHighLimits() ?
+							ApiBase::LIMIT_SML2 :
+							ApiBase::LIMIT_SML1;
+				}
+			if(isset($p[ApiBase::PARAM_ALLOW_DUPLICATES]))
+				if($p[ApiBase::PARAM_ALLOW_DUPLICATES])
+					$a['allowsduplicates'] = '';
 			if(isset($p[ApiBase::PARAM_TYPE]))
 			{
 				$a['type'] = $p[ApiBase::PARAM_TYPE];
@@ -131,7 +139,7 @@ class ApiParamInfo extends ApiBase {
 		$result->setIndexedTagName($retval['parameters'], 'param');
 		return $retval;
 	}
-	
+
 	public function getAllowedParams() {
 		return array (
 			'modules' => array(
@@ -161,7 +169,6 @@ class ApiParamInfo extends ApiBase {
 	}
 
 	public function getVersion() {
-		return __CLASS__ . ': $Id: ApiParse.php 29810 2008-01-15 21:33:08Z catrope $';
+		return __CLASS__ . ': $Id: ApiParamInfo.php 41653 2008-10-04 15:03:03Z catrope $';
 	}
 }
-
