@@ -31,8 +31,8 @@ if (!defined('MEDIAWIKI')) {
 /**
  * A query action to enumerate the recent changes that were done to the wiki.
  * Various filters are supported.
- * 
- * @addtogroup API
+ *
+ * @ingroup API
  */
 class ApiQueryRecentChanges extends ApiQueryBase {
 
@@ -43,39 +43,100 @@ class ApiQueryRecentChanges extends ApiQueryBase {
 	private $fld_comment = false, $fld_user = false, $fld_flags = false,
 			$fld_timestamp = false, $fld_title = false, $fld_ids = false,
 			$fld_sizes = false;
-	 
+	
+	protected function getTokenFunctions() {
+		// tokenname => function
+		// function prototype is func($pageid, $title, $rev)
+		// should return token or false
+
+		// Don't call the hooks twice
+		if(isset($this->tokenFunctions))
+			return $this->tokenFunctions;
+
+		// If we're in JSON callback mode, no tokens can be obtained
+		if(!is_null($this->getMain()->getRequest()->getVal('callback')))
+			return array();
+
+		$this->tokenFunctions = array(
+			'patrol' => array( 'ApiQueryRecentChanges', 'getPatrolToken' )
+		);
+		wfRunHooks('APIQueryRecentChangesTokens', array(&$this->tokenFunctions));
+		return $this->tokenFunctions;
+	}
+	
+	public static function getPatrolToken($pageid, $title, $rc)
+	{
+		global $wgUser;
+		if(!$wgUser->useRCPatrol() && !$wgUser->useNPPatrol())
+			return false;
+		
+		// The patrol token is always the same, let's exploit that
+		static $cachedPatrolToken = null;
+		if(!is_null($cachedPatrolToken))
+			return $cachedPatrolToken;
+
+		$cachedPatrolToken = $wgUser->editToken();
+		return $cachedPatrolToken;
+	}
+
 	/**
 	 * Generates and outputs the result of this query based upon the provided parameters.
 	 */
 	public function execute() {
-		/* Initialize vars */
-		$limit = $prop = $namespace = $show = $type = $dir = $start = $end = null;
-		
 		/* Get the parameters of the request. */
-		extract($this->extractRequestParams());
+		$params = $this->extractRequestParams();
 
 		/* Build our basic query. Namely, something along the lines of:
-		 * SELECT * from recentchanges WHERE rc_timestamp > $start 
-		 * 		AND rc_timestamp < $end AND rc_namespace = $namespace 
+		 * SELECT * FROM recentchanges WHERE rc_timestamp > $start
+		 * 		AND rc_timestamp < $end AND rc_namespace = $namespace
 		 * 		AND rc_deleted = '0'
 		 */
+		$db = $this->getDB();
 		$this->addTables('recentchanges');
-		$this->addWhereRange('rc_timestamp', $dir, $start, $end);
-		$this->addWhereFld('rc_namespace', $namespace);
+		$this->addOption('USE INDEX', array('recentchanges' => 'rc_timestamp'));
+		$this->addWhereRange('rc_timestamp', $params['dir'], $params['start'], $params['end']);
+		$this->addWhereFld('rc_namespace', $params['namespace']);
 		$this->addWhereFld('rc_deleted', 0);
-		if(!is_null($type))
-				$this->addWhereFld('rc_type', $this->parseRCType($type));
+		if($params['titles'])
+		{
+			$lb = new LinkBatch;
+			foreach($params['titles'] as $t)
+			{
+				$obj = Title::newFromText($t);
+				$lb->addObj($obj);
+				if($obj->getNamespace() < 0)
+				{
+					// LinkBatch refuses these, but we need them anyway
+					if(!array_key_exists($obj->getNamespace(), $lb->data))
+						$lb->data[$obj->getNamespace()] = array();
+					$lb->data[$obj->getNamespace()][$obj->getDBKey()] = 1;
+				}
+			}
+			$where = $lb->constructSet('rc', $this->getDB());
+			if($where != '')
+				$this->addWhere($where);
+		}
 
-		if (!is_null($show)) {
-			$show = array_flip($show);
+		if(!is_null($params['type']))
+				$this->addWhereFld('rc_type', $this->parseRCType($params['type']));
+
+		if (!is_null($params['show'])) {
+			$show = array_flip($params['show']);
 
 			/* Check for conflicting parameters. */
-			if ((isset ($show['minor']) && isset ($show['!minor'])) 
-					|| (isset ($show['bot']) && isset ($show['!bot'])) 
-					|| (isset ($show['anon']) && isset ($show['!anon']))) {
-						
+			if ((isset ($show['minor']) && isset ($show['!minor']))
+					|| (isset ($show['bot']) && isset ($show['!bot']))
+					|| (isset ($show['anon']) && isset ($show['!anon']))
+					|| (isset ($show['redirect']) && isset ($show['!redirect']))
+					|| (isset ($show['patrolled']) && isset ($show['!patrolled']))) {
+
 				$this->dieUsage("Incorrect parameter - mutually exclusive values may not be supplied", 'show');
 			}
+			
+			// Check permissions
+			global $wgUser;
+			if((isset($show['patrolled']) || isset($show['!patrolled'])) && !$wgUser->useRCPatrol() && !$wgUser->useNPPatrol())
+				$this->dieUsage("You need the patrol right to request the patrolled flag", 'permissiondenied');
 
 			/* Add additional conditions to query depending upon parameters. */
 			$this->addWhereIf('rc_minor = 0', isset ($show['!minor']));
@@ -84,6 +145,11 @@ class ApiQueryRecentChanges extends ApiQueryBase {
 			$this->addWhereIf('rc_bot != 0', isset ($show['bot']));
 			$this->addWhereIf('rc_user = 0', isset ($show['anon']));
 			$this->addWhereIf('rc_user != 0', isset ($show['!anon']));
+			$this->addWhereIf('rc_patrolled = 0', isset($show['!patrolled']));
+			$this->addWhereIf('rc_patrolled != 0', isset($show['patrolled']));
+			$this->addWhereIf('page_is_redirect = 1', isset ($show['redirect']));
+			// Don't throw log entries out the window here
+			$this->addWhereIf('page_is_redirect = 0 OR page_is_redirect IS NULL', isset ($show['!redirect']));
 		}
 
 		/* Add the fields we're concerned with to out query. */
@@ -91,14 +157,15 @@ class ApiQueryRecentChanges extends ApiQueryBase {
 			'rc_timestamp',
 			'rc_namespace',
 			'rc_title',
+			'rc_cur_id',
 			'rc_type',
 			'rc_moved_to_ns',
 			'rc_moved_to_title'
 		));
 
 		/* Determine what properties we need to display. */
-		if (!is_null($prop)) {
-			$prop = array_flip($prop);
+		if (!is_null($params['prop'])) {
+			$prop = array_flip($params['prop']);
 
 			/* Set up internal members based upon params. */
 			$this->fld_comment = isset ($prop['comment']);
@@ -108,13 +175,19 @@ class ApiQueryRecentChanges extends ApiQueryBase {
 			$this->fld_title = isset ($prop['title']);
 			$this->fld_ids = isset ($prop['ids']);
 			$this->fld_sizes = isset ($prop['sizes']);
+			$this->fld_redirect = isset($prop['redirect']);
+			$this->fld_patrolled = isset($prop['patrolled']);
+			$this->fld_loginfo = isset($prop['loginfo']);
+
+			global $wgUser;
+			if($this->fld_patrolled && !$wgUser->useRCPatrol() && !$wgUser->useNPPatrol())
+				$this->dieUsage("You need the patrol right to request the patrolled flag", 'permissiondenied');
 
 			/* Add fields to our query if they are specified as a needed parameter. */
-			$this->addFieldsIf('rc_id', $this->fld_ids);			
-			$this->addFieldsIf('rc_cur_id', $this->fld_ids);			
-			$this->addFieldsIf('rc_this_oldid', $this->fld_ids);			
-			$this->addFieldsIf('rc_last_oldid', $this->fld_ids);			
-			$this->addFieldsIf('rc_comment', $this->fld_comment);			
+			$this->addFieldsIf('rc_id', $this->fld_ids);
+			$this->addFieldsIf('rc_this_oldid', $this->fld_ids);
+			$this->addFieldsIf('rc_last_oldid', $this->fld_ids);
+			$this->addFieldsIf('rc_comment', $this->fld_comment);
 			$this->addFieldsIf('rc_user', $this->fld_user);
 			$this->addFieldsIf('rc_user_text', $this->fld_user);
 			$this->addFieldsIf('rc_minor', $this->fld_flags);
@@ -122,14 +195,20 @@ class ApiQueryRecentChanges extends ApiQueryBase {
 			$this->addFieldsIf('rc_new', $this->fld_flags);
 			$this->addFieldsIf('rc_old_len', $this->fld_sizes);
 			$this->addFieldsIf('rc_new_len', $this->fld_sizes);
+			$this->addFieldsIf('rc_patrolled', $this->fld_patrolled);
+			$this->addFieldsIf('rc_logid', $this->fld_loginfo);
+			$this->addFieldsIf('rc_log_type', $this->fld_loginfo);
+			$this->addFieldsIf('rc_log_action', $this->fld_loginfo);
+			$this->addFieldsIf('rc_params', $this->fld_loginfo);
+			if($this->fld_redirect || isset($show['redirect']) || isset($show['!redirect']))
+			{
+				$this->addTables('page');
+				$this->addJoinConds(array('page' => array('LEFT JOIN', array('rc_namespace=page_namespace', 'rc_title=page_title'))));
+				$this->addFields('page_is_redirect');
+			}
 		}
-
-		/* Specify the limit for our query. It's $limit+1 because we (possibly) need to 
-		 * generate a "continue" parameter, to allow paging. */
-		$this->addOption('LIMIT', $limit +1);
-
-		/* Specify the index to use in the query as rc_timestamp, instead of rc_revid (default). */
-		$this->addOption('USE INDEX', 'rc_timestamp');
+		$this->token = $params['token'];
+		$this->addOption('LIMIT', $params['limit'] +1);
 
 		$data = array ();
 		$count = 0;
@@ -140,7 +219,7 @@ class ApiQueryRecentChanges extends ApiQueryBase {
 
 		/* Iterate through the rows, adding data extracted from them to our query result. */
 		while ($row = $db->fetchObject($res)) {
-			if (++ $count > $limit) {
+			if (++ $count > $params['limit']) {
 				// We've reached the one extra which shows that there are additional pages to be had. Stop here...
 				$this->setContinueEnumParameter('start', wfTimestamp(TS_ISO_8601, $row->rc_timestamp));
 				break;
@@ -148,7 +227,7 @@ class ApiQueryRecentChanges extends ApiQueryBase {
 
 			/* Extract the data from a single row. */
 			$vals = $this->extractRowInfo($row);
-			
+
 			/* Add that row's data to our final output. */
 			if($vals)
 				$data[] = $vals;
@@ -172,7 +251,7 @@ class ApiQueryRecentChanges extends ApiQueryBase {
 	private function extractRowInfo($row) {
 		/* If page was moved somewhere, get the title of the move target. */
 		$movedToTitle = false;
-		if (!empty($row->rc_moved_to_title))
+		if (isset($row->rc_moved_to_title) && $row->rc_moved_to_title !== '')
 			$movedToTitle = Title :: makeTitle($row->rc_moved_to_ns, $row->rc_moved_to_title);
 
 		/* Determine the title of the page that has been changed. */
@@ -185,11 +264,11 @@ class ApiQueryRecentChanges extends ApiQueryBase {
 
 		/* Determine what kind of change this was. */
 		switch ( $type ) {
-		case RC_EDIT:  $vals['type'] = 'edit'; break;
-		case RC_NEW:   $vals['type'] = 'new'; break;
-		case RC_MOVE:  $vals['type'] = 'move'; break;
-		case RC_LOG:   $vals['type'] = 'log'; break;
-		case RC_MOVE_OVER_REDIRECT: $vals['type'] = 'move over redirect'; break;
+			case RC_EDIT:  $vals['type'] = 'edit'; break;
+			case RC_NEW:   $vals['type'] = 'new'; break;
+			case RC_MOVE:  $vals['type'] = 'move'; break;
+			case RC_LOG:   $vals['type'] = 'log'; break;
+			case RC_MOVE_OVER_REDIRECT: $vals['type'] = 'move over redirect'; break;
 		default: $vals['type'] = $type;
 		}
 
@@ -236,13 +315,44 @@ class ApiQueryRecentChanges extends ApiQueryBase {
 			$vals['timestamp'] = wfTimestamp(TS_ISO_8601, $row->rc_timestamp);
 
 		/* Add edit summary / log summary. */
-		if ($this->fld_comment && !empty ($row->rc_comment)) {
+		if ($this->fld_comment && isset($row->rc_comment)) {
 			$vals['comment'] = $row->rc_comment;
 		}
 
+		if ($this->fld_redirect)
+			if($row->page_is_redirect)
+				$vals['redirect'] = '';
+
+		/* Add the patrolled flag */
+		if ($this->fld_patrolled && $row->rc_patrolled == 1)
+			$vals['patrolled'] = '';
+			
+		if ($this->fld_loginfo && $row->rc_type == RC_LOG) {
+			$vals['logid'] = $row->rc_logid;
+			$vals['logtype'] = $row->rc_log_type;
+			$vals['logaction'] = $row->rc_log_action;
+			ApiQueryLogEvents::addLogParams($this->getResult(),
+				$vals, $row->rc_params,
+				$row->rc_log_type, $row->rc_timestamp);
+		}
+		
+		if(!is_null($this->token))
+		{
+			$tokenFunctions = $this->getTokenFunctions();
+			foreach($this->token as $t)
+			{
+				$val = call_user_func($tokenFunctions[$t], $row->rc_cur_id,
+					$title, RecentChange::newFromRow($row));
+				if($val === false)
+					$this->setWarning("Action '$t' is not allowed for the current user");
+				else
+					$vals[$t . 'token'] = $val;
+			}
+		}
+
 		return $vals;
 	}
-	
+
 	private function parseRCType($type)
 	{
 			if(is_array($type))
@@ -258,7 +368,7 @@ class ApiQueryRecentChanges extends ApiQueryBase {
 					case 'new': return RC_NEW;
 					case 'log': return RC_LOG;
 			}
-	}			
+	}
 
 	public function getAllowedParams() {
 		return array (
@@ -279,6 +389,9 @@ class ApiQueryRecentChanges extends ApiQueryBase {
 				ApiBase :: PARAM_ISMULTI => true,
 				ApiBase :: PARAM_TYPE => 'namespace'
 			),
+			'titles' => array(
+				ApiBase :: PARAM_ISMULTI => true
+			),
 			'prop' => array (
 				ApiBase :: PARAM_ISMULTI => true,
 				ApiBase :: PARAM_DFLT => 'title|timestamp|ids',
@@ -289,9 +402,16 @@ class ApiQueryRecentChanges extends ApiQueryBase {
 					'timestamp',
 					'title',
 					'ids',
-					'sizes'
+					'sizes',
+					'redirect',
+					'patrolled',
+					'loginfo',
 				)
 			),
+			'token' => array(
+				ApiBase :: PARAM_TYPE => array_keys($this->getTokenFunctions()),
+				ApiBase :: PARAM_ISMULTI => true
+			),
 			'show' => array (
 				ApiBase :: PARAM_ISMULTI => true,
 				ApiBase :: PARAM_TYPE => array (
@@ -300,7 +420,11 @@ class ApiQueryRecentChanges extends ApiQueryBase {
 					'bot',
 					'!bot',
 					'anon',
-					'!anon'
+					'!anon',
+					'redirect',
+					'!redirect',
+					'patrolled',
+					'!patrolled'
 				)
 			),
 			'limit' => array (
@@ -314,7 +438,7 @@ class ApiQueryRecentChanges extends ApiQueryBase {
 				ApiBase :: PARAM_ISMULTI => true,
 				ApiBase :: PARAM_TYPE => array (
 					'edit',
-					'new', 
+					'new',
 					'log'
 				)
 			)
@@ -327,13 +451,15 @@ class ApiQueryRecentChanges extends ApiQueryBase {
 			'end' => 'The timestamp to end enumerating.',
 			'dir' => 'In which direction to enumerate.',
 			'namespace' => 'Filter log entries to only this namespace(s)',
+			'titles' => 'Filter log entries to only these page titles',
 			'prop' => 'Include additional pieces of information',
+			'token' => 'Which tokens to obtain for each change',
 			'show' => array (
 				'Show only items that meet this criteria.',
 				'For example, to see only minor edits done by logged-in users, set show=minor|!anon'
 			),
 			'type' => 'Which types of changes to show.',
-			'limit' => 'How many total pages to return.'
+			'limit' => 'How many total changes to return.'
 		);
 	}
 
@@ -348,7 +474,6 @@ class ApiQueryRecentChanges extends ApiQueryBase {
 	}
 
 	public function getVersion() {
-		return __CLASS__ . ': $Id: ApiQueryRecentChanges.php 30222 2008-01-28 19:05:26Z catrope $';
+		return __CLASS__ . ': $Id: ApiQueryRecentChanges.php 44719 2008-12-17 16:34:01Z catrope $';
 	}
 }
-
