@@ -1,7 +1,7 @@
 <?php
 
 /**
- * @addtogroup Media
+ * @ingroup Media
  */
 class ArchivedFile
 {
@@ -26,16 +26,13 @@ class ArchivedFile
 		$timestamp, # time of upload
 		$dataLoaded, # Whether or not all this has been loaded from the database (loadFromXxx)
 		$deleted; # Bitfield akin to rev_deleted
-		
-	/**#@-*/	
-		
+
+	/**#@-*/
+
 	function ArchivedFile( $title, $id=0, $key='' ) {
-		if( !is_object($title) ) {
-			throw new MWException( 'ArchivedFile constructor given bogus title.' );
-		}
 		$this->id = -1;
-		$this->title = $title;
-		$this->name = $title->getDBkey();
+		$this->title = false;
+		$this->name = false;
 		$this->group = '';
 		$this->key = '';
 		$this->size = 0;
@@ -51,6 +48,20 @@ class ArchivedFile
 		$this->timestamp = NULL;
 		$this->deleted = 0;
 		$this->dataLoaded = false;
+		
+		if( is_object($title) ) {
+			$this->title = $title;
+			$this->name = $title->getDBkey();
+		}
+		
+		if ($id)
+			$this->id = $id;
+		
+		if ($key)
+			$this->key = $key;
+		
+		if (!$id && !$key && !is_object($title))
+			throw new MWException( "No specifications provided to ArchivedFile constructor." );
 	}
 
 	/**
@@ -61,8 +72,19 @@ class ArchivedFile
 		if ( $this->dataLoaded ) {
 			return true;
 		}
-		$conds = ($this->id) ? "fa_id = {$this->id}" : "fa_storage_key = '{$this->key}'";
-		if( $this->title->getNamespace() == NS_IMAGE ) {
+		$conds = array();
+		
+		if ($this->id>0)
+			$conds['fa_id'] = $this->id;
+		if ($this->key)
+			$conds['fa_storage_key'] = $this->key;	
+		if ($this->title)
+			$conds['fa_name'] = $this->title->getDBkey();
+			
+		if (!count($conds))
+			throw new MWException( "No specific information for retrieving archived file" );
+		
+		if( !$this->title || $this->title->getNamespace() == NS_FILE ) {
 			$dbr = wfGetDB( DB_SLAVE );
 			$res = $dbr->select( 'filearchive',
 				array(
@@ -84,19 +106,17 @@ class ArchivedFile
 					'fa_user_text',
 					'fa_timestamp',
 					'fa_deleted' ),
-				array( 
-					'fa_name' => $this->title->getDBkey(),
-					$conds ),
+				$conds,
 				__METHOD__,
 				array( 'ORDER BY' => 'fa_timestamp DESC' ) );
-				
+
 			if ( $dbr->numRows( $res ) == 0 ) {
 			// this revision does not exist?
 				return;
 			}
 			$ret = $dbr->resultObject( $res );
 			$row = $ret->fetchObject();
-	
+
 			// initialize fields for filestore image object
 			$this->id = intval($row->fa_id);
 			$this->name = $row->fa_name;
@@ -120,17 +140,17 @@ class ArchivedFile
 			return;
 		}
 		$this->dataLoaded = true;
-		
+
 		return true;
 	}
 
 	/**
 	 * Loads a file object from the filearchive table
 	 * @return ResultWrapper
-	 */	
-	public static function newFromRow( $row ) {	
-		$file = new ArchivedFile( Title::makeTitle( NS_IMAGE, $row->fa_name ) );
-		
+	 */
+	public static function newFromRow( $row ) {
+		$file = new ArchivedFile( Title::makeTitle( NS_FILE, $row->fa_name ) );
+
 		$file->id = intval($row->fa_id);
 		$file->name = $row->fa_name;
 		$file->archive_name = $row->fa_archive_name;
@@ -148,41 +168,41 @@ class ArchivedFile
 		$file->user_text = $row->fa_user_text;
 		$file->timestamp = $row->fa_timestamp;
 		$file->deleted = $row->fa_deleted;
-		
+
 		return $file;
 	}
-	
+
 	/**
 	 * Return the associated title object
 	 * @public
 	 */
-	public function getTitle() { 
+	public function getTitle() {
 		return $this->title;
 	}
 
 	/**
 	 * Return the file name
-	 */	
-	public function getName() { 
+	 */
+	public function getName() {
 		return $this->name;
 	}
 
-	public function getID() { 
+	public function getID() {
 		$this->load();
 		return $this->id;
 	}
-	
+
 	/**
 	 * Return the FileStore key
-	 */	
-	public function getKey() { 
+	 */
+	public function getKey() {
 		$this->load();
 		return $this->key;
 	}
-	
+
 	/**
 	 * Return the FileStore storage group
-	 */	
+	 */
 	public function getGroup() {
 		return $file->group;
 	}
@@ -192,7 +212,7 @@ class ArchivedFile
 	 */
 	public function getWidth() {
 		$this->load();
-		return $this->width; 
+		return $this->width;
 	}
 
 	/**
@@ -200,9 +220,9 @@ class ArchivedFile
 	 */
 	public function getHeight() {
 		$this->load();
-		return $this->height; 
+		return $this->height;
 	}
-	
+
 	/**
 	 * Get handler-specific metadata
 	 */
@@ -219,7 +239,7 @@ class ArchivedFile
 		$this->load();
 		return $this->size;
 	}
-	
+
 	/**
 	 * Return the bits of the image file, in bytes
 	 * @public
@@ -228,7 +248,7 @@ class ArchivedFile
 		$this->load();
 		return $this->bits;
 	}
-	
+
 	/**
 	 * Returns the mime type of the file.
 	 */
@@ -236,7 +256,7 @@ class ArchivedFile
 		$this->load();
 		return $this->mime;
 	}
-	
+
 	/**
 	 * Return the type of the media in the file.
 	 * Use the value returned by this function with the MEDIATYPE_xxx constants.
@@ -251,7 +271,7 @@ class ArchivedFile
 	 */
 	public function getTimestamp() {
 		$this->load();
-		return $this->timestamp;
+		return wfTimestamp( TS_MW, $this->timestamp );
 	}
 
 	/**
@@ -265,7 +285,7 @@ class ArchivedFile
 			return $this->user;
 		}
 	}
-	
+
 	/**
 	 * Return the user name of the uploader.
 	 */
@@ -277,7 +297,7 @@ class ArchivedFile
 			return $this->user_text;
 		}
 	}
-	
+
 	/**
 	 * Return upload description.
 	 */
@@ -289,7 +309,7 @@ class ArchivedFile
 			return $this->description;
 		}
 	}
-	
+
 	/**
 	 * Return the user ID of the uploader.
 	 */
@@ -297,7 +317,7 @@ class ArchivedFile
 		$this->load();
 		return $this->user;
 	}
-	
+
 	/**
 	 * Return the user name of the uploader.
 	 */
@@ -305,7 +325,7 @@ class ArchivedFile
 		$this->load();
 		return $this->user_text;
 	}
-	
+
 	/**
 	 * Return upload description.
 	 */
@@ -322,18 +342,18 @@ class ArchivedFile
 	public function isDeleted( $field ) {
 		return ($this->deleted & $field) == $field;
 	}
-	
+
 	/**
 	 * Determine if the current user is allowed to view a particular
 	 * field of this FileStore image file, if it's marked as deleted.
-	 * @param int $field					
+	 * @param int $field
 	 * @return bool
 	 */
 	public function userCan( $field ) {
 		if( ($this->deleted & $field) == $field ) {
 			global $wgUser;
 			$permission = ( $this->deleted & File::DELETED_RESTRICTED ) == File::DELETED_RESTRICTED
-				? 'hiderevision'
+				? 'suppressrevision'
 				: 'deleterevision';
 			wfDebug( "Checking for $permission due to $field match on $this->deleted\n" );
 			return $wgUser->isAllowed( $permission );
