@@ -1,15 +1,14 @@
 <?php
 /**
- * @addtogroup Templates
+ * @defgroup Templates Templates
+ * @file
+ * @ingroup Templates
  */
 if( !defined( 'MEDIAWIKI' ) ) die( -1 );
 
-/** */
-require_once( 'includes/SkinTemplate.php' );
-
 /**
  * HTML template for Special:Userlogin form
- * @addtogroup Templates
+ * @ingroup Templates
  */
 class UserloginTemplate extends QuickTemplate {
 	function execute() {
@@ -17,7 +16,7 @@ class UserloginTemplate extends QuickTemplate {
 ?>
 	<div class="<?php $this->text('messagetype') ?>box">
 		<?php if ( $this->data['messagetype'] == 'error' ) { ?>
-			<h2><?php $this->msg('loginerror') ?>:</h2>
+			<h2><?php $this->msg('loginerror') ?></h2>
 		<?php } ?>
 		<?php $this->html('message') ?>
 	</div>
@@ -55,7 +54,7 @@ class UserloginTemplate extends QuickTemplate {
 			$doms .= "<option>" . htmlspecialchars( $dom ) . "</option>";
 		}
 	?>
-		<tr>
+		<tr id="mw-user-domain-section">
 			<td class="mw-label"><?php $this->msg( 'yourdomainname' ) ?></td>
 			<td class="mw-input">
 				<select name="wpDomain" value="<?php $this->text( 'domain' ) ?>"
@@ -64,7 +63,8 @@ class UserloginTemplate extends QuickTemplate {
 				</select>
 			</td>
 		</tr>
-	<?php } ?>
+	<?php }
+	if( $this->data['canremember'] ) { ?>
 		<tr>
 			<td></td>
 			<td class="mw-input">
@@ -75,6 +75,7 @@ class UserloginTemplate extends QuickTemplate {
 					/> <label for="wpRemember"><?php $this->msg('remembermypassword') ?></label>
 			</td>
 		</tr>
+		<?php } ?>
 		<tr>
 			<td></td>
 			<td class="mw-submit">
@@ -95,15 +96,24 @@ class UserloginTemplate extends QuickTemplate {
 }
 
 /**
- * @addtogroup Templates
+ * @ingroup Templates
  */
 class UsercreateTemplate extends QuickTemplate {
+	function addInputItem( $name, $value, $type, $msg ) {
+		$this->data['extraInput'][] = array(
+			'name' => $name,
+			'value' => $value,
+			'type' => $type,
+			'msg' => $msg,
+		);
+	}
+	
 	function execute() {
 		if( $this->data['message'] ) {
 ?>
 	<div class="<?php $this->text('messagetype') ?>box">
 		<?php if ( $this->data['messagetype'] == 'error' ) { ?>
-			<h2><?php $this->msg('loginerror') ?>:</h2>
+			<h2><?php $this->msg('loginerror') ?></h2>
 		<?php } ?>
 		<?php $this->html('message') ?>
 	</div>
@@ -188,6 +198,7 @@ class UsercreateTemplate extends QuickTemplate {
 					</td>
 			<?php } ?>
 		</tr>
+		<?php if( $this->data['canremember'] ) { ?>
 		<tr>
 			<td></td>
 			<td class="mw-input">
@@ -198,15 +209,58 @@ class UsercreateTemplate extends QuickTemplate {
 					/> <label for="wpRemember"><?php $this->msg('remembermypassword') ?></label>
 			</td>
 		</tr>
+<?php   }
+
+		$tabIndex = 8;
+		if ( isset( $this->data['extraInput'] ) && is_array( $this->data['extraInput'] ) ) {
+			foreach ( $this->data['extraInput'] as $inputItem ) { ?>
+		<tr>
+			<?php 
+				if ( !empty( $inputItem['msg'] ) && $inputItem['type'] != 'checkbox' ) {
+					?><td class="mw-label"><label for="<?php 
+					echo htmlspecialchars( $inputItem['name'] ); ?>"><?php
+					$this->msgWiki( $inputItem['msg'] ) ?></label><?php
+				} else {
+					?><td><?php
+				}
+			?></td>
+			<td class="mw-input">
+				<input type="<?php echo htmlspecialchars( $inputItem['type'] ) ?>" name="<?php
+				echo htmlspecialchars( $inputItem['name'] ); ?>"
+					tabindex="<?php echo $tabIndex++; ?>"
+					value="<?php 
+				if ( $inputItem['type'] != 'checkbox' ) {
+					echo htmlspecialchars( $inputItem['value'] );
+				} else {
+					echo '1';
+				}					
+					?>" id="<?php echo htmlspecialchars( $inputItem['name'] ); ?>"
+					<?php 
+				if ( $inputItem['type'] == 'checkbox' && !empty( $inputItem['value'] ) )
+					echo 'checked="checked"'; 
+					?> /> <?php 
+					if ( $inputItem['type'] == 'checkbox' && !empty( $inputItem['msg'] ) ) {
+						?>
+				<label for="<?php echo htmlspecialchars( $inputItem['name'] ); ?>"><?php
+					$this->msg( $inputItem['msg'] ) ?></label><?php
+					}
+				?>
+			</td>
+		</tr>
+<?php				
+				
+			}
+		}
+?>
 		<tr>
 			<td></td>
 			<td class="mw-submit">
 				<input type='submit' name="wpCreateaccount" id="wpCreateaccount"
-					tabindex="8"
+					tabindex="<?php echo $tabIndex++; ?>"
 					value="<?php $this->msg('createaccount') ?>" />
 				<?php if( $this->data['createemail'] ) { ?>
 				<input type='submit' name="wpCreateaccountMail" id="wpCreateaccountMail"
-					tabindex="9"
+					tabindex="<?php echo $tabIndex++; ?>"
 					value="<?php $this->msg('createaccountmail') ?>" />
 				<?php } ?>
 			</td>
@@ -220,5 +274,3 @@ class UsercreateTemplate extends QuickTemplate {
 
 	}
 }
-
-?>
