@@ -68,7 +68,7 @@ $messages = array(
 'mypage'         => 'ܕܦܝ',
 'mytalk'         => 'ܕܘܪܫܝ',
 'navigation'     => 'ܐܠܦܪܘܬܐ',
-'and'            => 'ܘ',
+'and'            => '&#32;ܘ',
 
 'errorpagetitle'    => 'ܛܥܝܘܬܐ',
 'help'              => 'ܥܘܕܪܢܐ',
@@ -158,8 +158,8 @@ $messages = array(
 'upload'   => 'ܛܥܢܐ ܦ̮ܥܝܠ',
 'filename' => 'ܫܡܐ ܕܫܘܦܝܢܐ',
 
-# Special:ImageList
-'imagelist_name' => 'ܫܡܐ',
+# Special:ListFiles
+'listfiles_name' => 'ܫܡܐ',
 
 # Random page
 'randompage' => 'ܡܓܠܬܐ ܚܘܝܚܐ',
@@ -202,7 +202,7 @@ $messages = array(
 # Namespace 8 related
 'allmessagesname' => 'ܫܡܐ',
 
-# Special:NewImages
+# Special:NewFiles
 'ilsubmit' => 'ܛܥܘܝܐ',
 
 # 'all' in various places, this might be different for inflected languages
