@@ -81,7 +81,7 @@ $messages = array(
 'mypage'        => 'tañi nütramkawe',
 'mytalk'        => 'Tañi nütramkawe',
 'anontalk'      => 'Tüfachi IP ñi nütramkawe',
-'and'           => 'ka',
+'and'           => '&#32;ka',
 
 'returnto'         => 'Amutun $1 püle.',
 'tagline'          => '{{SITENAME}} mew',
@@ -103,6 +103,7 @@ $messages = array(
 'newpage'          => 'We Pakina',
 'talkpage'         => 'Nütramkafinge tüfachi pakina',
 'talkpagelinktext' => 'Nütramkawe',
+'personaltools'    => 'Kisungechi küdawpeyüm',
 'articlepage'      => 'adkintun artículo',
 'talk'             => 'Nütramkawe',
 'views'            => 'Pen',
@@ -134,6 +135,7 @@ $messages = array(
 'youhavenewmessagesmulti' => 'Elungeymi we dungu $1 mew.',
 'editsection'             => 'wirin',
 'editold'                 => 'wirin',
+'editlink'                => 'wirin',
 'showtoc'                 => 'pengelün',
 'hidetoc'                 => 'ellkan',
 'viewdeleted'             => 'Küpaadkintuymi $1 am?',
@@ -141,7 +143,7 @@ $messages = array(
 
 # Short words for each namespace, by default used in the namespace tab in monobook
 'nstab-main'      => 'Pakina',
-'nstab-user'      => 'Lludüchi',
+'nstab-user'      => 'Kellufe',
 'nstab-special'   => 'Kangelu',
 'nstab-mediawiki' => 'Dungu',
 'nstab-help'      => 'Kelluwe',
@@ -153,7 +155,7 @@ $messages = array(
 
 # Login and logout pages
 'loginpagetitle'          => 'Konün',
-'yourname'                => 'Tami lludüchi üy',
+'yourname'                => 'Tami üy',
 'yourpassword'            => 'Tami kondungu',
 'login'                   => 'Konün',
 'nav-login-createaccount' => 'Konün',
@@ -169,7 +171,7 @@ $messages = array(
 'loginlanguagelabel'      => 'Dungun: $1',
 
 # Edit pages
-'subject'            => 'Dungu/üy',
+'subject'            => 'Dungu/üy:',
 'minoredit'          => 'Tüfachi ta kiñe pichi wirin',
 'watchthis'          => 'Llaytun tüfachi pakina',
 'preview'            => 'Pen chum müley',
@@ -182,9 +184,10 @@ $messages = array(
 'template-protected' => '(Ngünaytun)',
 
 # History pages
-'page_first'   => 'wünen',
-'deletedrev'   => '[ñamümüngelu]',
-'historyempty' => '(welli)',
+'page_first'             => 'wünen',
+'history-fieldset-title' => 'Kintun pünon mew',
+'deletedrev'             => '[ñamümüngelu]',
+'historyempty'           => '(welli)',
 
 # Revision feed
 'history-feed-item-nocomment' => '$1 $2 mew', # user at time
@@ -196,31 +199,39 @@ $messages = array(
 'revdelete-hid' => 'Ellkan $1',
 
 # Diffs
-'lineno'   => 'Wirin $1:',
-'editundo' => 'wüñoeltun',
+'lineno'       => 'Wirin $1:',
+'editundo'     => 'wüñoeltun',
+'diff-movedto' => 'Nengümülu $1 püle',
+'diff-img'     => "kiñe '''ad'''",
+'diff-big'     => "'''füta'''",
+'diff-del'     => "'''Ñamümün'''",
 
 # Search results
-'viewprevnext'          => 'Pen ($1) ($2) ($3).',
-'search-interwiki-more' => '(Doy)',
-'searchall'             => 'Fill',
-'powersearch'           => 'Kintun',
-'powersearch-field'     => 'Kintun',
+'viewprevnext'                   => 'Pen ($1) ($2) ($3).',
+'searchhelp-url'                 => 'Help:Kellu',
+'searchprofile-articles-tooltip' => 'kintu $1 mew',
+'searchprofile-project-tooltip'  => 'Kintun $1 mew',
+'search-interwiki-more'          => '(Doy)',
+'searchall'                      => 'Fill',
+'powersearch'                    => 'Kintun',
+'powersearch-field'              => 'Kintun',
 
 # Preferences page
 'prefs-edits'       => 'Rakin Wirin:',
 'prefsnologin'      => 'Mülelay Konün',
+'skin-preview'      => 'Pen chum müley',
 'textboxsize'       => 'Wirin',
 'searchresultshead' => 'Kintun',
 
 # Groups
 'group'       => 'Kisuwen:',
-'group-user'  => 'Lludüchi',
+'group-user'  => 'Pu kellufe',
 'group-sysop' => 'Pu ngünefe',
 'group-all'   => '(kom pu che)',
 
-'group-user-member' => 'Lludüchi',
+'group-user-member' => 'Kellufe',
 
-'grouppage-user' => '{{ns:project}}: Lludüchi',
+'grouppage-user' => '{{ns:project}}: Pu kellufe',
 
 # Rights
 'right-edit'          => 'Wirin pakina',
@@ -234,6 +245,9 @@ $messages = array(
 # User rights log
 'rightsnone' => 'chemnorume',
 
+# Associated actions - in the sentence "You do not have permission to X"
+'action-move' => 'Nengümün tüfachi pakina',
+
 # Recent changes
 'rcshowhideminor'                   => '$1 wirin pichi',
 'rcshowhidemine'                    => '$1 tañi wirin',
@@ -242,7 +256,7 @@ $messages = array(
 'show'                              => 'pengelün',
 'minoreditletter'                   => 'p',
 'newpageletter'                     => 'W',
-'number_of_watching_users_pageview' => '[$1 {{PLURAL:$1|Lludüchi|Lludüchi}} wiñamüy]',
+'number_of_watching_users_pageview' => '[$1 {{PLURAL:$1|Kellufe|Kellufe}} wiñamüy]',
 
 # Recent changes linked
 'recentchangeslinked-page' => 'Pakina ñi üy:',
@@ -253,24 +267,28 @@ $messages = array(
 
 'nolicense' => 'Chemnorume dullinnongey',
 
-# Special:ImageList
-'imagelist_name' => 'Üy',
-'imagelist_user' => 'Lludüchi',
+# Special:ListFiles
+'listfiles_name' => 'Üy',
+'listfiles_user' => 'Kellufe',
 
-# Image description page
+# File description page
 'filehist-deleteall' => 'kom ñamümün',
 'filehist-deleteone' => 'ñamümün tüfa',
-'filehist-user'      => 'Lludüchi',
+'filehist-user'      => 'Kellufe',
 
 # File deletion
-'filedelete'         => '$1 ñamümün',
-'filedelete-intro'   => "Ñamümmekeymi '''[[Media:$1|$1]]'''.",
-'filedelete-submit'  => 'Ñamümün',
-'filedelete-success' => "'''$1''' ñamümngey.",
+'filedelete'                 => '$1 ñamümün',
+'filedelete-intro'           => "Ñamümmekeymi '''[[Media:$1|$1]]'''.",
+'filedelete-submit'          => 'Ñamümün',
+'filedelete-success'         => "'''$1''' ñamümngey.",
+'filedelete-edit-reasonlist' => 'Wirin dungu ñamümgün mew',
 
 # Unused templates
 'unusedtemplateswlh' => "Kake ''enlase''",
 
+# Statistics
+'statistics-pages' => 'Pakina',
+
 'brokenredirects-edit'   => '(wirin)',
 'brokenredirects-delete' => '(ñamümün)',
 
@@ -281,7 +299,7 @@ $messages = array(
 'nviews'            => '$1 {{PLURAL:$1|pen|pen}}',
 'shortpages'        => 'Pichi pakina',
 'newpages'          => 'We pakina',
-'newpages-username' => 'Güy lludüchi',
+'newpages-username' => 'Kellufe ñi üy',
 'move'              => 'Wiñamün',
 'movethispage'      => 'Nengümün tüfachi pakina',
 
@@ -289,9 +307,8 @@ $messages = array(
 'booksources-go' => 'Amun',
 
 # Special:Log
-'specialloguserlabel'  => 'Lludüchi:',
+'specialloguserlabel'  => 'Kellufe:',
 'speciallogtitlelabel' => 'Üy:',
-'log-search-submit'    => 'Amun',
 
 # Special:AllPages
 'allpages'       => 'Kakelu pakina',
@@ -299,6 +316,9 @@ $messages = array(
 'allpagesnext'   => 'Inan',
 'allpagessubmit' => 'Pengelün',
 
+# Special:LinkSearch
+'linksearch-ok' => 'Kintun',
+
 # Special:ListUsers
 'listusers-submit' => 'Pengelün',
 
@@ -308,29 +328,35 @@ $messages = array(
 'emailsend'    => 'Werkün',
 
 # Watchlist
-'watchnologin'         => 'Petu konlaymi',
-'watch'                => 'Llaytun',
-'watchthispage'        => 'Llaytun tüfachi pakina',
-'unwatch'              => 'Llaytuwelan',
-'unwatchthispage'      => 'Llaytuwelan',
-'notanarticle'         => 'Ngelay kiñe pakina',
-'watchlist-show-own'   => 'Nülan ñi wirin',
-'watchlist-hide-own'   => 'Ellkan ñi wirin',
-'watchlist-show-minor' => 'Nülan pichi wirin',
-'watchlist-hide-minor' => 'Ellkan wirin pichi',
+'watchlistfor'    => "('''$1''')",
+'watchnologin'    => 'Petu konlaymi',
+'watch'           => 'Llaytun',
+'watchthispage'   => 'Llaytun tüfachi pakina',
+'unwatch'         => 'Llaytuwelan',
+'unwatchthispage' => 'Llaytuwelan',
+'notanarticle'    => 'Ngelay kiñe pakina',
+
+# Displayed when you click the "watch" button and it is in the process of watching
+'watching'   => 'Llaytumekey...',
+'unwatching' => 'Llaytumekewelay...',
 
 'enotif_newpagetext'           => 'Tüfachi ta we pakina',
-'enotif_impersonal_salutation' => '{{SITENAME}} lludüchi',
+'enotif_impersonal_salutation' => '{{SITENAME}} kellufe',
 'created'                      => 'Llituy',
 
-# Delete/protect/revert
-'deletepage'              => 'Ñamümün tüfachi pakina',
-'delete-confirm'          => 'Ñamümüngelu "$1"',
-'delete-legend'           => 'Ñamümün',
-'deletedarticle'          => '«[[$1]]» Ñamümün',
+# Delete
+'deletepage'     => 'Ñamümün tüfachi pakina',
+'exblank'        => 'pakina wellingey',
+'delete-confirm' => 'Ñamümüngelu "$1"',
+'delete-legend'  => 'Ñamümün',
+'deletedarticle' => '«[[$1]]» Ñamümün',
+
+# Protect
+'prot_1movedto2'          => '[[$1]] wiñamngey [[$2]] püle',
 'protectexpiry'           => 'Afi:',
 'protect-level-sysop'     => 'Pu ngünefe müṯen',
 'protect-summary-cascade' => 'Trayengko',
+'protect-expiry-options'  => '1 ora:1 hour,1 aṉtü:1 day,1 semana:1 week,2 semanas:2 weeks,1 küyeṉ:1 month,3 küyeṉ:3 months,6 küyeṉ:6 months,1 tripantu:1 year,Rumel:infinite', # display1:time1,display2:time2,...
 
 # Restrictions (nouns)
 'restriction-edit'   => 'Pepiwelukay',
@@ -338,16 +364,18 @@ $messages = array(
 'restriction-create' => 'Llitun',
 
 # Undelete
-'viewdeletedpage'        => 'Pen pakina ñamümüngelu',
-'undelete-search-box'    => 'Kintun ñamümüngelu pakina',
-'undelete-search-submit' => 'Kintun',
+'viewdeletedpage'           => 'Pen pakina ñamümüngelu',
+'undelete-search-box'       => 'Kintun ñamümüngelu pakina',
+'undelete-search-submit'    => 'Kintun',
+'undelete-show-file-submit' => 'May',
 
 # Namespace form on various pages
 'blanknamespace' => '(Wüne pakina)',
 
 # Contributions
-'month' => 'Küyeṉ:',
-'year'  => 'Tripantu:',
+'contribsub2' => '$1 ($2)',
+'month'       => 'Küyeṉ:',
+'year'        => 'Tripantu:',
 
 'sp-contributions-submit' => 'Kintun',
 
@@ -357,14 +385,17 @@ $messages = array(
 
 # Block/unblock
 'ipbexpiry'          => 'Afi',
+'ipboptions'         => '2 ora:2 hours,1 aṉtü:1 day,3 aṉtü:3 days,1 semana:1 week,2 semana:2 weeks,1 küyeṉ:1 month,3 küyeṉ:3 months,6 küyeṉ:6 months,1 tripantu:1 year,rumel:infinite', # display1:time1,display2:time2,...
 'ipbotheroption'     => 'Kakelu',
 'ipblocklist-submit' => 'Kintun',
 'expiringblock'      => 'afi $1',
+'proxyblocksuccess'  => 'Dewmangey.',
 
 # Move page
 'move-page'               => 'Nengümün $1',
 'move-page-legend'        => 'Nengümün pakina',
 'movearticle'             => 'Nengümün pakina',
+'movenologin'             => 'Konlaymi',
 'newtitle'                => 'We üy püle',
 'move-watch'              => 'Llaytun tüfachi pakina',
 'movepagebtn'             => 'Nengümün pakina',
@@ -373,24 +404,28 @@ $messages = array(
 'delete_and_move'         => 'Ñamümün ka nengümün',
 'delete_and_move_confirm' => 'May, ñamümün pakina',
 
+# Export
+'export' => 'Wiñamün pakina',
+
 # Namespace 8 related
 'allmessagesname' => 'Üy',
 
 # Tooltip help for the actions
-'tooltip-pt-userpage'    => 'Ñi pakina lludüchi',
+'tooltip-pt-userpage'    => 'Tañi pakina',
 'tooltip-pt-mytalk'      => 'Tañi nütramkawe',
 'tooltip-pt-logout'      => 'Tripan',
 'tooltip-ca-delete'      => 'Ñamümün tüfachi pakina',
 'tooltip-ca-move'        => 'Nengümün tüfachi pakina',
 'tooltip-search'         => 'Kintun tüfachi wiki mew',
 'tooltip-p-logo'         => 'Wüne pakina',
-'tooltip-ca-nstab-user'  => 'Pen lludüchi pakina',
+'tooltip-ca-nstab-user'  => 'Pen kellufe pakina',
 'tooltip-ca-nstab-image' => 'Pen pakina ad mew',
 'tooltip-ca-nstab-help'  => 'Pen kellupakina',
 
 # Attribution
-'siteuser' => 'Lludüchi $1 {{SITENAME}}',
-'others'   => 'fill',
+'siteuser'  => 'Kellufe $1 {{SITENAME}}',
+'others'    => 'fill',
+'siteusers' => '{{PLURAL:$2|Kellufe|Kellufe}} $1 {{SITENAME}}',
 
 # Info page
 'numedits'     => 'Rakin wirin (pakina): $1',
@@ -403,13 +438,14 @@ $messages = array(
 'previousdiff' => '← Füta wirin',
 'nextdiff'     => 'We wirin →',
 
-# Special:NewImages
+# Special:NewFiles
 'ilsubmit' => 'Kintu',
 
 # Video information, used by Language::formatTimePeriod() to format lengths in the above messages
 'hours-abbrev' => 'o',
 
 # EXIF tags
+'exif-artist'              => 'Che llitun mew',
 'exif-exposuretime-format' => '$1 sek ($2)',
 
 'exif-exposureprogram-1' => 'Chillka kellu',
