@@ -34,7 +34,7 @@ $messages = array(
 'qbspecialpages' => 'Nyɛw kɛrɛnkɛrɛnnen',
 'mypage'         => "N'ka nyɛ",
 'mytalk'         => "N'ka baronyɛ",
-'and'            => 'ani',
+'and'            => '&#32;ani',
 
 'help'           => 'Dɛmɛ',
 'search'         => 'Nyini',
@@ -121,7 +121,7 @@ $messages = array(
 # Attribution
 'others' => 'wɛrɛ',
 
-# Special:NewImages
+# Special:NewFiles
 'ilsubmit' => 'Nyini',
 
 # Special:SpecialPages
