@@ -8,6 +8,8 @@
  * @author Uttam Singha, Dec 2006
  */
 
+$fallback='bn';
+
 $digitTransformTable = array(
 	'0' => '০',
 	'1' => '১',
@@ -30,8 +32,8 @@ $namespaceNames = array(
 	NS_USER_TALK      => 'আতাকুরার_য়্যারী',
 	# NS_PROJECT set by $wgMetaNamespace
 	NS_PROJECT_TALK   => '$1_য়্যারী',
-	NS_IMAGE          => 'ছবি',
-	NS_IMAGE_TALK     => 'ছবি_য়্যারী',
+	NS_FILE           => 'ছবি',
+	NS_FILE_TALK      => 'ছবি_য়্যারী',
 	NS_MEDIAWIKI      => 'মিডিয়াউইকি',
 	NS_MEDIAWIKI_TALK => 'মিডিয়াউইকির_য়্যারী',
 	NS_TEMPLATE       => 'মডেল',
@@ -89,8 +91,6 @@ $messages = array(
 'underline-never'   => 'সুপৌনা',
 'underline-default' => 'বাউজারগত যেসারে আসিল',
 
-'skinpreview' => '(মিল্লেখ)',
-
 # Dates
 'sunday'        => 'লামুইসিং',
 'monday'        => 'নিংথৌকাপা',
@@ -178,7 +178,7 @@ $messages = array(
 'mytalk'         => 'মর য়্যারি-পরি',
 'anontalk'       => 'অচিনা এগর য়্যারির পাতা',
 'navigation'     => 'দিশা-ধরুনী',
-'and'            => 'বারো',
+'and'            => '&#32;বারো',
 
 # Metadata in edit box
 'metadata_help' => 'মেটাডাটা:',
@@ -241,8 +241,6 @@ $messages = array(
 # All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
 'aboutsite'            => '{{SITENAME}}র বারে',
 'aboutpage'            => 'Project:বারে',
-'bugreports'           => 'লাল বিবরণী',
-'bugreportspage'       => 'Project:লাল_বিবরণী',
 'copyright'            => '$1-র মাতুঙে এহানর মেথেলহানি পানা একরের।',
 'copyrightpagename'    => '{{SITENAME}} স্বত্তাধিকারহান',
 'copyrightpage'        => '{{ns:project}}:স্বত্তাধিকারহানি',
@@ -265,8 +263,6 @@ $messages = array(
 
 'badaccess'        => 'য়্যাথাঙে লালসে',
 'badaccess-group0' => 'তি যে কামহানর হেইচা করিসত, তরতা অহান করানির য়্যাথাং নেই।',
-'badaccess-group1' => 'তি যে কামহানর হেইচা করিসত, অহান করানির য়্যাথাং হুদ্দা $1 গ্রুপরতা আসে।',
-'badaccess-group2' => 'তি যে কামহানর হেইচা করিসত, অহান করানির য়্যাথাং হুদ্দা $1 গ্রুপর আতাকুরারতা আসে।',
 'badaccess-groups' => 'তি যে কামহানর হেইচা করিসত, অহান করানির য়্যাথাং হুদ্দা $1 গ্রুপরতা আসে।',
 
 'ok'                  => 'চুমিসে',
@@ -367,6 +363,9 @@ $messages = array(
 'accountcreated'             => 'একাউন্টহান হঙকরানি ইল',
 'accountcreatedtext'         => 'আতাকুরা $1 -র কা একাউন্টহান হঙকরানি ইল।',
 
+# Password reset dialog
+'retypenew' => 'নুৱা খন্তাচাবি বারো টাইপ কর:',
+
 # Edit page toolbar
 'bold_sample'     => 'গাঢ়পা ৱাহি',
 'bold_tip'        => 'গাঢ়পা ৱাহি',
@@ -388,8 +387,8 @@ $messages = array(
 'hr_tip'          => 'পাথারি খাস (খানি করা ইয়া আতা)',
 
 # Edit pages
-'summary'                => 'সারমর্ম',
-'subject'                => 'বিষয়/চিঙনাঙ',
+'summary'                => 'সারমর্ম:',
+'subject'                => 'বিষয়/চিঙনাঙ:',
 'minoredit'              => 'এহান হুরু-মুরু সম্পাদনাহানহে।',
 'watchthis'              => 'পাতাএহান খিয়ালে থ',
 'savearticle'            => 'পাতাহান ইতুকর',
@@ -397,7 +396,7 @@ $messages = array(
 'showpreview'            => 'আগচা',
 'showdiff'               => 'পতাসিতা দেহাদে',
 'anoneditwarning'        => "'''সিঙুইসঃ''' তি লগইন নাকরিসত। পতানির ইতিহাসহাত তর IP addressহান সিজিল ইতই।",
-'summary-preview'        => 'সারমর্মর আগচা',
+'summary-preview'        => 'সারমর্মর আগচা:',
 'blockedtitle'           => 'আতাকুরাগরে থেপ করানি অসে',
 'blockedtext'            => "<big>'''তর আতাকুরা নাঙহান নাইলেউ আইপি ঠিকানাহানরে থেপকরানি অসে।'''</big>
 
@@ -420,17 +419,17 @@ $messages = array(
 'anontalkpagetext'       => "''এহান অচিনা অতার য়্যারির পাতাহান। এরে আইপি ঠিকানা (IP Address) এহানাত্ত লগ-ইন নাকরিয়া পতানিত মেইক্ষু অসিল। আক্কুস ক্ষেন্তামে আইপি ঠিকানা হামেসা বদল অর, বিশেষ করিয়া ডায়াল-আপ ইন্টারনেট, প্রক্সি সার্ভার মাহি ক্ষেত্র এতা সিলরতা, বারো আগত্ত বপ ব্যবহারকারেকুরার ক্ষেত্রত প্রযোজ্য ইতে পারে। অহানে তি নিশ্চকে এরে আইপি এহাত্ত উইকিপিডিয়াত হমিয়া কোন য়্যারী দেখর, অহান তরে নিঙকরিয়া নাউ ইতে পারে। অহানে হাবিত্ত হবা অর, তি যদি [[Special:UserLogin|লগ-ইন করর, বা নৱা একাউন্ট খুলর]] অহানবুলতেউ লগ-ইন করলে কুঙগউ তর আইপি ঠিকানাহান, বারো অহানর মাতুঙে তর অবস্থানহান সুপকরেউ হার না পেইবা।''",
 'noarticletext'          => 'এপাগা এরে পাতাত কোন টেক্সট নেই। তি মনেইলে হের পাতাহান [[Special:Search/{{PAGENAME}}|এরে চিঙনাঙল বিসারা পারর]] নাইলে [{{fullurl:{{FULLPAGENAME}}|action=edit}} এরে পাতা এহান পতা পারর]।',
 'clearyourcache'         => "'''খিয়াল থ:''' তর পছনহানি রক্ষা করানির থাঙনাত পতাহানি চানার কা তর ব্রাউজারর ক্যাশ লালুয়া যানা লাগতে পারে। '''মোজিলা/ফায়ারফক্স/সাফারি:''' শিফট কী চিপিয়া থয়া রিলোড-এ ক্লিক কর, নাইলে ''কন্ট্রোল-শিফট-R''(এপল ম্যাক-এ ''কমান্ড-শিফট-R'') আকপাকে চিপা; '''ইন্টারনেট এক্সপ্লোরার:''' ''কন্ট্রোল'' চিপিয়া থয়া রিফ্রেশ-এ ক্লিক কর, নাইলে ''কন্ট্রোল-F5'' চিপা; '''কংকারার:''' হুদ্দা রিলোড ক্লিক করলে বা F5 চিপিলে চলতই; '''অপেরা''' আতাকুরাই ''Tools→Preferences''-এ গিয়া কাশ সম্পূর্ণ ঙক্ষি করানি লাগতে পারে।",
-'previewnote'            => '<strong>এহান হুদ্দা আগচাহান;
-ফারাকহান এপাগাউ ইতু করানি নাইসে!</strong>',
+'previewnote'            => "'''এহান হুদ্দা আগচাহান;
+ফারাকহান এপাগাউ ইতু করানি নাইসে!'''",
 'editing'                => 'পতানি চলের $1',
 'editingsection'         => '$1র পতানি চলের (ডেংগ)',
 'yourtext'               => 'তর ইকরা বিষয়হানি',
 'yourdiff'               => 'ফারাকহানি',
-'copyrightwarning'       => 'দয়া করিয়া খিয়াল কর {{SITENAME}}-ত হারি অবদান $2-র মাতুঙে পাসিতা (আরাকউ হবাকরে $1-ত চা)। তর জমা দিয়াসত লেখা যেগউ বে-রিদয় ইয়া পতিতে পারে বারো যেসারে খুশি অসারে বিলিতে পারে। তি যদি এহানর বারে একমত নার, অতা ইলে তর লেখা এহাত জমা নাদি।<br />
+'copyrightwarning'       => "দয়া করিয়া খিয়াল কর {{SITENAME}}-ত হারি অবদান $2-র মাতুঙে পাসিতা (আরাকউ হবাকরে $1-ত চা)। তর জমা দিয়াসত লেখা যেগউ বে-রিদয় ইয়া পতিতে পারে বারো যেসারে খুশি অসারে বিলিতে পারে। তি যদি এহানর বারে একমত নার, অতা ইলে তর লেখা এহাত জমা নাদি।<br />
 তি আরাকউ ৱাশাক করর যে, এরে লেখা এহান তি নিজে ইকিসতহান, নাইলে  হাব্বির কা উন্মুক্ত কোন উৎস আহাত্ত পাসতহান।
-<strong>স্বত্ব সংরক্ষিত অসে অসাদে কোন লেখা স্বত্বাধিকারীর য়্যাথাঙ না লুইয়া এহাত জমা না দিস!</strong>',
-'longpagewarning'        => '<strong>সিঙুইস: এরে পাতা এহান $1 কিলোবাইট ডাঙর; ব্রাউজার আকেইগত ৩২ কিলোবাইটর গজে ডাঙর পাতানিত বেরা ইতে পারে।
-দয়া করিয়া পাতা এহানরে হুরকা হুরকা কত অংশত খেইকরানির হতনা কর।</strong>',
+'''স্বত্ব সংরক্ষিত অসে অসাদে কোন লেখা স্বত্বাধিকারীর য়্যাথাঙ না লুইয়া এহাত জমা না দিস!'''",
+'longpagewarning'        => "'''সিঙুইস: এরে পাতা এহান $1 কিলোবাইট ডাঙর; ব্রাউজার আকেইগত ৩২ কিলোবাইটর গজে ডাঙর পাতানিত বেরা ইতে পারে।
+দয়া করিয়া পাতা এহানরে হুরকা হুরকা কত অংশত খেইকরানির হতনা কর।'''",
 'templatesused'          => 'পাতাহান মডেল বরাসিতা:',
 'templatesusedpreview'   => 'আগচা এহানাত মিহিসে মডেল:',
 'template-protected'     => '(লুকরিসি)',
@@ -446,7 +445,7 @@ $messages = array(
 'viewpagelogs'        => 'পাতাহানর লগ চা',
 'currentrev'          => 'হাদিএহানর পতানি',
 'revisionasof'        => 'রিভিসনহান $1 পেয়া',
-'revision-info'       => '$1 পেয়া  $2-এ পতাসেতা',
+'revision-info'       => '$1 পেয়া  $2-এ পতাসেতা', # Additionally available: $3: revision id
 'previousrevision'    => '←পুরানা পতানিহান',
 'nextrevision'        => 'নুৱা ভার্সনহান→',
 'currentrevisionlink' => 'হাদি এহানর পতানি',
@@ -471,19 +470,20 @@ $messages = array(
 'diff-multi'              => '({{PLURAL:$1|হমবুকর রিভিসন আহান|$1 হমবুকর রিভিসন হানি}} দেহাদেনা এহাত না মিহিসে।)',
 
 # Search results
-'noexactmatch' => "'''\"\$1\" চিংনাঙর কোন পাতা নেই।'''
+'noexactmatch'   => "'''\"\$1\" চিংনাঙর কোন পাতা নেই।'''
 তি [[:\$1|পাতা এহান হঙকরে পারর]]।",
-'prevn'        => 'পিসেদে $1',
-'nextn'        => 'থাংনাত $1',
-'viewprevnext' => 'চা ($1) ($2) ($3)',
-'powersearch'  => 'এডভান্স বিসারানি',
+'prevn'          => 'পিসেদে $1',
+'nextn'          => 'থাংনাত $1',
+'viewprevnext'   => 'চা ($1) ($2) ($3)',
+'searchhelp-url' => 'Help:পাংলাক',
+'powersearch'    => 'এডভান্স বিসারানি',
 
 # Preferences page
 'preferences'    => 'পছনহানি',
 'mypreferences'  => 'মর পছন',
 'changepassword' => 'খন্তাচাবি(password) পতা',
+'skin-preview'   => 'আগচা',
 'saveprefs'      => 'ইতু',
-'retypenew'      => 'নুৱা খন্তাচাবি বারো টাইপ কর:',
 'columns'        => 'দুরগিঃ',
 'allowemail'     => 'আরতা(ব্যবহার করেকুরা)ই ইমেইল করানির য়্যাথাং দে।',
 
@@ -529,10 +529,10 @@ $messages = array(
 'uploadedimage'   => 'আপলোডকরানি অইল "[[$1]]"',
 'watchthisupload' => 'পাতাএহান খিয়ালে থ',
 
-# Special:ImageList
-'imagelist' => 'ছবির তালিকা',
+# Special:ListFiles
+'listfiles' => 'ছবির তালিকা',
 
-# Image description page
+# File description page
 'filehist'                  => 'ফাইলর ইতিহাস',
 'filehist-help'             => 'দিন/সময়-র গজে যাতিলে ঔ খেন্তাম পেয়া হঙিসে ফাইলগ চ পারতেই।',
 'filehist-current'          => 'এপাগা',
@@ -638,24 +638,21 @@ $messages = array(
 'emailuser' => 'আতাকুরাগরে ইমেইল কর',
 
 # Watchlist
-'watchlist'            => 'মর তালাবি',
-'mywatchlist'          => 'মর তালাবি',
-'watchlistfor'         => "('''$1'''-র কা)",
-'addedwatch'           => 'তালাবির তালিকাহাত থনা ইল',
-'addedwatchtext'       => "\"<nowiki>\$1</nowiki>\" পাতা এহান তর [[Special:Watchlist|আহির-আরুম তালিকা]]-ত তিলকরানি ইল। পিসেদে এরে পাতা এহান বারো পাতা এহানর লগে সাকেই আসে য়্যারী পাতাত অইতই হারি জাতর পতানি এহানাত তিলকরানি অইতই। অতাবাদেউ [[Special:RecentChanges|হাদি এহানর পতানিহানি]]-ত পাতা এহানরে '''গাঢ়করা''' মেয়েকে দেহা দেনা অইতই যাতে তি নুঙিকরে পাতা এহান চিনে পারবেতা।
+'watchlist'         => 'মর তালাবি',
+'mywatchlist'       => 'মর তালাবি',
+'watchlistfor'      => "('''$1'''-র কা)",
+'addedwatch'        => 'তালাবির তালিকাহাত থনা ইল',
+'addedwatchtext'    => "\"<nowiki>\$1</nowiki>\" পাতা এহান তর [[Special:Watchlist|আহির-আরুম তালিকা]]-ত তিলকরানি ইল। পিসেদে এরে পাতা এহান বারো পাতা এহানর লগে সাকেই আসে য়্যারী পাতাত অইতই হারি জাতর পতানি এহানাত তিলকরানি অইতই। অতাবাদেউ [[Special:RecentChanges|হাদি এহানর পতানিহানি]]-ত পাতা এহানরে '''গাঢ়করা''' মেয়েকে দেহা দেনা অইতই যাতে তি নুঙিকরে পাতা এহান চিনে পারবেতা।
 
 পিসেদে তি পাতা এহানরে থেইকরানি মনেইলে \"আহির-আরুমেত্ত থেইকরেদে\" ট্যাবগত ক্লিক করিস৷",
-'removedwatch'         => 'তালাবির পাতাত্ত গুসাদে',
-'removedwatchtext'     => 'এরে পাতা "[[:$1]]" এহান গুসানি ইলতা [[Special:Watchlist|তর তালাবির]] পাতাত্ত।',
-'watch'                => 'তালাবি',
-'watchthispage'        => 'পাতাএহান খিয়ালে থ',
-'unwatch'              => 'তালাবি নেই',
-'unwatchthispage'      => 'তালাবি এরাদেনা',
-'watchlist-details'    => '{{PLURAL:$1|$1 পাতা|$1 পাতাহানি}} চানাঅসিল অতার কোন য়্যারির পাতা নেই।',
-'wlshowlast'           => 'গেলগা $1 ঘন্টা $2 দিনর $3 দেখাদে',
-'watchlist-hide-bots'  => 'বোটর পতানি থেইকর',
-'watchlist-hide-own'   => 'মি পতাসুতা গুর',
-'watchlist-hide-minor' => 'হুরকা পতানি থেইকর',
+'removedwatch'      => 'তালাবির পাতাত্ত গুসাদে',
+'removedwatchtext'  => 'এরে পাতা "[[:$1]]" এহান গুসানি ইলতা [[Special:Watchlist|তর তালাবির]] পাতাত্ত।',
+'watch'             => 'তালাবি',
+'watchthispage'     => 'পাতাএহান খিয়ালে থ',
+'unwatch'           => 'তালাবি নেই',
+'unwatchthispage'   => 'তালাবি এরাদেনা',
+'watchlist-details' => '{{PLURAL:$1|$1 পাতা|$1 পাতাহানি}} চানাঅসিল অতার কোন য়্যারির পাতা নেই।',
+'wlshowlast'        => 'গেলগা $1 ঘন্টা $2 দিনর $3 দেখাদে',
 
 # Displayed when you click the "watch" button and it is in the process of watching
 'watching'   => 'চা...',
@@ -663,31 +660,36 @@ $messages = array(
 
 'changed' => 'পতেসে',
 
-# Delete/protect/revert
-'deletepage'                  => 'পাতাহান পুস',
-'confirm'                     => 'লেপকরানি',
-'historywarning'              => 'সিঙুইস: তি যে পাতাহান পুসানিত লেপুইসত এহানর ইতিহাস আহান আসে:',
-'confirmdeletetext'           => 'তি যে পাতাহান পুসানি লেপুইসত অহানর লগে ইতিহাসহানউ পুসতই।
+# Delete
+'deletepage'            => 'পাতাহান পুস',
+'confirm'               => 'লেপকরানি',
+'historywarning'        => 'সিঙুইস: তি যে পাতাহান পুসানিত লেপুইসত এহানর ইতিহাস আহান আসে:',
+'confirmdeletetext'     => 'তি যে পাতাহান পুসানি লেপুইসত অহানর লগে ইতিহাসহানউ পুসতই।
 তি লেপকর যে তি এহান করতেই বুলিয়া, বারো তি এহানর পিসহান হারপাসত লগে [[{{MediaWiki:Policy-url}}|পলিসিহান]] ইলয়া তি কামএহান করানিত লেপুইসত।',
-'actioncomplete'              => 'কামহান লমিল।',
-'deletedtext'                 => '"<nowiki>$1</nowiki>" পুসানি অইল।
+'actioncomplete'        => 'কামহান লমিল।',
+'deletedtext'           => '"<nowiki>$1</nowiki>" পুসানি অইল।
 চা $2 এহার বারে আগে আসে পুসানির লাতংগ।',
-'deletedarticle'              => 'পুসানিইল "[[$1]]"',
-'dellogpage'                  => 'পুসিসিতার লাতংগ',
-'deletecomment'               => 'পুসানির কারনহান:',
-'deleteotherreason'           => 'আরাক/উপরি কারন:',
-'deletereasonotherlist'       => 'আর আর কারন',
-'rollbacklink'                => 'রোলবেক',
-'cantrollback'                => 'আগেকার সঙস্করনহাত আলথকে যানা নুৱারলু, লমিলগা সম্পদনাকরেকুরা অগ পাতা অহানর আকখুলা লেখকগ।',
+'deletedarticle'        => 'পুসানিইল "[[$1]]"',
+'dellogpage'            => 'পুসিসিতার লাতংগ',
+'deletecomment'         => 'পুসানির কারনহান:',
+'deleteotherreason'     => 'আরাক/উপরি কারন:',
+'deletereasonotherlist' => 'আর আর কারন',
+
+# Rollback
+'rollbacklink' => 'রোলবেক',
+'cantrollback' => 'আগেকার সঙস্করনহাত আলথকে যানা নুৱারলু, লমিলগা সম্পদনাকরেকুরা অগ পাতা অহানর আকখুলা লেখকগ।',
+
+# Protect
 'protectlogpage'              => 'লুকরানির লগ',
+'prot_1movedto2'              => '[[$1]]-রে [[$2]]-ত গুসানি ইল',
 'protectcomment'              => 'মতহান:',
 'protectexpiry'               => 'মিয়াদহান লালর:',
 'protect_expiry_invalid'      => 'খেন্তাম লিতনাহান লালুইসে।',
 'protect_expiry_old'          => 'বাতিলর খেন্তামহান আগেকার তারিখে পরিসে।',
 'protect-unchain'             => 'গুসানি পারানির য়্যাথাঙ মুকা',
-'protect-text'                => 'তি চেইলে <strong><nowiki>$1</nowiki> পাতাহানর লুকরানির মাত্রাহান চানা বারো সিলকরানি পারর</strong>।',
-'protect-locked-access'       => 'তরতা পাতা লুকরে পারানির মত য়্যাথাঙ নেই।
-পাতাহান <strong>$1</strong>র এপাগার পাজালানিহান:',
+'protect-text'                => "তি চেইলে '''<nowiki>$1</nowiki> পাতাহানর লুকরানির মাত্রাহান চানা বারো সিলকরানি পারর'''।",
+'protect-locked-access'       => "তরতা পাতা লুকরে পারানির মত য়্যাথাঙ নেই।
+পাতাহান '''$1'''র এপাগার পাজালানিহান:",
 'protect-cascadeon'           => 'এরে পাতাহান এপাগা লুকরানি অসে, কারণ পাতাহানর তলে {{PLURAL:$1|পাতা আহানাত|পাতা হানিত}} অন্তর্ভুক্ত ইসে, যেহানাত আগপাতাকরেকুরাতাত লুকরানিহান আসে। তি চেইলে অহান সিলকরে পারর, তবে এরে আগপাতাকরেকুরাতাত কোন বদালা নাইব।',
 'protect-default'             => '(ডিফল্ট)',
 'protect-fallback'            => 'য়্যাথাং "$1" দরকার',
@@ -697,6 +699,7 @@ $messages = array(
 'protect-expiring'            => '$1 (আমাস) খেন্তামে মিয়াদহান লালুইতই',
 'protect-cascade'             => 'এরে পাতাত মিহিসে পাতাহানি তালাবি করানি অক (আগপাতাকরেকুরা তালাবি)',
 'protect-cantedit'            => 'লুকরিসি পাতাহানরে তি সিলকরে নারবে, কিদিয়া বুল্লে তরতা পতানির য়্যাথাঙ নেই।',
+'protect-expiry-options'      => '২ ঘন্টা:2 hours,১ দিন:1 day,৩ দিন:3 days,হাপ্তা আহান:1 week,হাপ্তা দুহান:2 weeks,মাহা আহান:1 month,৩ মাহা:3 months,৬ মাহা:6 months,বসর আহান:1 year,লম নেই সময়:infinite', # display1:time1,display2:time2,...
 'restriction-type'            => 'য়্যাথাঙ:',
 'restriction-level'           => 'লুকরানির থাক:',
 
@@ -725,7 +728,6 @@ $messages = array(
 # What links here
 'whatlinkshere'       => 'যে পাতাহানিত্ত এহানাত মিলাপ আসে',
 'whatlinkshere-title' => 'পাতাহানি $1 -ত মিলাপ আসে',
-'linklistsub'         => '(মিলাপর লাতংগ)',
 'linkshere'           => "থাঙনার পাতাহানি '''[[:$1]]'''র লগে মিলাপ আসে:",
 'nolinkshere'         => "পাতা '''[[:$1]]'''হানাত কোন মিলাপ নেই।",
 'isredirect'          => 'বুলনদের পাতা',
@@ -858,7 +860,7 @@ $messages = array(
 'show-big-image'       => 'পুল্লাপ রিজলিউশন',
 'show-big-image-thumb' => '<small>আগচা হানর সাইজহান: $1 × $2 পিক্সেলস</small>',
 
-# Special:NewImages
+# Special:NewFiles
 'newimages' => 'নুৱা ফাইলর গ্যালারিগ',
 'ilsubmit'  => 'বিসারা',
 'bydate'    => 'তারিখর সিজিলন',
@@ -902,13 +904,8 @@ $messages = array(
 'confirmemail_loggedin'   => 'তর ই-মেইল ঠিকানাহার লেপকরানিহান চুমিল।',
 
 # action=purge
-'confirm_purge'        => 'পাতা এহানর ক্যাশহান ঙক্ষি করানি মনারতা? 
-
-$1',
 'confirm_purge_button' => 'চুমিসে',
-
-# AJAX search
-'articletitles' => "যে পাতাহানি ''$1'' ন অকরাগ, অতার তালিকা",
+'confirm-purge-top'    => 'পাতা এহানর ক্যাশহান ঙক্ষি করানি মনারতা?',
 
 # Auto-summaries
 'autoredircomment' => '[[$1]]-ত যানার বারো-র্নিদেশ করানি ইল',
