@@ -6,6 +6,7 @@
  *
  * @author Chavash
  * @author PCode
+ * @author Александр Сигачёв
  */
 
 $fallback = 'ru';
@@ -21,8 +22,8 @@ $namespaceNames = array(
 	NS_USER_TALK        => 'Хутшăнаканăн_канашлу_страници',
 	# NS_PROJECT set by $wgMetaNamespace
 	NS_PROJECT_TALK     => '$1_сӳтсе_явмалли',
-	NS_IMAGE            => 'Ӳкерчĕк',
-	NS_IMAGE_TALK       => 'Ӳкерчĕке_сӳтсе_явмалли',
+	NS_FILE             => 'Ӳкерчĕк',
+	NS_FILE_TALK        => 'Ӳкерчĕке_сӳтсе_явмалли',
 	NS_MEDIAWIKI        => 'MediaWiki',
 	NS_MEDIAWIKI_TALK   => 'MediaWiki_сӳтсе_явмалли',
 	NS_TEMPLATE         => 'Шаблон',
@@ -81,8 +82,6 @@ $messages = array(
 'underline-never'   => 'Нихăçан та',
 'underline-default' => 'Браузер ĕнерлевĕсене усă курмалла',
 
-'skinpreview' => '(Малтанхи курăну)',
-
 # Dates
 'sunday'        => 'вырсарникун',
 'monday'        => 'Тунтикун',
@@ -158,7 +157,7 @@ $messages = array(
 == Пулăшма пултарĕç ==
 * [http://www.mediawiki.org/wiki/Manual:Configuration_settings Ĕнерлевсен списокĕ];
 * [http://www.mediawiki.org/wiki/Manual:FAQ MediaWiki тăрăх час-часах ыйтакан ыйтусемпе хуравсем];
-* [http://lists.wikimedia.org/mailman/listinfo/mediawiki-announce MediaWiki çĕнĕ верси тухнине пĕлтерекен рассылка].',
+* [https://lists.wikimedia.org/mailman/listinfo/mediawiki-announce MediaWiki çĕнĕ верси тухнине пĕлтерекен рассылка].',
 
 'about'          => 'Ăнлантаркăч',
 'article'        => 'Статья',
@@ -176,7 +175,7 @@ $messages = array(
 'mytalk'         => 'Ман канашлу страници',
 'anontalk'       => 'Çак IP-адреса сӳтсе явни',
 'navigation'     => 'Меню',
-'and'            => 'тата',
+'and'            => '&#32;тата',
 
 # Metadata in edit box
 'metadata_help' => 'Метаданнăйсем:',
@@ -239,8 +238,6 @@ $messages = array(
 # All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
 'aboutsite'            => '{{SITENAME}} çинчен',
 'aboutpage'            => 'Project:çинчен',
-'bugreports'           => 'Йăнăш çинчен пĕлтерни',
-'bugreportspage'       => 'Project:Йăнăшсен пĕтĕмлетĕвĕ',
 'copyright'            => 'Ку ăшлăх $1 килĕшӳллĕн сарăлать.',
 'copyrightpagename'    => '{{SITENAME}} проектăн автор прависем',
 'copyrightpage'        => '{{ns:project}}:Автор прависем',
@@ -263,8 +260,6 @@ $messages = array(
 
 'badaccess'        => 'Доступ йăнăшĕ',
 'badaccess-group0' => 'Эсир ыйтакан ĕçе тăваймастăр',
-'badaccess-group1' => 'Ку ĕçе $1 шутне кĕрекен хутшăнакан кăна тума пултарать.',
-'badaccess-group2' => 'Ку ĕçе $1 шутне кĕрекен хутшăнакан кăна тума пултарать.',
 'badaccess-groups' => 'Ку ĕçе $1 шутне кĕрекен хутшăнакан кăна тума пултарать.',
 
 'versionrequired'     => 'MediaWiki-н $1 версийĕ кирлĕ',
@@ -358,7 +353,6 @@ $1',
 'cannotdelete'         => 'Эсир кăтартнă страницăна е файла кăларса пăрахаймастпăр. Ăна, тен, урăххи кăларса пăрахнă?',
 'badtitle'             => 'Ку ят килĕшмест',
 'badtitletext'         => 'Эсир кăтартнă статья ячĕ тĕрĕс мар, пушă, е чĕлхе хушшинчипе интервики ячĕ тĕрĕс мар. Ятра усă курма юраман паллăсене çырнинче пулма пултарать.',
-'perfdisabled'         => 'Каçарăр та, сервер йывăррăн ĕçленине пула ку ĕçе вăхăтлăха тума май çук.',
 'perfcached'           => 'Ку даннăйсене кэшран илнĕ, çавна май унта юлашки улшăнусем палăрмасăр пултараççĕ.',
 'perfcachedts'         => 'Ку даннăйсене кэшран илнĕ, юлашки хут вăл $1 вăхăтра çĕнелнĕ.',
 'querypage-no-updates' => 'Ку страницăна хальхи вăхăтра улăштарма чарнă. Ку даннăйсене хальхи вăхăтра çĕнетме май çук.',
@@ -380,7 +374,7 @@ $1',
 Çак сăлтава кăтартнă: ''$2''.",
 
 # Virus scanner
-'virus-badscanner'     => 'Ĕнерлев йăнăшĕ. Вирус сканерĕ паллă мар: <i>$1</i>',
+'virus-badscanner'     => "Ĕнерлев йăнăшĕ. Вирус сканерĕ паллă мар: ''$1''",
 'virus-scanfailed'     => 'скенерланă чухнехи йăнăш (код $1)',
 'virus-unknownscanner' => 'паллă мар антивирус:',
 
@@ -396,7 +390,6 @@ $1',
 'yourpasswordagain'          => 'Вăрттăн сăмах тепре çырăр:',
 'remembermypassword'         => 'Ку компьютер çинче мана астуса хăвармалла',
 'yourdomainname'             => 'Сирĕн домен',
-'loginproblem'               => '<span style="color:red">Хутшăнакана палаймарăмăр.</span>',
 'login'                      => 'Сайта кĕр',
 'nav-login-createaccount'    => 'Сайта кĕр / регистрацилен',
 'loginprompt'                => 'Сайта кĕрес тесен сирĕн «cookies»-па усă курма ирĕк памалла.',
@@ -451,10 +444,11 @@ $1',
 'loginlanguagelabel'         => 'Чĕлхе: $1',
 
 # Password reset dialog
-'resetpass'         => 'Хутшăнаканăн вăрттăн сăмахне çĕнетесси',
-'resetpass_header'  => 'Пароле пăрахăçла',
-'resetpass_submit'  => 'Вăрттăн сăмаха лартса сайта кĕр',
-'resetpass_missing' => 'Формăра даннăйсем çук.',
+'resetpass'        => 'Хутшăнаканăн вăрттăн сăмахне çĕнетесси',
+'resetpass_header' => 'Пароле пăрахăçла',
+'oldpassword'      => 'Кивě пароль',
+'newpassword'      => 'Çěнě пароль',
+'resetpass_submit' => 'Вăрттăн сăмаха лартса сайта кĕр',
 
 # Edit page toolbar
 'bold_sample'    => 'Çурмахулăм текст',
@@ -476,8 +470,8 @@ $1',
 'hr_tip'         => 'Горизонтальлĕ йĕр (сахалтарах усă курăр)',
 
 # Edit pages
-'summary'                => 'Улшăнусен кĕске ăнлантарăвĕ',
-'subject'                => 'Тема',
+'summary'                => 'Улшăнусен кĕске ăнлантарăвĕ:',
+'subject'                => 'Тема:',
 'minoredit'              => 'Кунта пěчěк улшăнусем кăна кěртнě',
 'watchthis'              => 'Ку страницăна кěртекен  улшăнусем  хыççăн сăнамалла',
 'savearticle'            => 'Страницăна çырса хур',
@@ -487,8 +481,8 @@ $1',
 'showdiff'               => 'Кĕртнĕ улшăнусем',
 'anoneditwarning'        => "'''Асăрхăр''': Эсир сайта хăвăр çинчен пĕлтермен, çавăнпа та ку страницăна улăштарнин журналне сирĕн IP-адреса çырса хума тивĕ.",
 'missingcommenttext'     => 'Аяларах, тархасшăн, хăвар пĕлтерĕве çырăр.',
-'summary-preview'        => 'Ăнлантару çапла пулĕ',
-'subject-preview'        => 'Статья ячĕ çапла пулĕ',
+'summary-preview'        => 'Ăнлантару çапла пулĕ:',
+'subject-preview'        => 'Статья ячĕ çапла пулĕ:',
 'blockedtitle'           => 'Хутшăнакана ĕçлеме чарнă',
 'blockedtext'            => "<big>'''Ку аккаунта е IP-адреса ĕçлеме чарнă.'''</big>
 
@@ -520,8 +514,8 @@ $1 хутшăнакан патне, е ытти [[{{MediaWiki:Grouppage-sysop}}|
 'usercsspreview'         => "'''Ан манăр, эсир сирĕн css файл епле пулассине çеç куратăр, ăна халлĕхе çырса хуман!'''",
 'userjspreview'          => "'''Астăвăр, ку сирĕн javascript-файлăн малтанхи курăмĕ кăна, ăна хальлĕхе çырса хуман!'''",
 'updated'                => '(Çĕнелнĕ)',
-'note'                   => '<strong>Ăнлантаркăч:</strong>',
-'previewnote'            => '<strong>Ку страницăна халлěхе çырса хуман. Эсир ку страницă мěнле пулассине кăна куратăр!</strong>',
+'note'                   => "'''Ăнлантаркăч:'''",
+'previewnote'            => "'''Ку страницăна халлěхе çырса хуман. Эсир ку страницă мěнле пулассине кăна куратăр!'''",
 'previewconflict'        => 'Çӳлти чӳречере эсир халĕ çырса хурсан текст епле курăннине куратăр.',
 'editing'                => '$1 тӳрлетни',
 'editingsection'         => '$1 тӳрлетни (статья разделě)',
@@ -530,9 +524,9 @@ $1 хутшăнакан патне, е ытти [[{{MediaWiki:Grouppage-sysop}}|
 'yourtext'               => 'Сирĕн текст',
 'storedversion'          => 'Астуса хăварнă верси',
 'yourdiff'               => 'Уйрăмлăхсем',
-'copyrightwarning'       => 'Эсир кĕртнĕ, е улăштарнă пур статьясен тексчĕсем $2 ($1 пăхăр) лизензине пăхăнаççĕ. Енчен те эсир кĕртнĕ текста пурте усă курма, тӳрлетсе улăштарма пултарнипе килĕшместĕр пулсан кунта ăна ан кĕртĕр. <br /> Çавăн пекех эсир кĕртнĕ текстăн е авторĕ, е ăна ирĕклĕ усă курма юракан çăлкуçсенчен илнине çирĕплететĕр. <br /> <strong>АВТОР ПРАВИСЕМПЕ ХӲТĔЛЕНĔ МАТЕРИАЛСЕНЕ АН КĔРТĔР!</strong>',
-'protectedpagewarning'   => '<strong>АСĂРХАТТАРНИ: ку страницăна улшăнусем кĕртессинчен хӳтĕленĕ, ăна тӳрлетме администраторсем кăна пултараççĕ.</strong>',
-'titleprotectedwarning'  => '<strong>Асăрхаттару. Ку страницăпа ĕçлеме чарнă, ăна хăш-пĕр хутшăнакан кăна хатерлеме пултарать.</strong>',
+'copyrightwarning'       => "Эсир кĕртнĕ, е улăштарнă пур статьясен тексчĕсем $2 ($1 пăхăр) лизензине пăхăнаççĕ. Енчен те эсир кĕртнĕ текста пурте усă курма, тӳрлетсе улăштарма пултарнипе килĕшместĕр пулсан кунта ăна ан кĕртĕр. <br /> Çавăн пекех эсир кĕртнĕ текстăн е авторĕ, е ăна ирĕклĕ усă курма юракан çăлкуçсенчен илнине çирĕплететĕр. <br /> '''АВТОР ПРАВИСЕМПЕ ХӲТĔЛЕНĔ МАТЕРИАЛСЕНЕ АН КĔРТĔР!'''",
+'protectedpagewarning'   => "'''АСĂРХАТТАРНИ: ку страницăна улшăнусем кĕртессинчен хӳтĕленĕ, ăна тӳрлетме администраторсем кăна пултараççĕ.'''",
+'titleprotectedwarning'  => "'''Асăрхаттару. Ку страницăпа ĕçлеме чарнă, ăна хăш-пĕр хутшăнакан кăна хатерлеме пултарать.'''",
 'templatesused'          => 'Ку страница çинче усă курнă шаблонсем:',
 'templatesusedpreview'   => 'Пăхакан страница çинче усă курнă шаблонсем:',
 'templatesusedsection'   => 'Ку пайра усă курнă шаблонсем:',
@@ -554,10 +548,9 @@ $1 хутшăнакан патне, е ытти [[{{MediaWiki:Grouppage-sysop}}|
 # History pages
 'viewpagelogs'        => 'Ку страницăн журналĕсене пăхасси',
 'nohistory'           => 'Ку страницăн улшăнусен журналĕ çук.',
-'revnotfound'         => 'Верси тупăнмарĕ',
 'currentrev'          => 'Хальхи верси',
 'revisionasof'        => '$1 верси',
-'revision-info'       => '$1 версийĕ; $2',
+'revision-info'       => '$1 версийĕ; $2', # Additionally available: $3: revision id
 'previousrevision'    => '&larr;Малтанхи верси',
 'nextrevision'        => 'Çěнěрех верси→',
 'currentrevisionlink' => 'хальхи верси çине куç',
@@ -607,6 +600,7 @@ $1 хутшăнакан патне, е ытти [[{{MediaWiki:Grouppage-sysop}}|
 'textmatches'        => 'Статьясенчи текст пĕрпеклĕхĕ',
 'prevn'              => 'малтанхи $1',
 'nextn'              => 'малалли $1',
+'searchhelp-url'     => 'Help:Пулăшу',
 'showingresults'     => 'Аяларах эсир <b>#$2</b> пуçласа кăтартнă <b>$1</b> йĕркене куратăр.',
 'powersearch'        => 'Анлă шырав',
 'powersearch-legend' => 'Анлă шырав',
@@ -619,6 +613,7 @@ $1 хутшăнакан патне, е ытти [[{{MediaWiki:Grouppage-sysop}}|
 'qbsettings'         => 'Навигаци хăми',
 'changepassword'     => 'Пароле улăштар',
 'skin'               => 'Ерешленӳ',
+'skin-preview'       => 'Малтанхи курăну',
 'dateformat'         => 'Дата формачĕ',
 'datedefault'        => 'Палăртман чухнехи',
 'math_syntax_error'  => 'синтаксис йăнăшĕ',
@@ -626,8 +621,6 @@ $1 хутшăнакан патне, е ытти [[{{MediaWiki:Grouppage-sysop}}|
 'prefs-watchlist'    => 'Сăнав списокĕ',
 'prefs-misc'         => 'Ытти ĕнерлевсем',
 'saveprefs'          => 'Çырса хур',
-'oldpassword'        => 'Кивě пароль',
-'newpassword'        => 'Çěнě пароль',
 'textboxsize'        => 'Тӳрлетни',
 'rows'               => 'Йěркесем',
 'columns'            => 'Юпасем:',
@@ -741,18 +734,18 @@ $1 хутшăнакан патне, е ытти [[{{MediaWiki:Grouppage-sysop}}|
 'upload_source_url'  => ' (тĕрĕс, пурте курма пултаракан интертетел адресĕ)',
 'upload_source_file' => ' (сирĕн компьютер çинчи файл)',
 
-# Special:ImageList
-'imagelist-summary'     => 'Ку ятарлă страницăра эсир пур кĕртнĕ файлсене куратăр.
+# Special:ListFiles
+'listfiles-summary'     => 'Ку ятарлă страницăра эсир пур кĕртнĕ файлсене куратăр.
 Нумай пулмасть кĕртнисем çулте вырнаçнă.
 Юпа тăррине пуссан йĕркелӳ майĕ улшăнĕ.',
-'imagelist_search_for'  => 'Ӳкерчĕк ячĕ тăрăх шырани:',
-'imagelist'             => 'Ӳкерчěксен списокě',
-'imagelist_name'        => 'Файл ячĕ',
-'imagelist_user'        => 'Хутшăнакан',
-'imagelist_size'        => 'Виçи',
-'imagelist_description' => 'Ăнлантаркăч',
+'listfiles_search_for'  => 'Ӳкерчĕк ячĕ тăрăх шырани:',
+'listfiles'             => 'Ӳкерчěксен списокě',
+'listfiles_name'        => 'Файл ячĕ',
+'listfiles_user'        => 'Хутшăнакан',
+'listfiles_size'        => 'Виçи',
+'listfiles_description' => 'Ăнлантаркăч',
 
-# Image description page
+# File description page
 'filehist'                  => 'Файл историйĕ',
 'imagelinks'                => 'Ссылкăсем',
 'linkstoimage'              => 'Çак страницăсем ку файл çине кăтартаççĕ:',
@@ -772,7 +765,6 @@ $1 хутшăнакан патне, е ытти [[{{MediaWiki:Grouppage-sysop}}|
 'filedelete-submit'           => 'Кăларса пăрах',
 'filedelete-success'          => "'''$1''' кăларса пăрахрăмăр.",
 'filedelete-success-old'      => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\'-ăн $3, $2 вăхăтри версине кăларса пăрахнă.</span>',
-'filedelete-iscurrent'        => 'Эсир ку файлăн юлашки версине кăларса пăрахасшăн. Тархасшăн, файла малтан кивĕ версинчен пĕрин патне те пулин тавăрăр.',
 'filedelete-otherreason'      => 'Урăх сăлтав:',
 'filedelete-reason-otherlist' => 'Урăх сăлтав',
 
@@ -797,9 +789,8 @@ $1 хутшăнакан патне, е ытти [[{{MediaWiki:Grouppage-sysop}}|
 'randomredirect' => 'Ăнсăртран илнĕ куçару',
 
 # Statistics
-'sitestats'              => 'Сайт статистики',
-'userstats'              => 'Хутшăнакансен статистики',
-'statistics-mostpopular' => 'Чи нумай пăхакан страницăсем',
+'statistics-header-users' => 'Хутшăнакансен статистики',
+'statistics-mostpopular'  => 'Чи нумай пăхакан страницăсем',
 
 'disambiguations'      => 'Нумай пĕлтерĕшлĕ статьясене кăтартакан страницăсем',
 'disambiguationspage'  => 'Template:Disambig',
@@ -857,7 +848,6 @@ $1 хутшăнакан патне, е ытти [[{{MediaWiki:Grouppage-sysop}}|
 'specialloguserlabel' => 'Хутшăнакан:',
 'log'                 => 'Журналсем',
 'all-logs-page'       => 'Журналсем',
-'log-search-submit'   => 'Туп',
 
 # Special:AllPages
 'allpages'         => 'Пěтěм страницăсем',
@@ -901,27 +891,21 @@ $1 хутшăнакан патне, е ытти [[{{MediaWiki:Grouppage-sysop}}|
 'emailsenttext'   => 'Сирĕн электронлă çырăва леçрĕмĕр.',
 
 # Watchlist
-'watchlist'            => 'Пăхса тăракан страницăсем списокĕ',
-'mywatchlist'          => 'Ман сăнав списокĕ',
-'nowatchlist'          => 'Эсир пăхса тăракан страницăсен списокĕ пушă.',
-'watchnologin'         => 'Системăна хăвăр ята каламалла',
-'watchnologintext'     => 'Сăнав списокне улăштармашкăн сирĕн системăна [[Special:UserLogin|хăвăр ята каламалла]].',
-'addedwatch'           => 'Сăнамалли шутне кĕртрĕмĕр',
-'addedwatchtext'       => '«[[:$1]]» страницăна сирĕн [[Special:Watchlist|сăнав списока]] хушрăмăр. Малашне [[Special:RecentChanges|юлашки улшăнусене кăтартакан страницăра]] унпа çыхăннă улшăнусене хылăм шрифтпа курăнĕç.
+'watchlist'        => 'Пăхса тăракан страницăсем списокĕ',
+'mywatchlist'      => 'Ман сăнав списокĕ',
+'nowatchlist'      => 'Эсир пăхса тăракан страницăсен списокĕ пушă.',
+'watchnologin'     => 'Системăна хăвăр ята каламалла',
+'watchnologintext' => 'Сăнав списокне улăштармашкăн сирĕн системăна [[Special:UserLogin|хăвăр ята каламалла]].',
+'addedwatch'       => 'Сăнамалли шутне кĕртрĕмĕр',
+'addedwatchtext'   => '«[[:$1]]» страницăна сирĕн [[Special:Watchlist|сăнав списока]] хушрăмăр. Малашне [[Special:RecentChanges|юлашки улшăнусене кăтартакан страницăра]] унпа çыхăннă улшăнусене хылăм шрифтпа курăнĕç.
 Енчен те сирĕн ку страницăна сăнас кăмăл пĕтсен, «ан сăна» пускăч çине пусăр.',
-'removedwatch'         => 'Сăнамалли списокран кăларса пăрахнă',
-'removedwatchtext'     => '«[[:$1]]» страницăна сирĕн сăнамалли списокран кăларса пăрахнă.',
-'watch'                => 'Сăна',
-'watchthispage'        => 'Ку страницăна сăнаса тăр',
-'unwatch'              => 'ан сăна',
-'unwatchthispage'      => 'Сăнама пăрах',
-'notanarticle'         => 'Ку статья мар',
-'watchlist-show-bots'  => 'Ботсен ĕçне кăтарт',
-'watchlist-hide-bots'  => 'Ботсен ĕçне пытар',
-'watchlist-show-own'   => 'Ман тӳрлетӳсене кăтарт',
-'watchlist-hide-own'   => 'Ман тӳрлетӳсене пытар',
-'watchlist-show-minor' => 'Пĕчĕк тӳрлетӳсене кăтарт',
-'watchlist-hide-minor' => 'Пĕчĕк тӳрлетӳсене пытар',
+'removedwatch'     => 'Сăнамалли списокран кăларса пăрахнă',
+'removedwatchtext' => '«[[:$1]]» страницăна сирĕн сăнамалли списокран кăларса пăрахнă.',
+'watch'            => 'Сăна',
+'watchthispage'    => 'Ку страницăна сăнаса тăр',
+'unwatch'          => 'ан сăна',
+'unwatchthispage'  => 'Сăнама пăрах',
+'notanarticle'     => 'Ку статья мар',
 
 # Displayed when you click the "watch" button and it is in the process of watching
 'watching'   => 'Сăнамаллисем шутне хушасси…',
@@ -933,29 +917,34 @@ $1 хутшăнакан патне, е ытти [[{{MediaWiki:Grouppage-sysop}}|
 'created'            => 'хатĕрленĕ',
 'enotif_anon_editor' => '$1 анонимлă хутшăнакан',
 
-# Delete/protect/revert
-'deletepage'                  => 'Кăларса парахнă статьясем',
-'confirm'                     => 'Çирĕплетни',
-'excontent'                   => 'ăшлăхĕ: «$1»',
-'excontentauthor'             => 'ăшлăхĕ: «$1» ([[Special:Contributions/$2|$2]] пĕччен кăна улшăнусем кĕртнĕ)',
-'exblank'                     => 'страница пушă пулнă',
-'actioncomplete'              => 'Турăмăр',
-'deletedtext'                 => '«$1» кăларса парахрăмăр.
+# Delete
+'deletepage'        => 'Кăларса парахнă статьясем',
+'confirm'           => 'Çирĕплетни',
+'excontent'         => 'ăшлăхĕ: «$1»',
+'excontentauthor'   => 'ăшлăхĕ: «$1» ([[Special:Contributions/$2|$2]] пĕччен кăна улшăнусем кĕртнĕ)',
+'exblank'           => 'страница пушă пулнă',
+'actioncomplete'    => 'Турăмăр',
+'deletedtext'       => '«$1» кăларса парахрăмăр.
 Юлашки кăларса пăрахнă статьясен списокне курмашкăн кунта пăхăр: $2.',
-'suppressedarticle'           => '«[[$1]]» пытарнă',
-'dellogpage'                  => 'Кăларса пăрахнисем',
-'dellogpagetext'              => 'Аяларах эсир юлашки кăларса пăрахнă статьясене куратăр.',
-'deletionlog'                 => 'кăларса пăрахнисем',
-'reverted'                    => 'Малтанхи версине тавăрнă',
-'deletecomment'               => 'Кăларса пăрахнин сăлтавĕ',
-'rollback'                    => 'Тÿрлетÿсене каялла куçарасси',
-'rollback_short'              => 'Каялла куçарасси',
-'rollbacklink'                => 'каялла тавăр',
-'rollbackfailed'              => 'Каялла куçарнă çухна йăнăш тухнă',
+'suppressedarticle' => '«[[$1]]» пытарнă',
+'dellogpage'        => 'Кăларса пăрахнисем',
+'dellogpagetext'    => 'Аяларах эсир юлашки кăларса пăрахнă статьясене куратăр.',
+'deletionlog'       => 'кăларса пăрахнисем',
+'reverted'          => 'Малтанхи версине тавăрнă',
+'deletecomment'     => 'Кăларса пăрахнин сăлтавĕ',
+
+# Rollback
+'rollback'       => 'Тÿрлетÿсене каялла куçарасси',
+'rollback_short' => 'Каялла куçарасси',
+'rollbacklink'   => 'каялла тавăр',
+'rollbackfailed' => 'Каялла куçарнă çухна йăнăш тухнă',
+
+# Protect
 'protectlogpage'              => 'Хӳтĕлев журналĕ',
 'protectlogtext'              => 'Аяларах эсир статьясене хӳтĕленин тата хӳтĕлев паллине пăрахаçланин журналне куратăр.',
 'protectedarticle'            => '«[[$1]]» страницăна хӳтĕлерĕмĕр',
 'unprotectedarticle'          => '«[[$1]]» страницăн хӳтĕлевне пăрахăçланă',
+'prot_1movedto2'              => '$1 $2 çине куçарнă',
 'protectcomment'              => 'Страницăна хӳтĕленин сăлтавĕ',
 'protectexpiry'               => 'Пĕтет:',
 'protect-level-autoconfirmed' => 'Статьяна çĕнĕрен регистрациленнĕ, е пачах та регистрациленменнисенчен хӳтĕле',
@@ -987,7 +976,6 @@ $1 хутшăнакан патне, е ытти [[{{MediaWiki:Grouppage-sysop}}|
 
 # What links here
 'whatlinkshere'       => 'Кунта килекен ссылкăсем',
-'linklistsub'         => '(ссылкăсен списокĕ)',
 'linkshere'           => "Çак страницăсем '''[[:$1]]''' çине илсе килеççĕ:",
 'nolinkshere'         => "'''[[:$1]]''' страница çине ытти страницăсенчен килме пулмасть.",
 'whatlinkshere-links' => '← ссылкăсем',
@@ -1019,6 +1007,7 @@ $1 хутшăнакан патне, е ытти [[{{MediaWiki:Grouppage-sysop}}|
 # Move page
 'move-page-legend'        => 'Страницăна куçарнă',
 'movearticle'             => 'Страницăн ятне улăштар',
+'movenologin'             => 'Система сирĕн ята пĕлмест',
 'newtitle'                => 'Çĕнĕ ят',
 'move-watch'              => 'Ку страницăна сăнамаллисем шутне хуш',
 'movepagebtn'             => 'Страницăн ятне улăштар',
@@ -1128,7 +1117,7 @@ $1 хутшăнакан патне, е ытти [[{{MediaWiki:Grouppage-sysop}}|
 'file-info-size' => '($1 × $2 пиксел, файл пысăкăше: $3, MIME-тĕсĕ: $4)',
 'file-nohires'   => '<small>Пысăкрах калăпăшли çук.</small>',
 
-# Special:NewImages
+# Special:NewFiles
 'newimages'         => 'Çĕнĕ файлсен галерейи',
 'newimages-summary' => 'Ку ятарлă страницăра эсир нумай пулмасть кĕртнĕ файлсене куратăр',
 'noimages'          => 'Ӳкерчĕксем çук.',
@@ -1172,14 +1161,6 @@ $1 хутшăнакан патне, е ытти [[{{MediaWiki:Grouppage-sysop}}|
 'deletedwhileediting' => 'Асăрхăр: эсир тӳрлетнĕ вăхăтра ку страницăна кăларса парахнă!',
 'recreate'            => 'Çĕнĕрен пуçла',
 
-# HTML dump
-'redirectingto' => '[[:$1]] çине куçаракан страница …',
-
-# AJAX search
-'searchcontaining' => 'Ăшĕсенче «$1» пур статьясене шыратпăр.',
-'searchnamed'      => '$1 ятлă статьясене шыратпăр',
-'articletitles'    => '«$1»-ран пуçланакан статьясем',
-
 # Multipage image navigation
 'imgmultipageprev' => '← малтанхи страница',
 'imgmultipagenext' => 'тепĕр страница →',
