@@ -47,16 +47,17 @@ href="" class="internal"}?{/a}) bımocne.',
 'tog-watchlisthideown'        => 'Vurnayışanê mı lista mına seyr-kerdışi de bınımne',
 'tog-watchlisthidebots'       => 'Vurnayışanê boti lista mına seyr-kerdışi de bınımne',
 'tog-watchlisthideminor'      => 'Vurnayışanê qıckekan lista mına seyr-kerdışi de bınımne',
+'tog-watchlisthideliu'        => 'Lista seyrkerdışi ra vurnayışanê karberanê cıkewteyan bınımne',
+'tog-watchlisthideanons'      => 'Lista seyrkerdışi ra vurnayışanê karberanê anoniman bınımne',
 'tog-ccmeonemails'            => 'E-mailanê ke ez karberanê binan rê rışenan, mı rê kopya inan bırışe',
 'tog-diffonly'                => 'Qıyasê verziyonan de tek ferqan bımocne, perra butıne nê',
 'tog-showhiddencats'          => 'Kategoriyanê dızdine bımocne',
+'tog-norollbackdiff'          => 'Peyserardene ra dıme ferqi caverde',
 
 'underline-always'  => 'Tım',
 'underline-never'   => 'Qet',
 'underline-default' => 'Qerar cıgeyraoği dest dero',
 
-'skinpreview' => '(Verqayt)',
-
 # Dates
 'sunday'        => 'Kırê',
 'monday'        => 'Dışeme',
@@ -143,7 +144,7 @@ href="" class="internal"}?{/a}) bımocne.',
 'mytalk'         => 'Perra mına werênayışi',
 'anontalk'       => 'Perra werênayışê nê IPy',
 'navigation'     => 'pusula',
-'and'            => 'u',
+'and'            => '&#32;u',
 
 'errorpagetitle'    => 'Xeta',
 'returnto'          => 'Peyser şo $1.',
@@ -200,8 +201,6 @@ href="" class="internal"}?{/a}) bımocne.',
 # All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
 'aboutsite'            => 'Heqa {{SITENAME}} de',
 'aboutpage'            => 'Project:Heqa',
-'bugreports'           => 'Xebera xeteyan',
-'bugreportspage'       => 'Project:Xebera xeteyan',
 'copyright'            => 'Nuştey bınê Lisansê $1 de vêrenê.',
 'copyrightpagename'    => 'Heqa telifê {{SITENAME}}',
 'copyrightpage'        => '{{ns:project}}:Heqê telifi',
@@ -231,6 +230,8 @@ href="" class="internal"}?{/a}) bımocne.',
 'editsection-brackets'    => '[$1]',
 'editold'                 => 'bıvurne',
 'viewsourceold'           => 'çımey bıvêne',
+'editlink'                => 'bıvurne',
+'viewsourcelink'          => 'çımey bıvêne',
 'editsectionhint'         => 'Qısımê vurnayışi: $1',
 'toc'                     => 'Tedeestey',
 'showtoc'                 => 'bımocne',
@@ -266,7 +267,6 @@ Seba /qandê lista pelanê xasanê vêrdeyan kerem ke: [[Special:SpecialPages|{{
 # General errors
 'error'               => 'Ğelet',
 'badtitle'            => 'Sernameya xırabe',
-'perfdisabled'        => 'Qusır de seyrmeke! This feature has been temporarily disabled because it slows the database down to the point that no one can use the wiki.',
 'viewsource'          => 'Çımey bıvêne',
 'viewsourcefor'       => 'Seba / qandê $1',
 'viewsourcetext'      => 'To şikinay çımey na pele bıvêne u kopya kerê:',
@@ -307,7 +307,13 @@ It must have at least $1 characters and be different from your username.',
 'accountcreated'            => 'Hesab vıraciya',
 'loginlanguagelabel'        => 'Zıwan: $1',
 
+# Password reset dialog
+'oldpassword' => 'Parola kıhane:',
+'newpassword' => 'Parola newiye:',
+'retypenew'   => 'Parola newiye tekrar ke:',
+
 # Edit pages
+'summary'      => 'Xulasa:',
 'savearticle'  => 'Ena pele qeyd ke',
 'preview'      => 'Verqayt',
 'showpreview'  => 'Verqayti bımocne',
@@ -329,6 +335,7 @@ It must have at least $1 characters and be different from your username.',
 'editundo' => 'peyser biya',
 
 # Search results
+'searchhelp-url'     => 'Help:Tedeestey',
 'search-result-size' => '$1 ({{PLURAL:$2|1 çekuye|$2 çekuy}})',
 'powersearch'        => 'Cıgeyrayışo hera',
 'powersearch-legend' => 'Cıgeyrayışo hera',
@@ -340,13 +347,11 @@ It must have at least $1 characters and be different from your username.',
 # Preferences page
 'mypreferences'   => 'tercihê mı',
 'qbsettings-none' => 'çino',
+'skin-preview'    => 'Verqayt',
 'prefs-personal'  => 'Pela karberi',
 'prefs-rc'        => 'Vurnayışê peyêni',
 'prefs-watchlist' => 'Lista seyr-kerdışi',
 'saveprefs'       => 'Qeyd ke',
-'oldpassword'     => 'Parola kıhane:',
-'newpassword'     => 'Parola newiye:',
-'retypenew'       => 'Parola newiye tekrar ke:',
 'timezonelegend'  => 'Warey saete',
 'files'           => 'Dosyey',
 
@@ -374,13 +379,13 @@ It must have at least $1 characters and be different from your username.',
 'filesource' => 'Çımey:',
 'savefile'   => 'Dosya qeyd ke',
 
-# Special:ImageList
+# Special:ListFiles
 'imgfile'        => 'dosya',
-'imagelist'      => 'Lista Dosya',
-'imagelist_date' => 'Tarix',
-'imagelist_user' => 'Karber',
+'listfiles'      => 'Lista Dosya',
+'listfiles_date' => 'Tarix',
+'listfiles_user' => 'Karber',
 
-# Image description page
+# File description page
 'filehist'          => 'Tarixê dosya',
 'filehist-datetime' => 'Tarix/Zeman',
 'filehist-user'     => 'Karber',
@@ -419,7 +424,6 @@ It must have at least $1 characters and be different from your username.',
 
 # Special:Log
 'specialloguserlabel' => 'Karber:',
-'log-search-submit'   => 'Şo',
 
 # Special:AllPages
 'alphaindexline' => '$1 ra $2ine',
@@ -443,10 +447,12 @@ It must have at least $1 characters and be different from your username.',
 'watching'   => 'Seyr ke...',
 'unwatching' => 'Seyr meke...',
 
-# Delete/protect/revert
+# Delete
 'deletepage'            => 'Pele bıestere',
 'deletereasonotherlist' => 'Sebebo bin',
-'rollbacklink'          => 'peyser bia',
+
+# Rollback
+'rollbacklink' => 'peyser bia',
 
 # Restrictions (nouns)
 'restriction-edit' => 'Bıvurne',
@@ -506,7 +512,7 @@ Kerem ke, qeyd-kerdış ra ver gozega verqayti bıxebıtne.',
 # Attribution
 'lastmodifiedatby' => 'Ena pele tewr peyên roca $2, $1 by $3. de biya rocaniye', # $1 date, $2 time, $3 user
 
-# Special:NewImages
+# Special:NewFiles
 'ilsubmit' => 'Cıgeyre',
 
 # Bad image list
@@ -518,9 +524,6 @@ Na rêze de her gırêyo bin zey istisna vêniyeno, yanê pelê ke dosya beno ke
 
 'exif-gaincontrol-0' => 'çino',
 
-# AJAX search
-'articletitles' => "Perri be ''$1'' dest cı kenê",
-
 # Special:FilePath
 'filepath-page' => 'Dosya:',
 
