@@ -20,8 +20,8 @@ $namespaceNames = array(
 	NS_USER_TALK      => 'Diskisyon_Itilizatè',
 	# NS_PROJECT set by $wgMetaNamespace
 	NS_PROJECT_TALK   => 'Diskisyon_$1',
-	NS_IMAGE          => 'Imaj',
-	NS_IMAGE_TALK     => 'Diskisyon_Imaj',
+	NS_FILE           => 'Imaj',
+	NS_FILE_TALK      => 'Diskisyon_Imaj',
 	NS_MEDIAWIKI      => 'MedyaWiki',
 	NS_MEDIAWIKI_TALK => 'Diskisyon_MedyaWiki',
 	NS_TEMPLATE       => 'Modèl',
@@ -32,6 +32,93 @@ $namespaceNames = array(
 	NS_CATEGORY_TALK  => 'Diskisyon_Kategori'
 );
 
+$specialPageAliases = array(
+	'DoubleRedirects'           => array( 'RedireksyonDouble' ),
+	'BrokenRedirects'           => array( 'RedireksyonKase' ),
+	'Disambiguations'           => array( 'Disanbigyasyon', 'Klarifikasyon' ),
+	'Userlogin'                 => array( 'Login', 'AntreLòg' ),
+	'Userlogout'                => array( 'Dekoneksyon', 'ExitLòg' ),
+	'CreateAccount'             => array( 'KreyeKonpt' ),
+	'Preferences'               => array( 'Preferans' ),
+	'Watchlist'                 => array( 'LisSwivi' ),
+	'Recentchanges'             => array( 'ChanjmanResan' ),
+	'Upload'                    => array( 'Telechaje' ),
+	'Listfiles'                 => array( 'LisImaj' ),
+	'Newimages'                 => array( 'NouvoImaj' ),
+	'Listusers'                 => array( 'LisItilizatè', 'LisYonItilizatè' ),
+	'Listgrouprights'           => array( 'LisDwaGroup' ),
+	'Statistics'                => array( 'Estatistik' ),
+	'Randompage'                => array( 'Randonm', 'PajRandonm' ),
+	'Lonelypages'               => array( 'PajSolitè', 'PajOfelen' ),
+	'Uncategorizedpages'        => array( 'PajEnkategorize' ),
+	'Uncategorizedcategories'   => array( 'KategoriEnkategorize' ),
+	'Uncategorizedimages'       => array( 'ImageEnkategorize' ),
+	'Uncategorizedtemplates'    => array( 'TenmplaEnkategorize' ),
+	'Unusedcategories'          => array( 'KategoriPaItilize' ),
+	'Unusedimages'              => array( 'ImajePaItilize' ),
+	'Wantedpages'               => array( 'PajBezwen', 'LyenKase' ),
+	'Wantedcategories'          => array( 'KategoriBezwen' ),
+	'Mostlinked'                => array( 'PlisLenke' ),
+	'Mostlinkedcategories'      => array( 'KategoriPlisLenke', 'KategoriPlisItilize' ),
+	'Mostlinkedtemplates'       => array( 'TenmplaPlisLenke', 'TenmplaPlisItilize' ),
+	'Mostcategories'            => array( 'PlisKategori' ),
+	'Mostimages'                => array( 'PlisImaj' ),
+	'Mostrevisions'             => array( 'PlisRevizyon' ),
+	'Fewestrevisions'           => array( 'MwensRevizyon' ),
+	'Shortpages'                => array( 'PajKout' ),
+	'Longpages'                 => array( 'PajLong' ),
+	'Newpages'                  => array( 'PajNouvo' ),
+	'Ancientpages'              => array( 'PajAnsyen' ),
+	'Deadendpages'              => array( 'PajMòtèl' ),
+	'Protectedpages'            => array( 'PajProteje' ),
+	'Protectedtitles'           => array( 'TitProteje' ),
+	'Allpages'                  => array( 'ToutPaj' ),
+	'Prefixindex'               => array( 'PrefixEndèx' ),
+	'Ipblocklist'               => array( 'LisIPBloke' ),
+	'Specialpages'              => array( 'PajEspesyal' ),
+	'Contributions'             => array( 'Kontribisyon' ),
+	'Emailuser'                 => array( 'EmèlItilizatè' ),
+	'Confirmemail'              => array( 'VerifyeEmèl' ),
+	'Whatlinkshere'             => array( 'SakLenkeLa' ),
+	'Recentchangeslinked'       => array( 'LyenChajmanResan', 'Chanjman Relativ' ),
+	'Movepage'                  => array( 'DeplasePaj' ),
+	'Blockme'                   => array( 'Bloke-m' ),
+	'Booksources'               => array( 'SousLiv' ),
+	'Categories'                => array( 'Kategori' ),
+	'Export'                    => array( 'Expòt' ),
+	'Version'                   => array( 'Vèsyon' ),
+	'Allmessages'               => array( 'ToutMesaj' ),
+	'Log'                       => array( 'Jounal', 'Lòg yo' ),
+	'Blockip'                   => array( 'BlokeIP' ),
+	'Undelete'                  => array( 'Restore' ),
+	'Import'                    => array( 'Enpòt' ),
+	'Lockdb'                    => array( 'KadnaseDB' ),
+	'Unlockdb'                  => array( 'DekadnaseDB' ),
+	'Userrights'                => array( 'DwaItilizatè' ),
+	'MIMEsearch'                => array( 'BouskayMIME' ),
+	'FileDuplicateSearch'       => array( 'BouskeFilDouplike' ),
+	'Unwatchedpages'            => array( 'PajPaSiveye' ),
+	'Listredirects'             => array( 'RedireksyonLis' ),
+	'Revisiondelete'            => array( 'RevizyonSiprime' ),
+	'Unusedtemplates'           => array( 'TanmplaVyèj' ),
+	'Randomredirect'            => array( 'RedireksyonRandonm' ),
+	'Mypage'                    => array( 'PajMwen' ),
+	'Mytalk'                    => array( 'Diskisyon-m' ),
+	'Mycontributions'           => array( 'Kontribisyon-m' ),
+	'Listadmins'                => array( 'AdminLis' ),
+	'Listbots'                  => array( 'RoboLis' ),
+	'Popularpages'              => array( 'PajPopilè' ),
+	'Search'                    => array( 'Chache', 'Fouye' ),
+	'Resetpass'                 => array( 'ResètMoPas' ),
+	'Withoutinterwiki'          => array( 'SanEntèwiki' ),
+	'MergeHistory'              => array( 'MeleIstwa' ),
+	'Filepath'                  => array( 'ChemenFil' ),
+	'Invalidateemail'           => array( 'EnvalideEmèl' ),
+	'Blankpage'                 => array( 'PajVid' ),
+	'LinkSearch'                => array( 'BouskeLyen' ),
+	'DeletedContributions'      => array( 'SiprimeKontribisyon' ),
+);
+
 $linkTrail = '/^([a-zàèòÀÈÒ]+)(.*)$/sDu';
 
 $messages = array(
@@ -80,8 +167,6 @@ $messages = array(
 'underline-never'   => 'Jamè',
 'underline-default' => 'Brozè defo',
 
-'skinpreview' => '(Voye kout zye)',
-
 # Dates
 'sunday'        => 'dimanch',
 'monday'        => 'lendi',
@@ -175,7 +260,7 @@ $messages = array(
 'mytalk'         => 'Paj diskisyon mwen an',
 'anontalk'       => 'Diskite avèk adrès IP sa',
 'navigation'     => 'Navigasyon',
-'and'            => 'epi',
+'and'            => '&#32;epi',
 
 # Metadata in edit box
 'metadata_help' => 'Metadata:',
@@ -238,8 +323,6 @@ $messages = array(
 # All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
 'aboutsite'            => 'Apwopo {{SITENAME}}',
 'aboutpage'            => 'Project:Apwopo',
-'bugreports'           => 'Rapò erè ki fèt',
-'bugreportspage'       => 'Project:Repòt erè yo',
 'copyright'            => 'Konteni avalab anba $1.',
 'copyrightpagename'    => '{{SITENAME}} dwa rezève',
 'copyrightpage'        => '{{ns:project}}:Dwa rezève',
@@ -262,9 +345,7 @@ $messages = array(
 
 'badaccess'        => 'Pèmisyon erè',
 'badaccess-group0' => 'Ou pa genyen pèmisyon pou ou ekzekite demand sa.',
-'badaccess-group1' => 'Aksyon ou esete reyalize-a limite sèlman pou itilizatè ki nan group $1.',
-'badaccess-group2' => 'Aksion ke w vle reyalize a limite sèlman pou itilizatè ki nan group sa yo $1.',
-'badaccess-groups' => 'Aksion ke w vle reyalize a limite sèlman pou itilizatè ki nan group sa yo $1.',
+'badaccess-groups' => 'Aksyon ke w vle reyalize a limite sèlman pou itilizatè ki nan {{PLURAL:$2|gwoup sa |yonn nan gwoup sa yo}}: $1.',
 
 'versionrequired'     => 'Vèzion $1 de MediaWiki nesesè',
 'versionrequiredtext' => 'Vèzion $1 de MediaWiki nesesè pou itilize paj sa. Wè [[Special:Version|version page]].',
@@ -278,6 +359,8 @@ $messages = array(
 'editsection'             => 'modifye',
 'editold'                 => 'modifye',
 'viewsourceold'           => 'Wè kòd paj an',
+'editlink'                => 'modifye',
+'viewsourcelink'          => 'wè kòd tèks sa',
 'editsectionhint'         => 'Modifye seksyon : $1',
 'toc'                     => 'Kontni yo',
 'showtoc'                 => 'montre',
@@ -360,7 +443,6 @@ Souple, kontakte yon [[Special:ListUsers/sysop|administratè]], ba l adrès sa,
 'cannotdelete'         => 'Nou pa kapab efase paj oubyen fichye ou bay an. (Yon lòt moun gen dwa fè l anvan ou.)',
 'badtitle'             => 'Tit ou bay an pa bon, li pa koresponn nan sistèm an, eseye byen ekri li',
 'badtitletext'         => 'Tit, sijè paj ou mande a pa korèk oubyen li pa egziste oubyen li nan yon lòt pwojè wiki yo (gade nan lòt pwojè wiki yo pou wè toutbon). Li mèt genyen tou kèk karaktè ki pa rekonèt nan sistèm an, eseye itilize bon karaktè yo nan tit ou yo.',
-'perfdisabled'         => 'Eskize nou ! Fonksyon sa a dezaktive pou moman sa paske l ap ralanti ekzekisyon bazdone an; pyès moun pa tap kapab itilize wiki a.',
 'perfcached'           => 'Sa se yon vèsyon sòti nan sistèm kach ou an.Li gen dwa pa a jou.',
 'perfcachedts'         => 'Done sa yo nan sistèm cach an, yo gen dwa pa fèk fèt. Dènye fwa nou mete l a jou sete $1.',
 'querypage-no-updates' => 'Nou pa kapab mete paj sa yo a jou paske fonksyon l dezaktive. Done ou ap twouve pli ba pa fèk mete.',
@@ -404,7 +486,6 @@ Kont ou an kreye. Pa bliye pèsonalize l nan  [[Special:Preferences|preferans ou
 'remembermypassword'         => 'Anrejistre mopas mwen an nan òdinatè mwen an',
 'yourdomainname'             => 'Domèn ou an',
 'externaldberror'            => 'Li sanble ke yon erè pwodui ak bazdone a pou idantifikasyon ki pa nan sistèm an, oubyen ou pa otorize pou mete a jou kont ou genyen nan lòt sistèm yo.',
-'loginproblem'               => '<b>Pwoblèm idantifikasyon nan sistèm an.</b><br />Tanpri, eseye ankò !',
 'login'                      => 'Idantifikasyon',
 'nav-login-createaccount'    => 'Kreye yon kont oubyen konekte ou',
 'loginprompt'                => 'Ou dwèt aksepte (aktive) koukiz (cookies) yopou ou kapab [[Special:UserLogin|konekte nan {{SITENAME}}]].',
@@ -461,8 +542,8 @@ Si se pa ou menm ki mande modifye mopas ou an oubyen si ou konnen mopas ou an e
 Anvan yon lòt imèl voye, swiv komand ki nan mesaj imèl an epi konfime ke kont an se byen kont ou an.',
 'throttled-mailpassword'     => 'Yon imèl ki genyen anndan l mopas ou an pou rapèl voye pandan {{PLURAL:$1|dènye lè a|dènye $1 zè sa yo}}. Pou anpeche pwofitè ak kèk move itilizasyon, yon sèl imèl ap voye nan {{PLURAL:$1|è sa|entèval $1 zè sa yo}}.',
 'mailerror'                  => 'Erè ki vini lè nap voye imèl an : $1',
-'acct_creation_throttle_hit' => 'Eskize nou, ou ja kreye {{PLURAL:$1|$1 kont|$1 kont}}. Ou pa kapab kreye dòt ankò.',
-'emailauthenticated'         => 'Adrès imèl ou an otantifye nan sistèm nou an depi $1.',
+'acct_creation_throttle_hit' => 'Eskize nou, ou te deja kreye {{PLURAL:$1|1 kont|$1 kont}}. Ou pa kapab kreye dòt ankò.',
+'emailauthenticated'         => 'Adrès imèl ou an idantifye nan sistèm nou an depi $2 nan $3.',
 'emailnotauthenticated'      => '<strong>Nou pa kapab idantifye</strong> adrès imèl ou an. Pyès mesaj imèl ke voyen pou chak fonksyon sa yo.',
 'noemailprefs'               => 'Ou pa bay pyès adrès imèl nan mesaj preferans ou an, fonksyon sa yo pe ke disponib.',
 'emailconfirmlink'           => 'Konfime adrès imèl ou an',
@@ -473,17 +554,23 @@ Anvan yon lòt imèl voye, swiv komand ki nan mesaj imèl an epi konfime ke kont
 'createaccount-text'         => 'Yon moun kreye yon kont pou adrès imèl ou an sou paj sa {{SITENAME}} ($4), non l se « $2 », mopas an se « $3 ». Ou ta dwèt ouvè yon sesyon pou chanje, kounye a mopas sa.
 
 Pa pòte atansyon pou mesaj sa si kont sa kreye pa erè.',
+'login-throttled'            => 'Ou fè twòp tantativ pou konekte w ak mopas ou an. Souple, atann yon ti moman anvan ou eseye ankò.',
 'loginlanguagelabel'         => 'Lang : $1',
 
 # Password reset dialog
-'resetpass'               => 'Efase mopas ou an pou konfigire yon lòt',
-'resetpass_announce'      => 'Ou anrejistre ou ak yon mopas ki valab yon moman; mopas sa te voye pa imèl. Pou ou kapab fini anrejistreman sa, ou dwèt mete yon nouvo mopas kote sit :',
-'resetpass_header'        => 'Mopas ou an reyinisyalize',
-'resetpass_submit'        => 'Chanje mopas epitou anrejistre',
-'resetpass_success'       => 'Nou chanje mopas ou an ak siksè ! Nap anrejistre ou kounye a...',
-'resetpass_bad_temporary' => 'Mopas tanporè sa pa bon ditou. Li sanble ou deja chanje mopas ou an oubyen ou mande yon lòt mopas tanporè.',
-'resetpass_forbidden'     => 'Nou pa kapab chanje mopas yo nan sistèm sa',
-'resetpass_missing'       => 'Ou pa bay pyès done',
+'resetpass'                 => 'Efase mopas ou an pou konfigire yon lòt oubyen chanje l',
+'resetpass_announce'        => 'Ou anrejistre ou ak yon mopas ki valab yon moman; mopas sa te voye pa imèl. Pou ou kapab fini anrejistreman sa, ou dwèt mete yon nouvo mopas kote sit :',
+'resetpass_header'          => 'Mopas ou an reyinisyalize',
+'retypenew'                 => 'Konfime nouvo mopas an :',
+'resetpass_submit'          => 'Chanje mopas epitou anrejistre',
+'resetpass_success'         => 'Nou chanje mopas ou an ak siksè ! Nap anrejistre ou kounye a...',
+'resetpass_bad_temporary'   => 'Mopas tanporè sa pa bon ditou. Li sanble ou deja chanje mopas ou an oubyen ou mande yon lòt mopas tanporè.',
+'resetpass_forbidden'       => 'Nou pa kapab chanje mopas yo nan sistèm sa',
+'resetpass-no-info'         => 'Ou dwèt konekte pou ou kapab vini nan paj sa.',
+'resetpass-submit-loggedin' => 'Modifye mopas sa',
+'resetpass-wrong-oldpass'   => 'Mopas sa pa bon ditou;i te mèt mopas ou an kounye a oubyen yonn ki pa ap dire lontan.
+Ou dwèt te deja modifye l oubyen mande yon nouvo mopas ki tap pèmèt ou chanje l.',
+'resetpass-temp-password'   => 'Mopas yo ba ou an (li pap rete lontan):',
 
 # Edit page toolbar
 'bold_sample'     => 'Tèks fonse',
@@ -506,8 +593,8 @@ Pa pòte atansyon pou mesaj sa si kont sa kreye pa erè.',
 'hr_tip'          => 'Liy orizontal (pa abize)',
 
 # Edit pages
-'summary'                          => 'Somè&nbsp;',
-'subject'                          => 'Sijè/tit',
+'summary'                          => 'Somè&nbsp;:',
+'subject'                          => 'Sijè/tit:',
 'minoredit'                        => 'Modifikasyon sa a pa enpòtan',
 'watchthis'                        => 'Swiv paj sa a',
 'savearticle'                      => 'Anrejistre',
@@ -521,8 +608,8 @@ Si ou klike sou \"Pibliye\", piblikasyon sa ke ap fèt san pyès avètisman.",
 'missingcommenttext'               => 'Souple, ekri komantè ou an pli ba nan paj sa.',
 'missingcommentheader'             => "'''Pòte atansyon :''' ou pa bay komantè ou an yon sijè/tit .
 Si ou klike sou \"Pibliye\", edisyon ou an pap genyen yon tit.",
-'summary-preview'                  => 'Kout zye nan rezime an anvan li anrejistre',
-'subject-preview'                  => 'Yon kout zye sou sijè/tit atik kontni sa',
+'summary-preview'                  => 'Kout zye nan rezime an anvan li anrejistre:',
+'subject-preview'                  => 'Yon kout zye sou sijè/tit atik kontni sa:',
 'blockedtitle'                     => 'itilizatè a bloke.',
 'blockedtext'                      => "<big>'''Kont itilizatè ou an (oubyen adrès IP ou an) bloke.'''</big>
 
@@ -620,6 +707,7 @@ Sèl itilizatè yo ki genyen estati administratè kapab modifye l.'''",
 'recreate-deleted-warn'            => "'''Atansyon : ou ap kreye yon pak ki te efase deja.'''
 
 Mande ou byen si ou ap byen fè kreye li ankò toutbon (gade jounal paj sa a pou konnene poukisa efasman yo te fèt anba) :s :",
+'deletelog-fulllog'                => 'Wè istorik, jounal konplè pou paj sa',
 
 # Parser/template warnings
 'post-expand-template-inclusion-category' => 'Paj yo ki genyen twop modèl anndan yo',
@@ -628,26 +716,26 @@ Mande ou byen si ou ap byen fè kreye li ankò toutbon (gade jounal paj sa a pou
 'cantcreateaccounttitle' => 'Ou pa kapab kreye yon kont.',
 
 # History pages
-'viewpagelogs'        => 'gade jounal paj sa a',
-'nohistory'           => 'Istorik pou paj sa pa egziste ditou.',
-'revnotfound'         => 'Vèsyon nou pa kapab twouve ditou',
-'currentrev'          => 'Vèsyon kounye a',
-'revisionasof'        => 'Vèsyon jou $1',
-'revision-info'       => 'Vèsyon pou $1 pa $2',
-'previousrevision'    => '← Vèsyon presedan',
-'nextrevision'        => 'Vèsyon swivan →',
-'currentrevisionlink' => 'Vèsyon kounye a',
-'cur'                 => 'kounye a',
-'next'                => 'pli douvan',
-'last'                => 'dènye',
-'page_first'          => 'premye',
-'page_last'           => 'dènye',
-'histlegend'          => 'Lejand : ({{MediaWiki:Cur}}) = diferans ak vèsyon kounye a, ({{MediaWiki:Last}}) = diferans ak vèsyon anvan, <b>m</b> = modifikasyon ki pa enpòtan',
-'deletedrev'          => '[efase]',
-'histfirst'           => 'Premye kontribisyon yo',
-'histlast'            => 'Dènye kontribisyon yo',
-'historysize'         => '({{PLURAL:$1|$1 okte|$1 okte yo}})',
-'historyempty'        => '(vid, pa gen anyen)',
+'viewpagelogs'           => 'gade jounal paj sa a',
+'nohistory'              => 'Istorik pou paj sa pa egziste ditou.',
+'currentrev'             => 'Vèsyon kounye a',
+'revisionasof'           => 'Vèsyon jou $1',
+'revision-info'          => 'Vèsyon pou $1 pa $2', # Additionally available: $3: revision id
+'previousrevision'       => '← Vèsyon presedan',
+'nextrevision'           => 'Vèsyon swivan →',
+'currentrevisionlink'    => 'Vèsyon kounye a',
+'cur'                    => 'kounye a',
+'next'                   => 'pli douvan',
+'last'                   => 'dènye',
+'page_first'             => 'premye',
+'page_last'              => 'dènye',
+'histlegend'             => 'Lejand : ({{MediaWiki:Cur}}) = diferans ak vèsyon kounye a, ({{MediaWiki:Last}}) = diferans ak vèsyon anvan, <b>m</b> = modifikasyon ki pa enpòtan',
+'history-fieldset-title' => 'Navige nan istorik paj sa',
+'deletedrev'             => '[efase]',
+'histfirst'              => 'Premye kontribisyon yo',
+'histlast'               => 'Dènye kontribisyon yo',
+'historysize'            => '({{PLURAL:$1|$1 okte|$1 okte yo}})',
+'historyempty'           => '(vid, pa gen anyen)',
 
 # Revision feed
 'history-feed-title'          => 'Istorik vèsyon yo',
@@ -693,16 +781,17 @@ Mande ou byen si ou ap byen fè kreye li ankò toutbon (gade jounal paj sa a pou
 'diff-multi'              => '({{PLURAL:$1|Yon revizyon nan mitan evolisyon ki kache|$1 revizyon yo nan mitan evolisyon ki kache}})',
 
 # Search results
-'noexactmatch' => "'''Pa genyen pyès paj ki genyen non sa a « $1 ».''' Ou mèt [[:$1|kreye atik sa a]].",
-'prevn'        => '$1 anvan yo',
-'nextn'        => '$1 swivan yo',
-'viewprevnext' => 'Wè ($1) ($2) ($3).',
-'powersearch'  => 'Fouye fon',
+'noexactmatch'   => "'''Pa genyen pyès paj ki genyen non sa a « $1 ».''' Ou mèt [[:$1|kreye atik sa a]].",
+'prevn'          => '$1 anvan yo',
+'nextn'          => '$1 swivan yo',
+'viewprevnext'   => 'Wè ($1) ($2) ($3).',
+'searchhelp-url' => 'Help:Èd',
+'powersearch'    => 'Fouye fon',
 
 # Preferences page
 'preferences'   => 'Preferans yo',
 'mypreferences' => 'Preferans yo',
-'retypenew'     => 'Konfime nouvo mopas an :',
+'skin-preview'  => 'Voye kout zye',
 
 'grouppage-sysop' => '{{ns:project}}:Administratè',
 
@@ -743,10 +832,10 @@ Mande ou byen si ou ap byen fè kreye li ankò toutbon (gade jounal paj sa a pou
 'uploadlogpage' => 'Istorik chajman pou fichye miltimedya',
 'uploadedimage' => 'chaje « [[$1]] »',
 
-# Special:ImageList
-'imagelist' => 'Lis fichye yo',
+# Special:ListFiles
+'listfiles' => 'Lis fichye yo',
 
-# Image description page
+# File description page
 'filehist'                  => 'Istorik fichye a',
 'filehist-help'             => 'Klike anlè yon dat epi yon lè pou fichye a jan li te ye nan moman sa a.',
 'filehist-current'          => 'Kounye a',
@@ -848,45 +937,55 @@ Mande ou byen si ou ap byen fè kreye li ankò toutbon (gade jounal paj sa a pou
 'special-categories-sort-count' => 'klase pa valè',
 'special-categories-sort-abc'   => 'klase alfabetikalman',
 
+# Special:Log/newusers
+'newuserlogpage'              => 'Istorik pou kreyasyon kont itilizatè yo',
+'newuserlogpagetext'          => 'Men jounal, istorik kreyasyon kont itilizatè yo.',
+'newuserlog-byemail'          => 'mopas an voye pa imèl',
+'newuserlog-create-entry'     => 'Nouvo itilizatè',
+'newuserlog-create2-entry'    => 'kont kreye pou $1',
+'newuserlog-autocreate-entry' => 'Kont sa kreye otomatikman',
+
 # E-mail user
 'emailuser' => 'Voye yon mesaj (imèl) pou itilizatè sa a',
 
 # Watchlist
-'watchlist'            => 'Lis swivi',
-'mywatchlist'          => 'Lis swivi',
-'watchlistfor'         => "(pou itilizatè '''$1''')",
-'addedwatch'           => 'Ajoute nan lis swivi',
-'addedwatchtext'       => 'Paj « <nowiki>$1</nowiki> » an byen ajoute nan [[Special:Watchlist|lis swivi ou an]].
+'watchlist'         => 'Lis swivi',
+'mywatchlist'       => 'Lis swivi',
+'watchlistfor'      => "(pou itilizatè '''$1''')",
+'addedwatch'        => 'Ajoute nan lis swivi',
+'addedwatchtext'    => 'Paj « <nowiki>$1</nowiki> » an byen ajoute nan [[Special:Watchlist|lis swivi ou an]].
 Pwochen modifikasyon nan paj sa a ke make na lis swivi ou an, paj an ke parèt <b>fonse </b> nan [[Special:RecentChanges|chanjman ki fèk fèt]] pou ou kapab wè yo pli fasilman.',
-'removedwatch'         => 'Retire nan lis swivi',
-'removedwatchtext'     => 'Paj "[[:$1]]" byen retire nan [[Special:Watchlist|lis swivi ou an]].',
-'watch'                => 'Swiv',
-'watchthispage'        => 'Swiv paj sa a',
-'unwatch'              => 'Pa swiv ankò',
-'watchlist-details'    => 'Ou ap swiv {{PLURAL:$1|paj|paj}}, san konte paj diskisyon yo.',
-'wlshowlast'           => 'Montre dènye $1 zè yo, dènye $2 jou yo, oubyen $3.',
-'watchlist-hide-bots'  => 'Kache kontribisyon wobo yo (Bòt)',
-'watchlist-hide-own'   => 'kache modifikasyon mwen yo',
-'watchlist-hide-minor' => 'Kache modifikasyon ki pa enpòtan yo',
+'removedwatch'      => 'Retire nan lis swivi',
+'removedwatchtext'  => 'Paj "[[:$1]]" byen retire nan [[Special:Watchlist|lis swivi ou an]].',
+'watch'             => 'Swiv',
+'watchthispage'     => 'Swiv paj sa a',
+'unwatch'           => 'Pa swiv ankò',
+'watchlist-details' => 'Ou ap swiv {{PLURAL:$1|paj|paj}}, san konte paj diskisyon yo.',
+'wlshowlast'        => 'Montre dènye $1 zè yo, dènye $2 jou yo, oubyen $3.',
 
 # Displayed when you click the "watch" button and it is in the process of watching
 'watching'   => 'Swiv...',
 'unwatching' => 'Fini swiv paj sa a...',
 
-# Delete/protect/revert
-'deletepage'                  => 'Efase yon paj',
-'historywarning'              => 'Atansyon, paj ou ap efase an genyen yon istorik :',
-'confirmdeletetext'           => 'Ou ap efase pou tout bon nan bazdone a yon paj oubyen yon imaj epi tout vèsyon li yo. Souple, konfime aksyon enpòtan sa a, ke ou konprann sa ou ap fè, nan dwa ak [[{{MediaWiki:Policy-url}}|lwa medyawiki a]].',
-'actioncomplete'              => 'Aksyon an fèt',
-'deletedtext'                 => '« <nowiki>$1</nowiki> » efase.
+# Delete
+'deletepage'            => 'Efase yon paj',
+'historywarning'        => 'Atansyon, paj ou ap efase an genyen yon istorik :',
+'confirmdeletetext'     => 'Ou ap efase pou tout bon nan bazdone a yon paj oubyen yon imaj epi tout vèsyon li yo. Souple, konfime aksyon enpòtan sa a, ke ou konprann sa ou ap fè, nan dwa ak [[{{MediaWiki:Policy-url}}|lwa medyawiki a]].',
+'actioncomplete'        => 'Aksyon an fèt',
+'deletedtext'           => '« <nowiki>$1</nowiki> » efase.
 Gade $2 pou wè yon lis efasman resan.',
-'deletedarticle'              => 'efase « [[$1]] »',
-'dellogpage'                  => 'Istorik efasman yo',
-'deletecomment'               => 'Rezon pou kilès la ou efase :',
-'deleteotherreason'           => 'Rezon an plis :',
-'deletereasonotherlist'       => 'Lòt rezon',
-'rollbacklink'                => 'anlve',
+'deletedarticle'        => 'efase « [[$1]] »',
+'dellogpage'            => 'Istorik efasman yo',
+'deletecomment'         => 'Rezon pou kilès la ou efase :',
+'deleteotherreason'     => 'Rezon an plis :',
+'deletereasonotherlist' => 'Lòt rezon',
+
+# Rollback
+'rollbacklink' => 'anlve',
+
+# Protect
 'protectlogpage'              => 'Istorik pwoteksyon yo',
+'prot_1movedto2'              => '[[$1]] renonmen, li kounye a [[$2]]',
 'protect-legend'              => 'Konfime pwoteksyon an',
 'protectcomment'              => 'Poukisa ou pwoteje li:',
 'protectexpiry'               => 'Ekspirasyon(Paj an pe ke ekspire si ou pa mete anyen)',
@@ -905,6 +1004,7 @@ Men reglaj pou paj '''$1''' an kounye a:",
 'protect-expiring'            => 'ap ekspire $1',
 'protect-cascade'             => 'Pwoteksyon enbrike - ap pwoteje tout paj ki andidan paj sa a.',
 'protect-cantedit'            => 'Ou pa kapab modifye nivo pwoteksyon paj sa a paske ou pa gen dwa pou edite li.',
+'protect-expiry-options'      => '2 zè:2 hours,1 jou:1 day,3 jou:3 days,1 semèn:1 week,2 semèn:2 weeks,1 mwa:1 month,3 mwa:3 months,6 mwa:6 months,1 lane:1 year,ki pap janm fini:infinite', # display1:time1,display2:time2,...
 'restriction-type'            => 'Pèmisyon:',
 'restriction-level'           => 'Nivo kontrent, restriksyon:',
 
@@ -933,7 +1033,6 @@ Men reglaj pou paj '''$1''' an kounye a:",
 # What links here
 'whatlinkshere'       => 'Paj ki lye nan paj sa a',
 'whatlinkshere-title' => 'Paj ki genyen lyen ki ap mennen nan "$1"',
-'linklistsub'         => '(Lis lyen yo)',
 'linkshere'           => 'Paj yo ki anba ap mene nan <b>[[:$1]]</b> :',
 'nolinkshere'         => 'Pyès paj genyen lyen pou paj sa a <b>[[:$1]]</b>.',
 'isredirect'          => 'Paj redireksyon',
@@ -1051,7 +1150,7 @@ Nan pozisyon sa a, ou ke dwèt renonmen oubyen fizyone ou menm menm paj an si ou
 'show-big-image'       => 'Imaj pli gwo, pli fin',
 'show-big-image-thumb' => '<small>Lajè kout zye sa a : $1 × $2 piksèl</small>',
 
-# Special:NewImages
+# Special:NewFiles
 'newimages' => 'Galri pou nouvo fichye yo',
 
 # Bad image list
