@@ -1,8 +1,10 @@
 <?php
 /** Maori (Māori)
  *
- * @addtogroup Language
+ * @ingroup Language
+ * @file
  *
+ * @author Kiharoa
  */
 
 $messages = array(
@@ -46,12 +48,15 @@ $messages = array(
 'toolbox'          => 'Pouaka utauta',
 
 # All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
-'currentevents'     => 'Kōrero',
-'currentevents-url' => 'Project:Kōrero',
-'mainpage'          => 'Hau Kāinga',
-'portal'            => 'Tomokanga hapori',
-'portal-url'        => 'Project:Tomokanga hapori',
-'sitesupport'       => 'Koha',
+'aboutsite'            => 'Mo {{SITENAME}}',
+'currentevents'        => 'Kōrero',
+'currentevents-url'    => 'Project:Kōrero',
+'mainpage'             => 'Hau Kāinga',
+'mainpage-description' => 'Hau Kāinga',
+'portal'               => 'Tomokanga hapori',
+'portal-url'           => 'Project:Tomokanga hapori',
+'privacy'              => 'Tikanga tūmataiti',
+'privacypage'          => 'Project:Tikanga tūmataiti',
 
 'toc'     => 'Rārangi kōrero',
 'showtoc' => 'whakakite',
@@ -88,11 +93,10 @@ $messages = array(
 'randompage' => 'Tipihaere',
 
 # Miscellaneous special pages
-'allpages'     => 'Ngā whārangi katoa',
-'specialpages' => 'Whārangi motuhake',
-'move'         => 'Nekehia',
+'move' => 'Nekehia',
 
-# Special:Allpages
+# Special:AllPages
+'allpages'       => 'Ngā whārangi katoa',
 'allpagessubmit' => 'Haere',
 
 # Watchlist
@@ -111,4 +115,7 @@ $messages = array(
 # Namespace 8 related
 'allmessages' => 'Pānui pūnaha',
 
+# Special:SpecialPages
+'specialpages' => 'Whārangi motuhake',
+
 );
