@@ -10,14 +10,6 @@
 
 $fallback = 'ru';
 
-$skinNames = array(
-	'standard' => 'Стандартон',
-	'nostalgia' => 'Æнкъард',
-	'cologneblue' => 'Кёльны æрхæндæг',
-	'monobook' => 'Моно-чиныг',
-	'myskin' => 'Мæхи',
-	'chick' => 'Карк'
-);
 $namespaceNames = array(
 	NS_MEDIA            => 'Media', //чтоб не писать "Мультимедия"
 	NS_SPECIAL          => 'Сæрмагонд',
@@ -27,8 +19,8 @@ $namespaceNames = array(
 	NS_USER_TALK        => 'Архайæджы_дискусси',
 	# NS_PROJECT set by $wgMetaNamespace
 	NS_PROJECT_TALK     => 'Дискусси_$1',
-	NS_IMAGE            => 'Ныв',
-	NS_IMAGE_TALK       => 'Нывы_тыххæй_дискусси',
+	NS_FILE             => 'Ныв',
+	NS_FILE_TALK        => 'Нывы_тыххæй_дискусси',
 	NS_MEDIAWIKI        => 'MediaWiki',
 	NS_MEDIAWIKI_TALK   => 'Дискусси_MediaWiki',
 	NS_TEMPLATE         => 'Шаблон',
@@ -45,6 +37,7 @@ $fallback8bitEncoding =  'windows-1251';
 $messages = array(
 # User preference toggles
 'tog-underline'               => 'Æрвитæнты бын хахх',
+'tog-justify'                 => 'Æмвæз абзацтæ',
 'tog-hideminor'               => 'Чысыл ивддзинæдтæ фæстаг ивддзинæдты номхыгъды мауал æвдис',
 'tog-numberheadings'          => 'Сæргæндты автоматикон нумераци',
 'tog-editondblclick'          => 'Фæрстæ дыкъæппæй ив (JavaScript)',
@@ -129,6 +122,7 @@ $messages = array(
 'category-empty'                => "''Ацы категори афтид ма у.''",
 'hidden-categories'             => 'Æмбæхст {{PLURAL:$1|категори|категоритæ}}',
 'hidden-category-category'      => 'Æмбæхст категоритæ', # Name of the category where hidden categories will be listed
+'category-subcat-count'         => '{{PLURAL:$2|Ацы категорийы мидæг æрмæст иу дæлкатегори и.|{{PLURAL:$1|$1 дæлкатегори æвдыст у|$1 дæлкатегорийы æвдыст сты}}, æдæппæт $2.}}',
 'category-subcat-count-limited' => 'Ацы категорийы мидæг ис {{PLURAL:$1|$1 дæлкатегори|$1 дæлкатегорийы}}.',
 'category-file-count-limited'   => 'Ацы категорийы {{PLURAL:$1|$1 файл|$1 файлы}} ис.',
 'listingcontinuesabbrev'        => '(дарддæрдзу)',
@@ -137,8 +131,10 @@ $messages = array(
 'article'        => 'Статья',
 'newwindow'      => '(ног рудзынджы)',
 'qbfind'         => 'Агур',
+'qbbrowse'       => 'Фен',
 'qbedit'         => 'Баив æй',
 'qbpageoptions'  => 'Ацы фарс',
+'qbpageinfo'     => 'Фарсы контекст',
 'qbmyoptions'    => 'Мæ фæрстæ',
 'qbspecialpages' => 'Сæрмагонд фæрстæ',
 'moredotdotdot'  => 'Фылдæр…',
@@ -146,9 +142,10 @@ $messages = array(
 'mytalk'         => 'Дæумæ цы дзурынц',
 'anontalk'       => 'Ацы IP-адрисы дискусси',
 'navigation'     => 'хъæугæ æрвитæнтæ',
-'and'            => 'æмæ',
+'and'            => '&#32;æмæ',
 
 'errorpagetitle'    => 'Рæдыд',
+'returnto'          => '$1 фарсмæ раздæх.',
 'tagline'           => 'Сæрибар энциклопеди Википедийы æрмæг.',
 'help'              => 'Æххуыс',
 'search'            => 'агур',
@@ -157,11 +154,14 @@ $messages = array(
 'searcharticle'     => 'Статьямæ',
 'history'           => 'Фарсы истори',
 'history_short'     => 'Истори',
+'info_short'        => 'Информаци',
 'printableversion'  => 'Мыхурмæ верси',
 'permalink'         => 'Ацы версимæ æрвитæн',
 'print'             => 'Мыхуыр',
 'edit'              => 'Баив æй',
+'create'            => 'Скæн æй',
 'editthispage'      => 'Ацы фарс баив',
+'create-this-page'  => 'Ацы фарс скæн',
 'delete'            => 'Аппар',
 'deletethispage'    => 'Аппар æй',
 'protect'           => 'Сæхгæн',
@@ -191,11 +191,12 @@ $messages = array(
 'redirectpagesub'   => 'Рарвитыны фарс',
 'lastmodifiedat'    => 'Ацы фарс фæстаг хатт ивд æрцыд: $1, $2.', # $1 date, $2 time
 'protectedpage'     => 'Æхгæд фарс',
+'jumptonavigation'  => 'навигаци',
 
 # All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
 'aboutsite'            => '{{grammar:genitive|{{SITENAME}}}} тыххæй',
 'aboutpage'            => 'Project:Афыст',
-'bugreports'           => 'Рæдыдыл хъуысынгæнинаг',
+'copyrightpage'        => '{{ns:project}}:Авторы бартæ',
 'currentevents'        => 'Ног хабæрттæ',
 'currentevents-url'    => 'Project:Xabar',
 'mainpage'             => 'Сæйраг фарс',
@@ -208,17 +209,24 @@ $messages = array(
 
 'ok'                  => 'Афтæ уæд!',
 'pagetitle'           => '$1 — {{SITENAME}}',
+'retrievedfrom'       => 'Ратæдзæн: «$1»',
 'youhavenewmessages'  => 'Райстай $1 ($2).',
 'newmessageslink'     => 'ног фыстæгтæ',
 'newmessagesdifflink' => 'фæстаг ивддзинад',
 'editsection'         => 'баив æй',
 'editold'             => 'баив æй',
 'viewsourceold'       => 'йæ код фен',
+'editlink'            => 'баив æй',
+'viewsourcelink'      => 'йæ код фен',
 'editsectionhint'     => 'Баив æй: $1',
 'toc'                 => 'Сæргæндтæ',
 'showtoc'             => 'равдис',
 'hidetoc'             => 'бамбæхс',
 'viewdeleted'         => '$1 фенын дæ фæнды?',
+'site-rss-feed'       => '$1 — RSS-уадздзаг',
+'site-atom-feed'      => '$1 — Atom-уадздзаг',
+'page-rss-feed'       => '«$1» — RSS-уадздзаг',
+'page-atom-feed'      => '«$1» — Atom-уадздзаг',
 'red-link-title'      => '$1 (фыст нæма у)',
 
 # Short words for each namespace, by default used in the namespace tab in monobook
@@ -271,7 +279,7 @@ $messages = array(
 'nav-login-createaccount' => 'Системæйæн дæхи бавдис',
 'userlogin'               => 'Системæйæн дæхи бавдис',
 'logout'                  => 'Номсусæг суын',
-'userlogout'              => 'Номсусæг суын',
+'userlogout'              => 'Номсусæг су',
 'notloggedin'             => 'Системæйæн дæхи нæ бацамыдтай',
 'createaccountmail'       => 'адрисмæ гæсгæ',
 'badretype'               => 'Дыууæ хатты иу пароль хъуамæ ныффыстаис',
@@ -284,6 +292,7 @@ $messages = array(
 'badsiglength'            => 'Æгæр даргъ къухæрфыст, хъуамæ $1 дамгъæйæ къаддæр уа.',
 'email'                   => 'Эл. посты адрис',
 'loginsuccess'            => 'Ныр та Википедийы архайыс $1, зæгъгæ, ахæм номæй.',
+'nouserspecified'         => 'Дæхи бацамонын хъæуы: дæ архайæджы ном цы у.',
 'wrongpasswordempty'      => 'Пароль афтид уыд. Афтæ нæ баззы, ныффыс-ма исты пароль.',
 'mailmypassword'          => 'Рарвит мæм ног пароль',
 'noemail'                 => 'Архайæг $1 йæ электрон посты адрис нæ ныууагъта.',
@@ -291,7 +300,9 @@ $messages = array(
 'loginlanguagelabel'      => 'Æвзаг: $1',
 
 # Password reset dialog
-'resetpass_text' => '<!-- Бахæсс дæ текст ам -->',
+'resetpass_text'          => '<!-- Бахæсс дæ текст ам -->',
+'newpassword'             => 'Новый пароль',
+'resetpass-temp-password' => 'Рæстæгмæ пароль:',
 
 # Edit page toolbar
 'bold_sample'     => 'Ацы текст бæзджын суыдзæн',
@@ -306,8 +317,8 @@ $messages = array(
 'math_tip'        => 'Математикон формулæ (формат LaTeX)',
 
 # Edit pages
-'summary'            => 'Ивддзинæдты мидис',
-'subject'            => 'Темæ/сæргонд',
+'summary'            => 'Ивддзинæдты мидис:',
+'subject'            => 'Темæ/сæргонд:',
 'minoredit'          => 'Ай чысыл ивддзинад у.',
 'watchthis'          => 'Ацы фарсмæ дæ цæст æрдар',
 'savearticle'        => 'Афтæ уæд!',
@@ -315,13 +326,16 @@ $messages = array(
 'showdiff'           => 'Цы баивтай ацы тексты, уый фен',
 'blockednoreason'    => 'аххос амынд не ’рцыд',
 'newarticle'         => '(Ног)',
-'note'               => '<strong>Бафиппай:</strong>',
+'note'               => "'''Бафиппай:'''",
+'editing'            => 'Ивыс: $1',
+'editingsection'     => 'Ивыс $1 (фарсы хай)',
 'editconflict'       => 'Ивыны конфликт: $1',
-'longpagewarning'    => '<strong>РАГФÆДЗАХСТ: Ацы фарсы бæрцуат у $1 килобайты.
+'longpagewarning'    => "'''РАГФÆДЗАХСТ: Ацы фарсы бæрцуат у $1 килобайты.
 Сæ бæрцуат 32 килобайтæй фылдæр кæмæн у, ахæм фæрстæ иуæй-иу браузерты раст нæ зынынц.
-Кæд ахæм вариант и, уæд ацы фарсæй цалдæр фарсы скæн.</strong>',
+Кæд ахæм вариант и, уæд ацы фарсæй цалдæр фарсы скæн.'''",
 'templatesused'      => 'Ацы фарсы шаблонтæ:',
 'template-protected' => '(æхгæд)',
+'edit-conflict'      => 'Иввдзинæдты конфликт.',
 
 # History pages
 'currentrev'          => 'Нырыккон верси',
@@ -331,6 +345,8 @@ $messages = array(
 'page_first'          => 'фыццаг',
 'page_last'           => 'фæстаг',
 'histlegend'          => 'Куыд æй æмбарын: (нырыккон) = нырыккон версийæ хъауджыдæрдзинад, (раздæры) = раздæры версийæ хъауджыдæрдзинад, Ч = чысыл ивддзинад.',
+'histfirst'           => 'раздæр',
+'histlast'            => 'фæстæдæр',
 'historyempty'        => '(афтид)',
 
 # Revision feed
@@ -347,38 +363,75 @@ $messages = array(
 'lineno' => 'Рæнхъ $1:',
 
 # Search results
-'searchresults'      => 'Цы ссардæуы',
-'titlematches'       => 'Статьяты сæргæндты æмцаутæ',
-'textmatches'        => 'Статьяты æмцаутæ',
-'prevn'              => '$1 фæстæмæ',
-'nextn'              => '$1 размæ',
-'searchall'          => 'æппæт',
-'powersearch'        => 'Сæрмагонд агуырд',
-'powersearch-legend' => 'Сæрмагонд агуырд',
+'searchresults'            => 'Цы ссардæуы',
+'titlematches'             => 'Статьяты сæргæндты æмцаутæ',
+'textmatches'              => 'Статьяты æмцаутæ',
+'prevn'                    => '$1 фæстæмæ',
+'nextn'                    => '$1 размæ',
+'viewprevnext'             => 'Фен ($1) ($2) ($3)',
+'search-section'           => '(хай $1)',
+'search-interwiki-caption' => 'Æфсымæрон проекттæ',
+'searchall'                => 'æппæт',
+'powersearch'              => 'Сæрмагонд агуырд',
+'powersearch-legend'       => 'Сæрмагонд агуырд',
 
 # Preferences page
 'mypreferences'           => 'Æрмадз',
 'prefsnologin'            => 'Системæйæн дæхи нæ бацамыдтай',
+'qbsettings'              => 'Навигацион таг',
 'qbsettings-none'         => 'Ма равдис',
 'qbsettings-fixedleft'    => 'Галиуырдыгæй',
 'qbsettings-fixedright'   => 'Рахизырдыгæй',
 'qbsettings-floatingleft' => 'Рахизырдыгæй ленккæнгæ',
-'newpassword'             => 'Новый пароль',
+'skin-preview'            => 'Разæркаст',
 'rows'                    => 'Рæнхътæ:',
 'timezonelegend'          => 'Сахаты таг',
 'localtime'               => 'Бынатон рæстæг',
 'timezoneoffset'          => 'Хъауджыдæрдзинад',
 
 # Groups
-'group-all' => '(æппæт)',
+'group'            => 'Къорд:',
+'group-user'       => 'Архайджытæ',
+'group-bot'        => 'Роботтæ',
+'group-sysop'      => 'Админтæ',
+'group-bureaucrat' => 'Бюрократтæ',
+'group-all'        => '(æппæт)',
+
+'group-user-member'       => 'архайæг',
+'group-bot-member'        => 'робот',
+'group-sysop-member'      => 'админ',
+'group-bureaucrat-member' => 'бюрократ',
+
+'grouppage-user'       => '{{ns:project}}:Архайджытæ',
+'grouppage-bot'        => '{{ns:project}}:Роботтæ',
+'grouppage-sysop'      => '{{ns:project}}:Админтæ',
+'grouppage-bureaucrat' => '{{ns:project}}:Бюрократтæ',
+
+# Rights
+'right-read'          => 'фæрстæ кæсын',
+'right-edit'          => 'фæрстæ ивын',
+'right-move'          => 'фæрсты нæмттæ ивын',
+'right-move-subpages' => 'фæрсты æмæ сæ дæлфæрсты нæмттæ ивын',
+'right-movefile'      => 'файлты нæмттæ ивын',
+'right-upload'        => 'файлтæ сæвæрын',
+'right-upload_by_url' => 'интернет-адрисæй файлтæ сæвæрын',
+'right-delete'        => 'фæрстæ аппарын',
+'right-bigdelete'     => 'фæрстæ æмæ сæ ивды истори аппарын',
 
 # User rights log
 'rightsnone' => '(нæй)',
 
+# Associated actions - in the sentence "You do not have permission to X"
+'action-read'     => 'ацы фарс кæсын',
+'action-edit'     => 'ацы фарс ивын',
+'action-move'     => 'ацы фарсы ном ивын',
+'action-movefile' => 'ацы файлы ном ивын',
+'action-delete'   => 'ацы фарс аппарын',
+
 # Recent changes
 'recentchanges'     => 'Фæстаг ивддзинæдтæ',
 'recentchangestext' => 'Ацы фарсыл ирон Википедийы фæстаг ивддзинæдтæ фенæн ис.',
-'rcnote'            => 'Дæлдæр нымад сты афæстаг <strong>$2</strong> боны дæргъы конд <strong>{{PLURAL:$1|ивддзинад|$1 ивддзинады}}</strong>, $3 уавæрмæ гæсгæ.',
+'rcnote'            => 'Дæлдæр нымад сты афæстаг <strong>$2</strong> боны дæргъы конд <strong>{{PLURAL:$1|иу ивддзинад|$1 ивддзинады}}</strong>, $5, $4 уавæрмæ гæсгæ.',
 'rcshowhideminor'   => '$1 чысыл ивддзинæдтæ',
 'rclinks'           => 'Фæстаг $1 ивддзинæдтæ (афæстаг $2 боны дæргъы чи ’рцыдысты) равдис;
 $3',
@@ -388,66 +441,90 @@ $3',
 'show'              => 'Равдис',
 'minoreditletter'   => 'ч',
 'newpageletter'     => 'Н',
+'boteditletter'     => 'б',
 
 # Recent changes linked
 'recentchangeslinked' => 'Баст ивддзинæдтæ',
 
 # Upload
-'upload'          => 'Ног файл сæвæр',
-'uploadbtn'       => 'Ног файл сæвæр',
-'uploadnologin'   => 'Системæйæн дæхи нæ бацамыдтай',
-'filename'        => 'Файлы ном',
-'savefile'        => 'Бавæр æй',
-'uploadvirus'     => 'Файлы разынд вирус! Кæс $1',
-'watchthisupload' => 'Ацы файлмæ дæ цæст æрдар',
+'upload'           => 'Ног файл сæвæр',
+'uploadbtn'        => 'Ног файл сæвæр',
+'uploadnologin'    => 'Системæйæн дæхи нæ бацамыдтай',
+'uploaderror'      => 'Файл сæвæрыны рæдыд',
+'filename'         => 'Файлы ном',
+'minlength1'       => 'Файлы номы хъуамæ æппынкъаддæр иу дамгъæ уа.',
+'fileexists-thumb' => "<center>'''Ис ахæм файл'''</center>",
+'successfulupload' => 'Файлы сæвæрд фæрæстмæ',
+'savefile'         => 'Бавæр æй',
+'uploadvirus'      => 'Файлы разынд вирус! Кæс $1',
+'watchthisupload'  => 'Ацы файлмæ дæ цæст æрдар',
 
-# Special:ImageList
-'imagelist' => 'Нывты номхыгъд',
+'upload-file-error' => 'Мидæг рæдыд',
 
-# Image description page
-'filehist'          => 'Файлы истори',
-'filehist-current'  => 'нырыккон',
-'filehist-datetime' => 'Датæ/рæстæг',
-'filehist-user'     => 'Архайæг',
-'filehist-filesize' => 'Файлы бæрцуат',
-'filehist-comment'  => 'Фиппаинаг',
-'imagelinks'        => 'Æрвитæнтæ',
-'linkstoimage'      => 'Ацы нывæй пайда {{PLURAL:$1|кæны иу фарс|кæнынц ахæм фæрстæ}}:',
+# Special:ListFiles
+'listfiles' => 'Нывты номхыгъд',
+
+# File description page
+'filehist'                  => 'Файлы истори',
+'filehist-current'          => 'нырыккон',
+'filehist-datetime'         => 'Датæ/рæстæг',
+'filehist-user'             => 'Архайæг',
+'filehist-filesize'         => 'Файлы бæрцуат',
+'filehist-comment'          => 'Фиппаинаг',
+'imagelinks'                => 'Æрвитæнтæ файлмæ',
+'linkstoimage'              => 'Ацы нывæй пайда {{PLURAL:$1|кæны иу фарс|кæнынц ахæм фæрстæ}}:',
+'shareduploadwiki-linktext' => 'файлы сфысты фарсы',
 
 # File deletion
 'filedelete-submit'           => 'Аппар',
 'filedelete-otherreason'      => 'Æндæр кæнæ уæлæмхасæн аххос:',
 'filedelete-reason-otherlist' => 'Æндæр аххос',
 
+# MIME search
+'download' => 'æрбавгæн',
+
+# Unused templates
+'unusedtemplates' => 'Пайда кæмæй нæ чындæуы, ахæм шаблонтæ',
+
 # Random page
 'randompage' => 'Æнæбары æвзæрст фарс',
 
 # Statistics
-'userstats'     => 'Архайджыты статистикæ',
-'userstatstext' => "Регистрацигонд {{PLURAL:$1|æрцыд '''иу архайæг'''|æрцыдысты $1 [[Special:ListUsers|архайæджы]]}}, уыдонæй '''$2''' (ома сæ '''$4%''') {{PLURAL:$2|у|сты}} $5.",
+'statistics-header-users' => 'Архайджыты статистикæ',
 
 'brokenredirects-edit'   => '(баив æй)',
 'brokenredirects-delete' => '(аппар)',
 
 'withoutinterwiki-submit' => 'Равдис',
 
+'fewestrevisions' => 'Къаддæр кæй ивынц, ахæм фæрстæ',
+
 # Miscellaneous special pages
-'nbytes'            => '$1 {{PLURAL:$1|байт|байты}}',
-'nlinks'            => '$1 {{PLURAL:$1|æрвитæн|æрвитæны}}',
-'nviews'            => '$1 {{PLURAL:$1|æркаст|æркасты}}',
-'lonelypages'       => 'Сидзæр фæрстæ',
-'wantedcategories'  => 'Хъæугæ категоритæ',
-'wantedpages'       => 'Хъæугæ фæрстæ',
-'shortpages'        => 'Цыбыр фæрстæ',
-'longpages'         => 'Даргъ фæрстæ',
-'protectedpages'    => 'Æхгæд фæрстæ',
-'listusers'         => 'Архайджыты номхыгъд',
-'newpages'          => 'Ног фæрстæ',
-'newpages-username' => 'Архайæг:',
-'ancientpages'      => 'Зæронддæр фæрстæ',
-'move'              => 'Ном баив',
+'nbytes'                 => '$1 {{PLURAL:$1|байт|байты}}',
+'nlinks'                 => '$1 {{PLURAL:$1|æрвитæн|æрвитæны}}',
+'nviews'                 => '$1 {{PLURAL:$1|æркаст|æркасты}}',
+'lonelypages'            => 'Сидзæр фæрстæ',
+'uncategorizedpages'     => 'Æнæкатегори фæрстæ',
+'uncategorizedimages'    => 'Æнæкатегори файлтæ',
+'uncategorizedtemplates' => 'Æнæкатегори шаблонтæ',
+'wantedcategories'       => 'Хъæугæ категоритæ',
+'wantedpages'            => 'Хъæугæ фæрстæ',
+'mostlinked'             => 'Фылдæр æрвитæнтæ кæмæ и, ахæм фæрстæ',
+'mostlinkedcategories'   => 'Фылдæр æрвитæнтæ кæмæ и, уыцы категоритæ',
+'mostrevisions'          => 'Фылдæр кæй ивынц, ахæм фæрстæ',
+'shortpages'             => 'Цыбыр фæрстæ',
+'longpages'              => 'Даргъ фæрстæ',
+'protectedpages'         => 'Æхгæд фæрстæ',
+'listusers'              => 'Архайджыты номхыгъд',
+'newpages'               => 'Ног фæрстæ',
+'newpages-username'      => 'Архайæг:',
+'ancientpages'           => 'Зæронддæр фæрстæ',
+'move'                   => 'Ном баив',
+'pager-newer-n'          => '{{PLURAL:$1|фæстæдæр иу|фæстæдæр $1}}',
+'pager-older-n'          => '{{PLURAL:$1|раздæр иу|раздæр $1}}',
 
 # Special:Log
+'specialloguserlabel'  => 'Архайæг:',
 'speciallogtitlelabel' => 'Сæргонд:',
 
 # Special:AllPages
@@ -463,44 +540,59 @@ $3',
 'special-categories-sort-count' => 'нымæцмæ гæсгæ равæр',
 'special-categories-sort-abc'   => 'алфавитмæ гæсгæ равæр',
 
+# Special:LinkSearch
+'linksearch-ok' => 'Агур',
+
 # Special:ListUsers
 'listusers-submit' => 'Равдис',
 
+# Special:ListGroupRights
+'listgrouprights-group' => 'Къорд',
+
 # E-mail user
 'mailnologintext' => 'Фыстæгтæ æрвитынмæ хъуамæ [[Special:UserLogin|системæйæн дæхи бавдисай]] æмæ дæ бæлвырд электронон посты адрис [[Special:Preferences|ныффыссай]].',
 'emailpage'       => 'Электронон фыстæг йæм барвит',
 
 # Watchlist
-'watchlist'            => 'Цæстдарды номхыгъд',
-'mywatchlist'          => 'Дæ цæст кæмæ дарыс, уыцы фæрстæ',
-'nowatchlist'          => 'Иу статьямæ дæр дæ цæст нæ дарыс.',
-'watchnologin'         => 'Системæйæн дæхи нæ бацамыдтай',
-'watchnologintext'     => 'Ацы номхыгъд ивынмæ [[Special:UserLogin|хъуамæ дæхи бацамонай системæйæн]].',
-'addedwatch'           => 'Дæ цæст кæмæ дарыс, уыцы статьятæм бафтыд.',
-'watch'                => 'Дæ цæст æрдар',
-'watchthispage'        => 'Ацы фарсмæ дæ цæст æрдар',
-'unwatch'              => 'Мауал дæ цæст дар',
-'watchlist-details'    => '$1 фарсмæ дæ цæст дарыс, дискусситы фæстæмæ.',
-'watchlistcontains'    => 'Дæ цæст $1 фарсмæ дарыс.',
-'wlnote'               => "Дæлæ афæстаг '''$2 сахаты дæргъы''' цы $1 {{PLURAL:$1|ивддзинад|ивддзинады}} æрцыди.",
-'wlshowlast'           => 'Фæстæг $1 сахаты, $2 боны дæргъы; $3.',
-'watchlist-show-bots'  => 'Роботты куыст равдис',
-'watchlist-hide-bots'  => 'Роботты куыст бамбæхс',
-'watchlist-show-own'   => 'Мæхæдæг цы ивддзинæдтæ скодтон, уыдон равдис',
-'watchlist-hide-own'   => 'Мæхæдæг цы ивддзинæдтæ скодтон, уыдон бамбæхс',
-'watchlist-show-minor' => 'Чысыл ивддзинæдтæ равдис',
-'watchlist-hide-minor' => 'Чысыл ивддзинæдтæ бамбæхс',
+'watchlist'         => 'Цæстдарды номхыгъд',
+'mywatchlist'       => 'Дæ цæст кæмæ дарыс, уыцы фæрстæ',
+'nowatchlist'       => 'Иу статьямæ дæр дæ цæст нæ дарыс.',
+'watchnologin'      => 'Системæйæн дæхи нæ бацамыдтай',
+'watchnologintext'  => 'Ацы номхыгъд ивынмæ [[Special:UserLogin|хъуамæ дæхи бацамонай системæйæн]].',
+'addedwatch'        => 'Дæ цæст кæмæ дарыс, уыцы статьятæм бафтыд.',
+'removedwatch'      => 'Нал дарыс дæ цæст',
+'removedwatchtext'  => 'Фарсмæ «[[:$1]]» нал дарыс дæ цæст.',
+'watch'             => 'Дæ цæст æрдар',
+'watchthispage'     => 'Ацы фарсмæ дæ цæст æрдар',
+'unwatch'           => 'Мауал дæ цæст дар',
+'watchlist-details' => '$1 фарсмæ дæ цæст дарыс, дискусситы фæстæмæ.',
+'watchlistcontains' => 'Дæ цæст $1 фарсмæ дарыс.',
+'wlnote'            => "Дæлæ афæстаг '''$2 сахаты дæргъы''' цы $1 {{PLURAL:$1|ивддзинад|ивддзинады}} æрцыди.",
+'wlshowlast'        => 'Фæстæг $1 сахаты, $2 боны дæргъы; $3.',
 
-# Delete/protect/revert
+# Displayed when you click the "watch" button and it is in the process of watching
+'watching'   => 'Цæстдард фæрсты номхыгъдмæ афтауын...',
+'unwatching' => 'Цæстдард фæрсты номхыгъдæй аиуварс кæнын...',
+
+# Delete
 'exblank'               => 'фарс афтид уыдис',
 'deleteotherreason'     => 'Æндæр кæнæ уæлæмхасæн аххос:',
 'deletereasonotherlist' => 'Æндæр аххос',
-'restriction-type'      => 'Бартæ:',
+
+# Protect
+'protectcomment'         => 'Сæхкæнынæн аххос:',
+'protectexpiry'          => 'Кæдмæ æхгæд у:',
+'protect-othertime'      => 'Æндæр рæстæг:',
+'protect-othertime-op'   => 'æндæр рæстæг',
+'protect-otherreason'    => 'Æндæр аххос/уæлæмхасæн:',
+'protect-otherreason-op' => 'æндæр кæнæ уæлæмхасæн аххос',
+'restriction-type'       => 'Бартæ:',
 
 # Restrictions (nouns)
 'restriction-edit' => 'Ивын',
 
 # Namespace form on various pages
+'namespace'      => 'Нæмтты тыгъдад:',
 'blanknamespace' => '(Сæйраг)',
 
 # Contributions
@@ -513,22 +605,28 @@ $3',
 # What links here
 'whatlinkshere'           => 'Цавæр æрвитæнтæ цæуынц ардæм',
 'whatlinkshere-page'      => 'Фарс:',
-'linklistsub'             => '(Æрвитæнты номхыгъд)',
+'whatlinkshere-next'      => '{{PLURAL:$1|фæдылдзог|фæдылдзог $1}}',
 'whatlinkshere-links'     => '← æрвитæнтæ',
 'whatlinkshere-hidelinks' => '$1 æрвитæнтæ',
 'whatlinkshere-filters'   => 'Фильтртæ',
 
 # Block/unblock
-'ipbreason'          => 'Аххос',
-'ipbreasonotherlist' => 'Æндæр аххос',
-'ipb-blocklist'      => 'Актуалон хъоды равдис',
-'ipblocklist-legend' => 'Хъодыгонд архайæджы ацагур',
-'ipblocklist-empty'  => 'Хъодыгæндты номхыгъд афтид у.',
-'contribslink'       => 'бавæрд',
-'blocklogpage'       => 'Хъодыты лог',
+'blockip'                => 'Бахъоды кæн',
+'blockip-legend'         => 'Бахъоды æй кæн',
+'ipbreason'              => 'Аххос',
+'ipbreasonotherlist'     => 'Æндæр аххос',
+'ipbotherreason'         => 'Æндæр кæнæ уæлæмхасæн аххос:',
+'ipb-blocklist'          => 'Актуалон хъоды равдис',
+'ipb-blocklist-contribs' => '$1, зæгъгæ, уыцы архайæджы бавæрд',
+'ipblocklist-legend'     => 'Хъодыгонд архайæджы ацагур',
+'ipblocklist-empty'      => 'Хъодыгæндты номхыгъд афтид у.',
+'blocklink'              => 'бахъоды кæн',
+'contribslink'           => 'бавæрд',
+'blocklogpage'           => 'Хъодыты лог',
 
 # Move page
 'movearticle' => 'Статьяйы ном баив',
+'movenologin' => 'Системæйæн дæхи нæ бацамыдтай',
 'newtitle'    => 'Ног ном',
 'move-watch'  => 'Ацы фарсмæ дæ цæст æрдар',
 'movereason'  => 'Аххос:',
@@ -540,15 +638,28 @@ $3',
 'importnotext' => 'Афтид у кæнæ текст дзы нæй',
 
 # Tooltip help for the actions
-'tooltip-pt-mycontris'    => 'Мæ бавæрд',
-'tooltip-ca-protect'      => 'Ацы фарс ивддзинæдтæй сæхгæн',
-'tooltip-ca-delete'       => 'Аппар ацы фарс',
-'tooltip-ca-watch'        => 'Дæ цæст кæмæ дарыс, уыцы фæрсты номхыгъдмæ бафтау',
-'tooltip-n-mainpage'      => 'Сæйраг фарсмæ рацу',
-'tooltip-t-whatlinkshere' => 'Ацы фарсмæ чи ’рвитынц, ахæм фæрсты номхыгъд',
-'tooltip-t-upload'        => 'Нывтæ кæнæ мультимедиа-файлтæ бавæр',
-'tooltip-t-specialpages'  => 'Сæрмагонд фæрсты номхыгъд',
-'tooltip-ca-nstab-image'  => 'Нывы фарс',
+'tooltip-pt-userpage'      => 'Мæхи фарс (дæу тыххæй ам ныффысс)',
+'tooltip-pt-mytalk'        => 'Æндæр ахрхайджытæ мын цы дзурынц',
+'tooltip-pt-preferences'   => 'Википеди куыд кусы, уый срæвдз кæн дæ хъæуындзинæдтæм гæсгæ',
+'tooltip-pt-mycontris'     => 'Цы у мæ бавæрд',
+'tooltip-pt-login'         => 'Системæмæ дæхи бацамонай, кæд æцæг дæ хæс нæу, уæддæр',
+'tooltip-pt-logout'        => 'Регистрацигонд сеансæй рацу',
+'tooltip-ca-edit'          => 'Ацы фарс дæ бон у ивын. Дæ хорзæхæй, «Фен уал æй» джыбыйæ пайда кæн',
+'tooltip-ca-protect'       => 'Ацы фарс ивддзинæдтæй сæхгæн',
+'tooltip-ca-delete'        => 'Аппар ацы фарс',
+'tooltip-ca-watch'         => 'Дæ цæст кæмæ дарыс, уыцы фæрсты номхыгъдмæ бафтау',
+'tooltip-n-mainpage'       => 'Сæйраг фарсмæ рацу',
+'tooltip-n-portal'         => 'Проекты тыххæй æмæ, дæу цы бон у, уый тыххæй дæр',
+'tooltip-n-recentchanges'  => 'Чи æмæ цавæр статьяты баивта',
+'tooltip-n-randompage'     => 'Æнæбары æвзæрст фарс фен',
+'tooltip-n-help'           => 'Кæд цыдæртæ нæ бамбæрстай',
+'tooltip-t-whatlinkshere'  => 'Ацы фарсмæ чи ’рвитынц, ахæм фæрсты номхыгъд',
+'tooltip-t-upload'         => 'Нывтæ кæнæ мультимедиа-файлтæ бавæр',
+'tooltip-t-specialpages'   => 'Сæрмагонд фæрсты номхыгъд',
+'tooltip-t-permalink'      => 'Фарсы ацы версимæ æрвитæн (фæрстæ ивынц, ацы верси — никуы)',
+'tooltip-ca-nstab-user'    => 'Архайæджы фарс фен',
+'tooltip-ca-nstab-project' => 'Проекты фарс',
+'tooltip-ca-nstab-image'   => 'Нывы фарс',
 
 # Attribution
 'others' => 'æндæртæ',
@@ -556,14 +667,30 @@ $3',
 # Spam protection
 'spamprotectiontitle' => 'Спамы ныхмæ фильтр',
 
-# Media information
-'widthheightpage' => '$1 × $2, $3 фарсы',
+# Skin names
+'skinname-standard'    => 'Стандартон',
+'skinname-nostalgia'   => 'Æнкъард',
+'skinname-cologneblue' => 'Кёльны æрхæндæг',
+'skinname-monobook'    => 'Моно-чиныг',
+'skinname-myskin'      => 'Мæхи',
+'skinname-chick'       => 'Карк',
 
-# Special:NewImages
+# Browsing diffs
+'previousdiff' => '← Раздæры ивддзинад',
+'nextdiff'     => 'Фæстæдæр ивддзинад →',
+
+# Media information
+'widthheightpage' => '$1 × $2, $3 {{PLURAL:$3|фарс|фарсы}}',
+
+# Special:NewFiles
 'newimages' => 'Ног нывты галерей',
 'ilsubmit'  => 'Агур',
 'bydate'    => 'рæстæгмæ гæсгæ',
 
+# Metadata
+'metadata'        => 'Метабæрæггæнæнтæ',
+'metadata-expand' => 'Фылдæр детальтæ равдис',
+
 # EXIF tags
 'exif-artist' => 'Чи йæ систа',
 
