@@ -1,10 +1,10 @@
 <?php
 /** Pangasinan (Pangasinan)
  *
- * @addtogroup Language
+ * @ingroup Language
+ * @file
  *
  * @author Arikasikis
- * @author SPQRobin
  */
 
 $messages = array(
@@ -14,7 +14,7 @@ $messages = array(
 'underline-always' => 'Naynay',
 'underline-never'  => 'Andin-balot',
 
-# Bits of text used by many pages
+# Categories related messages
 'category_header' => 'Saray artikulo ed category ya "$1"',
 
 'about'          => 'Nipakar ed',
@@ -25,7 +25,7 @@ $messages = array(
 'mypage'         => 'Say bolong ko',
 'mytalk'         => 'Say tongtongan ko',
 'anontalk'       => 'Tongtongan para ed sayan IP',
-'and'            => 'san',
+'and'            => '&#32;san',
 
 'returnto'          => 'Impawel ed $1.',
 'help'              => 'Tolong',
@@ -60,16 +60,16 @@ $messages = array(
 'jumptosearch'      => 'anapen',
 
 # All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
-'aboutsite'         => 'Nipakar ed {{SITENAME}}',
-'aboutpage'         => 'Project:Nipaakar',
-'currentevents'     => 'Saray nagagawa natan',
-'currentevents-url' => 'Project:Saray nagagawa natan',
-'edithelp'          => 'Tolong nipakar ed panagbalo na artikulo',
-'helppage'          => 'Help:Saray Laman',
-'mainpage'          => 'Arapan ya Bolong',
-'portal'            => 'Pwerta na komyunidad',
-'portal-url'        => 'Project:Pwerta na Komyunidad',
-'sitesupport'       => 'Donasyon',
+'aboutsite'            => 'Nipakar ed {{SITENAME}}',
+'aboutpage'            => 'Project:Nipaakar',
+'currentevents'        => 'Saray nagagawa natan',
+'currentevents-url'    => 'Project:Saray nagagawa natan',
+'edithelp'             => 'Tolong nipakar ed panagbalo na artikulo',
+'helppage'             => 'Help:Saray Laman',
+'mainpage'             => 'Arapan ya Bolong',
+'mainpage-description' => 'Arapan ya Bolong',
+'portal'               => 'Pwerta na komyunidad',
+'portal-url'           => 'Project:Pwerta na Komyunidad',
 
 'badaccess-group0' => 'Agmo sarag ya gaween so action ya kekerewen mo.',
 
@@ -106,6 +106,9 @@ $messages = array(
 'accountcreated'             => 'Agawa so account',
 'accountcreatedtext'         => 'Agawa la so user account para $1.',
 
+# Password reset dialog
+'newpassword' => 'Balon password:',
+
 # Edit page toolbar
 'link_tip' => 'Gawing ed loob',
 
@@ -121,7 +124,6 @@ $messages = array(
 'blockededitsource'     => "Wadyad leksab so text na '''saray binalom''' anggag '''$1''':",
 'whitelistedittitle'    => 'Nakaukulan ya onloob umpian makapanbalo',
 'whitelistedittext'     => 'Nakaukulan mo ya $1 umpian nabalo o nadagdagan ray bolobolong.',
-'whitelistreadtext'     => 'Nakaukulan mon [[Special:Userlogin|onloob]] umpian basaen ramay bolong.',
 'confirmedittitle'      => 'Nakaukulan na e-mail confirmation para makapan-edit',
 'loginreqtitle'         => 'Nakaukulan kan Onloob',
 'loginreqlink'          => 'onloob',
@@ -136,7 +138,6 @@ $messages = array(
 'cantcreateaccounttitle' => 'Aga makagawa na account',
 
 # History pages
-'loadhist'  => 'Ilulugan so awaran na bolong',
 'last'      => 'sampot',
 'histfirst' => 'Sankaunaan',
 'histlast'  => 'Sankautetan',
@@ -147,6 +148,7 @@ $messages = array(
 # Search results
 'searchsubtitle'        => "'''[[:$1]]''' so inanap mo.",
 'searchsubtitleinvalid' => "'''$1''' so inanap mo.",
+'searchhelp-url'        => 'Help:Saray Laman',
 'powersearch'           => 'Anapen',
 
 # Preferences page
@@ -158,7 +160,6 @@ $messages = array(
 'math_unknown_error' => 'aga-antan error',
 'prefs-rc'           => 'Sampot ran binalo',
 'prefs-watchlist'    => 'Listaan na babantayan',
-'newpassword'        => 'Balon password:',
 'textboxsize'        => 'Babaloen',
 'searchresultshead'  => 'Anapen',
 
@@ -176,18 +177,18 @@ $messages = array(
 # Upload
 'upload'          => 'Mangisigep na file',
 'uploadlog'       => 'Isigep so log',
-'filesource'      => 'Pinanlapuan',
+'filesource'      => 'Pinanlapuan:',
 'uploadedfiles'   => 'Insegep ran file',
 'badfilename'     => 'Binalo so ngaran na file, umpian "$1" so balon ngaran to.',
-'sourcefilename'  => 'Filename na pinanlapuan',
+'sourcefilename'  => 'Filename na pinanlapuan:',
 'watchthisupload' => 'Bantayan yan bolong',
 
-# Image list
-'getimagelist'     => 'aaleen so listaan na file',
-'ilsubmit'         => 'Anapen',
+# Special:ListFiles
+'listfiles_name' => 'Ngaran',
+
+# File description page
 'imagelinks'       => 'Saray Gawing',
 'noimage-linktext' => 'I-segep ya',
-'imagelist_name'   => 'Ngaran',
 
 # MIME search
 'download' => 'mangileksab (download)',
@@ -199,15 +200,13 @@ $messages = array(
 'randompage'         => 'Random ya bolong',
 'randompage-nopages' => 'Anggapoy bolong ya wadya ed ayan namespace.',
 
-'withoutinterwiki'        => 'Saray bolobolong ya anggapoy gawing ya language',
-'withoutinterwiki-header' => 'Anggapoy gawin paulad version na arum ran salita so ontombok ran bolobolong:',
+'withoutinterwiki'         => 'Saray bolobolong ya anggapoy gawing ya language',
+'withoutinterwiki-summary' => 'Anggapoy gawin paulad version na arum ran salita so ontombok ran bolobolong:',
 
 # Miscellaneous special pages
-'allpages'       => 'Amin ya bolobolong',
 'shortpages'     => 'Antikey ran bolong',
 'longpages'      => 'Andokoy ran bolong',
 'protectedpages' => 'Iyayagel ran bolobolong',
-'specialpages'   => 'Niduma ran bolobolong',
 'newpages'       => 'Balo ran bolong',
 'ancientpages'   => 'Sankadaanan ran bolobolong',
 'move'           => 'Iyales',
@@ -218,13 +217,12 @@ $messages = array(
 'booksources-search-legend' => 'Mananap na saray libron pinanlapuan',
 'booksources-go'            => 'Ula',
 
-'alphaindexline' => '$1 anggad $2',
-
 # Special:Log
-'all-logs-page'     => 'Amin ran log',
-'log-search-submit' => 'Ula',
+'all-logs-page' => 'Amin ran log',
 
-# Special:Allpages
+# Special:AllPages
+'allpages'          => 'Amin ya bolobolong',
+'alphaindexline'    => '$1 anggad $2',
 'nextpage'          => 'Ontombok ya page ($1)',
 'allpagesfrom'      => 'Ipanengneng ray bolobolong ya manlapod:',
 'allarticles'       => 'Amin ran bolobolong',
@@ -235,6 +233,14 @@ $messages = array(
 'allpagessubmit'    => 'Ula',
 'allpagesprefix'    => 'Ipanengneng so saray bolobolong ya walay prefix:',
 
+# Special:LinkSearch
+'linksearch'     => 'Anapen ramay gawing ed web',
+'linksearch-pat' => 'Anapen so pattern:',
+'linksearch-ok'  => 'Anapen',
+
+# Special:Log/newusers
+'newuserlog-create-entry' => 'Balon user',
+
 # E-mail user
 'emailuser'     => 'E-mail so ayan user',
 'emailfrom'     => 'Manlapud',
@@ -248,29 +254,32 @@ $messages = array(
 'mywatchlist'    => 'Listaan na babantayan ko',
 'watchnologin'   => 'Agka ni akaloob',
 'addedwatch'     => 'Enyarom ed listaan na bantayan',
-'addedwatchtext' => "Impila so bolong ya \"[[:\$1]]\" diad [[Special:Watchlist|listaan na babantayan]] mo. Isulat diman so saray ontombok ran idagdag o panagbalo ed sayan bolong san diad bolong na tongtongan. San akasulat ran '''mapatnag''' (bolded) ed [[Special:Recentchanges|listaan na saray sampot ran binalo]] umpian mas maganom ya nanengneng.
+'addedwatchtext' => "Impila so bolong ya \"[[:\$1]]\" diad [[Special:Watchlist|listaan na babantayan]] mo. Isulat diman so saray ontombok ran idagdag o panagbalo ed sayan bolong san diad bolong na tongtongan. San akasulat ran '''mapatnag''' (bolded) ed [[Special:RecentChanges|listaan na saray sampot ran binalo]] umpian mas maganom ya nanengneng.
 
 No labay mon ekalen may bolong diad listaan na babantayan, tapik mo labat so \"ekalen ed babantayan\" (unwatch) diad gilig ya bar.",
 'watch'          => 'bantayan',
 'watchthispage'  => 'Bantayan yan bolong',
 
-# Displayed when you click the "watch" button and it's in the process of watching
+# Displayed when you click the "watch" button and it is in the process of watching
 'watching' => 'Babantayan...',
 
 'enotif_newpagetext' => 'Balo yan bolong.',
 'changed'            => 'asalatan',
 'created'            => 'agawa',
 
-# Delete/protect/revert
-'deletepage'          => 'Buralen so bolong',
-'confirm'             => 'Paletan',
-'exblank'             => 'Anggapoy laman na bolong',
-'actioncomplete'      => 'Asumpal lan agawa',
-'deletedtext'         => 'Abural lay "<nowiki>$1</nowiki>".
+# Delete
+'deletepage'     => 'Buralen so bolong',
+'confirm'        => 'Paletan',
+'exblank'        => 'Anggapoy laman na bolong',
+'actioncomplete' => 'Asumpal lan agawa',
+'deletedtext'    => 'Abural lay "<nowiki>$1</nowiki>".
 Pinengneng so $2 para ed listaan na saray abural ran balo.',
-'deletedarticle'      => 'binural so "[[$1]]"',
-'deletecomment'       => 'Aken buralen',
-'confirmprotect'      => 'Palitaen so pangiyagel',
+'deletedarticle' => 'binural so "[[$1]]"',
+'deletecomment'  => 'Aken buralen',
+
+# Protect
+'prot_1movedto2'      => 'say [[$1]] enyales paula ed [[$2]]',
+'protect-legend'      => 'Palitaen so pangiyagel',
 'protect-level-sysop' => 'Sysops labat',
 
 # Undelete
@@ -307,7 +316,7 @@ Pinengneng so $2 para ed listaan na saray abural ran balo.',
 'contribslink'       => 'saray entolong to',
 
 # Move page
-'movepage'                => 'Iyales so bolong',
+'move-page-legend'        => 'Iyales so bolong',
 'movearticle'             => 'Iyales so bolong',
 'movepagebtn'             => 'Iyales so bolong',
 'pagemovedsub'            => 'Asumpal lan inyales',
@@ -340,7 +349,6 @@ Pinengneng so $2 para ed listaan na saray abural ran balo.',
 'tooltip-ca-move'            => 'Iyales so ayan bolong',
 'tooltip-search'             => 'Anapen {{SITENAME}}',
 'tooltip-p-logo'             => 'Arapan ya Bolong',
-'tooltip-n-sitesupport'      => 'Itdan na tolong kami',
 'tooltip-t-specialpages'     => 'Listaan na amin ran niduman bolobolong',
 'tooltip-ca-nstab-user'      => 'Nengnengen so bolong na manag-usar',
 'tooltip-ca-nstab-mediawiki' => 'Nengnengen so pakabat na oksoy',
@@ -348,6 +356,9 @@ Pinengneng so $2 para ed listaan na saray abural ran balo.',
 # Attribution
 'lastmodifiedatby' => 'Sampot ya binalo yan bolong nen agew ya $2, $1 nen $3.', # $1 date, $2 time, $3 user
 
+# Special:NewFiles
+'ilsubmit' => 'Anapen',
+
 # EXIF tags
 'exif-filesource' => 'File na pinanlapuan',
 
@@ -368,18 +379,11 @@ Pinengneng so $2 para ed listaan na saray abural ran balo.',
 'deletedwhileediting' => 'Pasakbay: Abural yan bolong nen ginapuan mon baloen!',
 
 # action=purge
-'confirm_purge' => 'Ekalen so cache na sayan bolong?
-
-$1',
-
-# AJAX search
-'articletitles' => "Saray article na manggagapo ed ''$1''",
-'hideresults'   => 'Iyamot so saray result',
+'confirm-purge-top' => 'Ekalen so cache na sayan bolong?',
 
 # Multipage image navigation
 'imgmultipagenext' => 'ontombok ya bolong →',
 'imgmultigo'       => 'Ula!',
-'imgmultigotopre'  => 'Ula ed bolong',
 
 # Table pager
 'table_pager_next'         => 'Ontombok ya bolong',
@@ -398,4 +402,7 @@ $1',
 'livepreview-loading' => 'Ilulugan…',
 'livepreview-ready'   => 'Ilulugan… Akaparaan!',
 
+# Special:SpecialPages
+'specialpages' => 'Niduma ran bolobolong',
+
 );
