@@ -57,7 +57,7 @@ $messages = array(
 'mytalk'        => 'Mi diskushon',
 'anontalk'      => 'Diskushon pa e IP aki',
 'navigation'    => 'Nabegashon',
-'and'           => 'i',
+'and'           => '&#32;i',
 
 'errorpagetitle'    => 'Eror',
 'returnto'          => 'Bai bèk $1.',
@@ -186,7 +186,8 @@ Bo por kambia página libremente, pero tene kuenta ku lo nota bo IP adrès den e
 'histlast'            => 'Último',
 
 # Search results
-'nextn' => 'siguiente $1',
+'nextn'          => 'siguiente $1',
+'searchhelp-url' => 'Help:Kontenido',
 
 # Preferences page
 'preferences'    => 'Preferensianan',
@@ -210,9 +211,8 @@ Bo por kambia página libremente, pero tene kuenta ku lo nota bo IP adrès den e
 'unwatchedpages' => 'Páginanan no observá',
 
 # Statistics
-'statistics' => 'Estadístika',
-'sitestats'  => 'Estadístika di {{SITENAME}}',
-'userstats'  => 'Estadístika di uzadónan',
+'statistics'              => 'Estadístika',
+'statistics-header-users' => 'Estadístika di uzadónan',
 
 # Miscellaneous special pages
 'ncategories'             => '$1 {{PLURAL:$1|kategoria|kategorianan}}',
@@ -279,9 +279,12 @@ Si despues bo ke kita e página for di bo lista di observashon, primi \"Stop di
 'changed' => 'kambiá',
 'created' => 'trahá',
 
-# Delete/protect/revert
+# Delete
 'confirm'        => 'Konfirmá',
 'actioncomplete' => 'Akshon kompletá',
+
+# Protect
+'prot_1movedto2' => '[[$1]] mové pa [[$2]]',
 'protect-legend' => 'Konfirmá protekshon',
 
 # Undelete
@@ -375,10 +378,6 @@ E kódigo di konfirmashon aki lo kaduká riba $4.',
 : ''$2''
 Por fabor konfirmá ku bo ke traha e artíkulo aki di nobo.",
 
-# AJAX search
-'articletitles' => "Artíkulonan kuminsando ku ''$1''",
-'hideresults'   => 'Skonde resultado',
-
 # Special:SpecialPages
 'specialpages' => 'Páginanan Spesial',
 
