@@ -1,9 +1,9 @@
 <?php
 /** Sardinian (Sardu)
  *
- * @addtogroup Language
+ * @ingroup Language
+ * @file
  *
- * @author Nike
  * @author לערי ריינהארט
  */
 
@@ -15,8 +15,8 @@ $namespaceNames = array(
 	NS_USER_TALK       => 'Utente_discussioni',
 	# NS_PROJECT set by $wgMetaNamespace
 	NS_PROJECT_TALK    => '$1_discussioni',
-	NS_IMAGE           => 'Immàgini',
-	NS_IMAGE_TALK      => 'Immàgini_contièndha'
+	NS_FILE            => 'Immàgini',
+	NS_FILE_TALK       => 'Immàgini_contièndha'
 );
 
 $dateFormats = array(
@@ -115,14 +115,13 @@ $messages = array(
 'protectedpage'     => 'Pagina protetta',
 
 # All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
-'aboutsite'      => 'A proposito di {{SITENAME}}',
-'bugreports'     => 'Segnalazioni di malfunzionamento',
-'bugreportspage' => 'Project:Malfunzionamenti',
-'currentevents'  => 'Attualità',
-'edithelp'       => 'Guida per la modifica o la scrittura di un articolo',
-'edithelppage'   => 'Help:Come_scrivere_un_articolo',
-'helppage'       => 'Help:Aiuto',
-'mainpage'       => 'Pàggina principali',
+'aboutsite'            => 'A proposito di {{SITENAME}}',
+'currentevents'        => 'Attualità',
+'edithelp'             => 'Guida per la modifica o la scrittura di un articolo',
+'edithelppage'         => 'Help:Come_scrivere_un_articolo',
+'helppage'             => 'Help:Aiuto',
+'mainpage'             => 'Pàggina principali',
+'mainpage-description' => 'Pàggina principali',
 
 'retrievedfrom' => 'Ricavato da  "$1"',
 
@@ -147,9 +146,6 @@ MySQL ha restituito un errore "<tt>$3: $4</tt>".',
 'readonlytext'    => "Il database di {{SITENAME}} è al momento bloccato, e non consente nuove immissioni né modifiche, molto probabilmente per manutenzione server, nel qual caso il database sarà presto di nuovo completamente accessibile.
 L/'amministratore di sistema che ha imposto il blocco, ha lasciato questa nota:
 <p>$1",
-'missingarticle'  => 'Il database non ha trovato il testo di una pagina, che invece avrebbe dovuto trovare, intitolata "$1".
-Questo non è un errore del database, ma più probabilmente un problema del software.
-Per favore, segnalate l\'accaduto ad un administrator, segnalando la URL e l\'ora dell\'incidente.',
 'internalerror'   => 'Errore interno',
 'filecopyerror'   => 'Non è stato possibile copiare il file "$1" come "$2".',
 'filerenameerror' => 'Non è stato possibile rinominare il file "$1" in "$2".',
@@ -161,44 +157,48 @@ Per favore, segnalate l\'accaduto ad un administrator, segnalando la URL e l\'or
 'cannotdelete'    => "Impossibile cancellare la pagina o l'immagine richiesta.",
 'badtitle'        => 'Titolo non corretto',
 'badtitletext'    => 'La pagina richiesta non è disponibile, potrebbe essere non valida, vuota, o potrebbe trattarsi di un errore in un link interlinguistico o fra diverse versioni di {{SITENAME}}.',
-'perfdisabled'    => 'Siamo davvero rammaricati, ma questa funzionalità è temporaneamente disabilitata durante le ore di maggiore accesso al database per ragioni di accessibilità al resto del sito! Torna fra le 02:00 e le 14:00 UTC e riprova. Grazie.',
 
 # Login and logout pages
-'logouttitle'           => 'Logout Utente',
-'logouttext'            => 'Logout effettuato.
+'logouttitle'             => 'Logout Utente',
+'logouttext'              => 'Logout effettuato.
 Ora puoi continuare ad usare {{SITENAME}} come utente anonimo (ma il tuo indirizzo IP resterà riconoscibile), oppure puoi nuovamente richiedere il login con il precedente username, oppure come uno diverso.',
-'welcomecreation'       => '<h2>Benvenuto, $1!</h2><p>Il tuo account è stato creato con successo.<br />Grazie per aver scelto di far crescere {{SITENAME}} con il tuo aiuto.<br />Per rendere {{SITENAME}} più tua, e per usarla più scorrevolmente, non dimenticare di personalizzare le tue preferenze.',
-'loginpagetitle'        => 'Login',
-'yourname'              => 'Il tuo  user name',
-'yourpassword'          => 'La tua  password',
-'yourpasswordagain'     => 'Ripeti la password',
-'remembermypassword'    => 'Ricorda la mia password per più sessioni (richiede uso dei cookies).',
-'loginproblem'          => '<b>Si è verificato un errore durante il tuo tentativo di login.</b><br />Riprova, sarai più fortunato!',
-'userlogin'             => 'Log in',
-'createaccount'         => 'Crea nuovo account',
-'badretype'             => 'Le password che hai immesso non coincidono, sono diverse fra loro.',
-'userexists'            => 'Siamo spiacenti. Lo user name che hai scelto è già usato da un altro Utente. Ti preghiamo perciò di voler scegliere uno user name diverso.',
-'youremail'             => 'La tua e-mail',
-'yournick'              => 'Il tuo diminutivo o soprannome (per le firme)',
-'loginerror'            => 'Errore di Login',
-'noname'                => 'Lo user name indicato non è valido, non è possibile creare un account a questo nome.',
-'loginsuccesstitle'     => 'Login effettuato con successo!',
-'loginsuccess'          => 'Sei stato ammesso alla connessione al server di {{SITENAME}} con il nome utente di "$1".',
-'nosuchuser'            => 'Attenzione<br /><br />a seguito di verifica, non ci risulta alcun Utente con il nome di  "$1".<br /><br />
+'welcomecreation'         => '<h2>Benvenuto, $1!</h2><p>Il tuo account è stato creato con successo.<br />Grazie per aver scelto di far crescere {{SITENAME}} con il tuo aiuto.<br />Per rendere {{SITENAME}} più tua, e per usarla più scorrevolmente, non dimenticare di personalizzare le tue preferenze.',
+'loginpagetitle'          => 'Login',
+'yourname'                => 'Il tuo  user name',
+'yourpassword'            => 'La tua  password',
+'yourpasswordagain'       => 'Ripeti la password',
+'remembermypassword'      => 'Ricorda la mia password per più sessioni (richiede uso dei cookies).',
+'nav-login-createaccount' => 'Log in',
+'userlogin'               => 'Log in',
+'createaccount'           => 'Crea nuovo account',
+'badretype'               => 'Le password che hai immesso non coincidono, sono diverse fra loro.',
+'userexists'              => 'Siamo spiacenti. Lo user name che hai scelto è già usato da un altro Utente. Ti preghiamo perciò di voler scegliere uno user name diverso.',
+'youremail'               => 'La tua e-mail',
+'yournick'                => 'Il tuo diminutivo o soprannome (per le firme)',
+'loginerror'              => 'Errore di Login',
+'noname'                  => 'Lo user name indicato non è valido, non è possibile creare un account a questo nome.',
+'loginsuccesstitle'       => 'Login effettuato con successo!',
+'loginsuccess'            => 'Sei stato ammesso alla connessione al server di {{SITENAME}} con il nome utente di "$1".',
+'nosuchuser'              => 'Attenzione<br /><br />a seguito di verifica, non ci risulta alcun Utente con il nome di  "$1".<br /><br />
 Controlla per favore il nome digitato, oppure usa il modulo qui sotto per creare un nuovo user account.',
-'wrongpassword'         => 'La password immessa non è corretta.<br /><br />Riprova, per favore.',
-'mailmypassword'        => 'Spediscimi una nuova password in posta elettronica',
-'passwordremindertitle' => 'Servizio Password Reminder di {{SITENAME}}',
-'passwordremindertext'  => 'Qualcuno (probabilmente tu, con indirizzo IP $1)
+'wrongpassword'           => 'La password immessa non è corretta.<br /><br />Riprova, per favore.',
+'mailmypassword'          => 'Spediscimi una nuova password in posta elettronica',
+'passwordremindertitle'   => 'Servizio Password Reminder di {{SITENAME}}',
+'passwordremindertext'    => 'Qualcuno (probabilmente tu, con indirizzo IP $1)
 ha richiesto l\'invio di una nuova password per il login a {{SITENAME}}.
 La password per l\'Utente "$2" è ora "$3".
 Per evidenti ragioni di sicurezza, dovresti fare un log in il prima possibile, e cambiare la password immediatamente.',
-'noemail'               => 'Nessuna casella e-mail risulta registrata per l\'Utente "$1".',
-'passwordsent'          => 'Una nuova password è stata inviata alla casella e-mail registrata per l\'Utente "$1".
+'noemail'                 => 'Nessuna casella e-mail risulta registrata per l\'Utente "$1".',
+'passwordsent'            => 'Una nuova password è stata inviata alla casella e-mail registrata per l\'Utente "$1".
 Per favore, fai subito un log in non appena la ricevi.',
 
+# Password reset dialog
+'oldpassword' => 'Vecchia password',
+'newpassword' => 'Nuova password',
+'retypenew'   => 'Riscrivi qui la nuova password',
+
 # Edit pages
-'summary'         => 'Oggetto',
+'summary'         => 'Oggetto:',
 'minoredit'       => 'Questa è una modifica minore',
 'watchthis'       => "Tieni d'occhio questo articolo",
 'savearticle'     => 'Salva la pagina',
@@ -217,11 +217,10 @@ Se lo desideri, puoi contattare $1, o uno degli altri [[{{MediaWiki:Grouppage-sy
 'newarticletext'  => 'Scrivi qui il tuo testo.',
 'noarticletext'   => "(L'articolo è vuoto, potresti gentilmente iniziare l'articolo oppure richiedere la cancellazione di questa pagina)",
 'updated'         => '(Aggiornato)',
-'note'            => '<strong>Nota:</strong>',
-'previewnote'     => 'Tieni presente che questa è solo una ANTEPRIMA, e che la tua versione non è ancora stata salvata!',
+'note'            => "'''Nota:'''",
+'previewnote'     => "'''Tieni presente che questa è solo una ANTEPRIMA, e che la tua versione non è ancora stata salvata!'''",
 'previewconflict' => "Questa anteprima rappresenta il testo nella casella di edizione di sopra, l'articolo apparirà n questa forma se sceglierai di salvare la pagina.",
 'editing'         => 'Modifica di $1',
-'editinguser'     => 'Modifica di $1',
 'editconflict'    => 'Conflitto di edizione: $1',
 'explainconflict' => 'Qualcun altro ha salvato una sua versione dell\'articolo nel tempo in cui tu stavi preparando la tua versione.<br />
 La casella di modifica di sopra contiene il testo dell\'articolo nella sua forma attuale (cioè il testo attualmente online). Le tue modifiche sono invece contenute nella casella di modifica inferiore.
@@ -229,22 +228,18 @@ Dovrai inserire, se lo desideri, le tue modifiche nel testo esistente, e perciò
 <b>Soltanto</b> il testo nella casella di sopra sarà sakvato se premerai il bottone "Salva".<br />',
 'yourtext'        => 'Il tuo testo',
 'storedversion'   => 'Versione in archivio',
-'editingold'      => "<strong>ATTENZIONE: Stai modificando una versione dell'articolo non aggiornata.
-Se la salvi così, tutti i cambiamenti apportati dopo questa revisione verranno persi per sempre.</strong>",
+'editingold'      => "'''ATTENZIONE: Stai modificando una versione dell'articolo non aggiornata.
+Se la salvi così, tutti i cambiamenti apportati dopo questa revisione verranno persi per sempre.'''",
 'yourdiff'        => 'Differenze',
 
 # History pages
-'nohistory'       => 'Cronologia delle versioni di questa pagina non reperibile.',
-'revnotfound'     => 'Versione non trovata',
-'revnotfoundtext' => 'La versione precedente di questo articolo che hai richiesto, non è stata trovata.
-Controlla per favore la URL che hai usato per accedere a questa pagina.',
-'loadhist'        => 'Caricamento cronologia di questa pagina',
-'currentrev'      => 'Versione attuale',
-'revisionasof'    => 'Revisione $1',
-'cur'             => 'corr',
-'next'            => 'succ',
-'last'            => 'prec',
-'histlegend'      => 'Legend: (corr) = differenze con la versione corrente,
+'nohistory'    => 'Cronologia delle versioni di questa pagina non reperibile.',
+'currentrev'   => 'Versione attuale',
+'revisionasof' => 'Revisione $1',
+'cur'          => 'corr',
+'next'         => 'succ',
+'last'         => 'prec',
+'histlegend'   => 'Legend: (corr) = differenze con la versione corrente,
 (prec) = differenze con la versione precedente, M = modifica minore',
 
 # Diffs
@@ -263,18 +258,15 @@ Controlla per favore la URL che hai usato per accedere a questa pagina.',
 'prevn'                 => 'precedenti $1',
 'nextn'                 => 'successivi $1',
 'viewprevnext'          => 'Vedi ($1) ($2) ($3).',
+'searchhelp-url'        => 'Help:Aiuto',
 'showingresults'        => 'Qui di seguito <b>$1</b> risultati, partendo dal numero #<b>$2</b>.',
 'nonefound'             => '<strong>Nota</strong>: la ricerca di parole troppo comuni, come "avere" o "essere", che non sono indicizzate, può causare un esito negativo, così come indicare più di un termine da ricercare (solo le pagine che contengano tutti i termini ricercati verrebbero infatti visualizzate fra i risultati).',
 'powersearch'           => 'Ricerca',
-'powersearchtext'       => '
-Cerca fra i campi :<br />
-$1<br />
-$2 Elenca i redirects &nbsp; cerca per $3 $9',
 
 # Preferences page
 'preferences'              => 'Preferenze',
 'prefsnologin'             => 'Non hai eseguito il login',
-'prefsnologintext'         => 'Devi avere eseguito il [[Special:Userlogin|login]]
+'prefsnologintext'         => 'Devi avere eseguito il [[Special:UserLogin|login]]
 per poter personalizzare le tue preferenze.',
 'prefsreset'               => 'Le tue Preferenze sono state ripescate dalla memoria di sistema del potente server di {{SITENAME}}.',
 'qbsettings'               => 'Settaggio della barra menu',
@@ -287,9 +279,6 @@ per poter personalizzare le tue preferenze.',
 'skin'                     => 'Aspetto',
 'saveprefs'                => 'Salva preferenze',
 'resetprefs'               => 'Resetta preferenze',
-'oldpassword'              => 'Vecchia password',
-'newpassword'              => 'Nuova password',
-'retypenew'                => 'Riscrivi qui la nuova password',
 'textboxsize'              => 'Dimensione della casella di edizione',
 'rows'                     => 'Righe',
 'columns'                  => 'Colonne',
@@ -303,12 +292,15 @@ per poter personalizzare le tue preferenze.',
 'localtime'                => 'Ora Locale',
 'timezoneoffset'           => 'Offset',
 
+# User rights
+'editinguser' => "Modifica di '''[[User:$1|$1]]''' ([[User talk:$1|{{int:talkpagelinktext}}]] | [[Special:Contributions/$1|{{int:contribslink}}]])",
+
 # Recent changes
 'recentchanges'   => 'Ultime Modifiche',
 'rcnote'          => 'Qui di seguito sono elencate le ultime <strong>$1</strong> pagine modificate negli ultimi <strong>$2</strong> giorni.',
 'rcnotefrom'      => ' Qui di seguito sono elencate le modifiche da <b>$2</b> (fino a <b>$1</b>).',
 'rclistfrom'      => 'Mostra modifiche a partire da $1',
-'rclinks'         => ' Mostra le ultime $1 modifiche negli ultimi $2 giorni.',
+'rclinks'         => 'Mostra le ultime $1 modifiche negli ultimi $2 giorni.',
 'hist'            => 'cron',
 'hide'            => 'nascondi',
 'show'            => 'mostra',
@@ -321,15 +313,15 @@ per poter personalizzare le tue preferenze.',
 'reupload'          => 'Ri-upload',
 'reuploaddesc'      => 'Torna al modulo per lo upload.',
 'uploadnologin'     => 'Devi fare il login per eseguire questa operazione.',
-'uploadnologintext' => 'Devi eseguire [[Special:Userlogin|il login]]
+'uploadnologintext' => 'Devi eseguire [[Special:UserLogin|il login]]
 per fare lo upload di files.',
 'uploaderror'       => 'Errore di Upload',
 'uploadtext'        => "'''FERMA!''' Prima di effettuare un upload su {{SITENAME}}, accertati di avere ben letto e soprattutto compreso
-[[Project:Image_use_policy|le regole di {{SITENAME}} sull'uso delle immagini]].
+le regole di {{SITENAME}} sull'uso delle immagini.
 
-Per visualizzare o cercare immagini precedentemente caricate su {{SITENAME}}, vai alla [[Special:Imagelist|lista delle immagini già caricate]].
+Per visualizzare o cercare immagini precedentemente caricate su {{SITENAME}}, vai alla [[Special:FileList|lista delle immagini già caricate]].
 Uploads e cancellazioni delle immagini sono registrati nello
-[[Project:Upload_log|upload log]].
+upload log.
 
 Usa il modulo sottostante per caricare nuovi files immagine da utilizzare per arricchire ed illustrare i tuoi articoli.
 Sulla maggior parte dei browsers, dovresti vedere un bottone con la scritta \"Browse...\" (oppure \"Sfoglia...\", che aprirà una comune finestra di dialogo.
@@ -349,7 +341,7 @@ Per inserire la nuova immagine in un articolo, usa semplicemente un link nella f
 Tieni presente che, come per tutte le pagine di {{SITENAME}}, chiunque può modificare o sostituire o cancellare i tuoi files ove ritenga che ciò sia negli interessi della nostra enciclopedia. Tieni anche presente che, in caso di abuso, o di sovraccarico sul sistema, potresti essere bloccato (oltre ad essere perseguito per le connesse responsabilità).",
 'uploadlogpage'     => 'Upload_log',
 'uploadlogpagetext' => 'Qui di seguito la lista degli ultimi files caricati sul server di {{SITENAME}}.
-Tutti i tempi indicati sono calcolati sul fuso orario del server (UTC).',
+Tutti i tempi indicati sono calcolati sul fuso orario del server.',
 'filename'          => 'Nome del file',
 'filedesc'          => 'Oggetto',
 'uploadedfiles'     => 'Files Caricati in {{SITENAME}}',
@@ -359,16 +351,10 @@ Tutti i tempi indicati sono calcolati sul fuso orario del server (UTC).',
 'savefile'          => 'Salva file',
 'uploadedimage'     => 'caricato "[[$1]]"',
 
-# Image list
-'imagelist'      => 'Lista delle immagini',
-'imagelisttext'  => 'Qui di seguito una lista di $1 immagini, ordinate per $2.',
-'getimagelist'   => 'ricerca nella lista delle immagini',
-'ilsubmit'       => 'Cerca',
-'showlast'       => 'Mostra le ultime $1 immagini ordinate per $2.',
-'byname'         => 'nome',
-'bydate'         => 'data',
-'bysize'         => 'peso',
-'imgdelete'      => 'canc',
+# Special:ListFiles
+'listfiles' => 'Lista delle immagini',
+
+# File description page
 'imagelinks'     => 'Link alle immagini',
 'linkstoimage'   => 'Le pagine seguenti linkano questa immagine:',
 'nolinkstoimage' => 'Nessuna pagina linka questa immagine.',
@@ -377,16 +363,8 @@ Tutti i tempi indicati sono calcolati sul fuso orario del server (UTC).',
 'randompage' => 'Una pagina a caso',
 
 # Statistics
-'statistics'    => 'Statistiche',
-'sitestats'     => 'Statistiche del sito',
-'userstats'     => 'Statistiche del {{SITENAME}}',
-'sitestatstext' => 'Ci sono ben <b>$1</b> pagine nel database.
-Questa cifra comprende le pagine "talk" (discussione), pagine su {{SITENAME}}, articoli esigui ("stub"), redirects, e altre pagine che probabilmente non andrebbero conteggiate fra gli articoli.
-Escludendo queste, ci sono ben  <b>$2</b> pagine che sono con buona probabilità propriamente degli articoli.<p>
-Ci sono state un totale di <b>$3</b> pagine viste, e <b>$4</b> modifiche agli articoli da quando il software è stato potenziato (Dicembre, 2002).
-Questa media rivela che ci sono state una media di  <b>$5</b> modifiche per ciascun articolo, e che l\'articolo è stato letto <b>$6</b> volte per ciascuna modifica.',
-'userstatstext' => 'Ci sono <b>$1</b> Utenti registrati.
-<b>$2</b> di questi hanno il grado di amministratori (vedi $3).',
+'statistics'              => 'Statistiche',
+'statistics-header-users' => 'Statistiche del {{SITENAME}}',
 
 'disambiguationspage' => '{{ns:project}}:Links_to_disambiguating_pages',
 
@@ -405,20 +383,20 @@ Ogni riga contiene i link al primo ed al secondo redirect, oltre alla prima riga
 'unusedimages'     => 'Immagini non utilizzate',
 'popularpages'     => 'Pagine più viste',
 'wantedpages'      => 'Articoli più richiesti',
-'allpages'         => 'Tutte le pagine',
 'shortpages'       => 'Pagine corte',
 'longpages'        => 'Pagine lunghe',
 'listusers'        => 'Elenco degli Utenti',
-'specialpages'     => 'Pagine speciali',
-'spheading'        => 'Pagine speciali',
 'newpages'         => 'Pagine nuove',
 'movethispage'     => 'Sposta questa pagina',
 'unusedimagestext' => '<p>Nota che altri siti web, come la {{SITENAME}} internazionale, potrebbero aver messo un link ad una immagine per mezzo di una URL diretta, perciò le immagini potrebbero essere listate qui anche essendo magari in uso.',
 'notargettitle'    => 'Dati mancanti',
 'notargettext'     => "Non hai specificato una pagina o un Utente in relazione al quale eseguire l'operazione richiesta.",
 
+# Special:AllPages
+'allpages' => 'Tutte le pagine',
+
 # E-mail user
-'mailnologintext' => 'Devi fare il [[Special:Userlogin|login]]
+'mailnologintext' => 'Devi fare il [[Special:UserLogin|login]]
 ed aver registrato una valida casella e-mail nelle tue [[Special:Preferences|preferenze]] per mandare posta elettronica ad altri Utenti.',
 'emailuser'       => 'Manda una E-mail a questo Utente',
 'emailpagetext'   => 'Se questo Utente ha registrato una valida casella e-mail, il modulo qui sotto ti consentirà di scrivergli un solo messaggio.
@@ -434,11 +412,11 @@ oppure ha scelto di non ricevere  posta elettronica dagli altri Utenti.',
 'mywatchlist'      => 'Osservati Speciali',
 'nowatchlist'      => "Non hai indicato articoli da tenere d'occhio.",
 'watchnologin'     => 'Manca il login',
-'watchnologintext' => 'Devi prima fare il [[Special:Userlogin|login]]
+'watchnologintext' => 'Devi prima fare il [[Special:UserLogin|login]]
 per modificare la tua lista di osservati speciali.',
 'addedwatch'       => 'Aggiunto agli Osservati Speciali',
 'addedwatchtext'   => ' La pagina  "<nowiki>$1</nowiki>" è stata aggiunta alla tua [[Special:Watchlist|lista di osservati speciali]].
-Le future modifiche a questa pagina ed alla relativa pagina di discussione saranno elencate qui, e la pagina apparirà in <b>grassetto</b> nella pagina delle [[Special:Recentchanges|modifiche recenti]] per essere più facile da tener d\'occhio.
+Le future modifiche a questa pagina ed alla relativa pagina di discussione saranno elencate qui, e la pagina apparirà in <b>grassetto</b> nella pagina delle [[Special:RecentChanges|modifiche recenti]] per essere più facile da tener d\'occhio.
 
 Se in seguito vorrai togliere questo articolo dalla tua lista di osservati speciali, clicca " Smetti di seguire " nella barra dei menu.',
 'removedwatch'     => 'Rimosso dalla lista degli Osservati Speciali',
@@ -447,7 +425,7 @@ Se in seguito vorrai togliere questo articolo dalla tua lista di osservati speci
 'unwatchthispage'  => 'Smetti di seguire',
 'notanarticle'     => 'Non è un articolo',
 
-# Delete/protect/revert
+# Delete
 'deletepage'        => 'Cancella pagina',
 'confirm'           => 'Conferma',
 'confirmdeletetext' => 'Stai per cancellare permanentemente dal database una pagina o una immagine, insieme a tutta la sua cronologia.
@@ -459,12 +437,14 @@ Vedi $2 per un elenco delle pagine cancellate di recente.',
 'deletedarticle'    => 'Cancellata "$1"',
 'dellogpage'        => 'Deletion_log',
 'dellogpagetext'    => 'Qui di seguito, un elenco delle pagine cancellate di recente.
-Tutti i tempi sono in ora del server (UTC).',
+Tutti i tempi sono in ora del server.',
 'reverted'          => 'Ripristinata versione precedente',
 'deletecomment'     => 'Motivazione della cancellazione',
-'rollback'          => 'Usa una revisione precdente',
-'cantrollback'      => "Impossibile tornare ad una versione precedente: l'ultima modifica è stata apportata dall'unico utente che abbia lavorato a questo articolo.",
-'revertpage'        => 'Riportata alla revisione precedente da $1', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
+
+# Rollback
+'rollback'     => 'Usa una revisione precdente',
+'cantrollback' => "Impossibile tornare ad una versione precedente: l'ultima modifica è stata apportata dall'unico utente che abbia lavorato a questo articolo.",
+'revertpage'   => 'Riportata alla revisione precedente da [[User:$1|$1]]', # Additionally available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
 
 # Undelete
 'undelete'          => 'Recupera una pagina cancellata',
@@ -480,13 +460,10 @@ Se una nuova pagina è stata creata con questo stesso nome dopo la cancellazione
 'contributions' => 'Contributi di questo Utente',
 'contribsub2'   => 'Per $1 ($2)',
 'nocontribs'    => 'Nessuna modifica trovata conformemente a questi criteri.',
-'ucnote'        => 'Qui sotto troverai le ultime <b>$1</b> modifiche effettuate da questo Utente negli ultimi <b>$2</b> giorni.',
-'uclinks'       => 'Vedi le ultime $1 modifiche; vedi gli ultimi $2 giorni.',
 'uctop'         => ' (ultima per la pagina)',
 
 # What links here
 'whatlinkshere' => 'Pagine che linkano questa',
-'linklistsub'   => '(Lista di links)',
 'linkshere'     => 'Le seguenti pagine contengono link che puntano qui:',
 'nolinkshere'   => 'Nessuna pagina contiene links che puntano a questa.',
 'isredirect'    => 'redirect',
@@ -501,7 +478,7 @@ Scrivi un motivo specifico per il quale questo indirizzo IP dovrebbe a tuo avvis
 'badipaddress'       => "L'indirizzo IP indicato non è corretto.",
 'blockipsuccesssub'  => 'Blocco eseguito',
 'blockipsuccesstext' => ' L\'indirizzo IP "$1" è stato bloccato.
-<br />Vedi [[Special:Ipblocklist|lista IP bloccati]].',
+<br />Vedi [[Special:IPBlockList|lista IP bloccati]].',
 'unblockip'          => ' Sblocca indirizzo IP',
 'unblockiptext'      => 'Usa il modulo sottostante per restituire il diritto di scrittura ad un indirizzo IP precedentemente bloccato.',
 'ipusubmit'          => 'Sblocca questo indirizzo IP',
@@ -530,15 +507,17 @@ Per cortesia, conferma che questo è effettivamente quanto tu intendi ora effett
 'unlockdbsuccesstext' => ' Il database di {{SITENAME}} è stato sbloccato.',
 
 # Move page
-'movepage'         => 'Spostamento di pagina',
+'move-page-legend' => 'Spostamento di pagina',
 'movepagetext'     => "Con il modulo sottostante puoi rinominare una pagina, spostando anche tutta la sua cronologia al nuovo nome.
 Il vecchior titolo diverrà automaticamente un redirect che punta al nuovo titolo.
-I link alla vecchia pagina non saranno aggiornati (e punteranno quindi al redirect); accertati di [[Special:Manutenzioni|controllare con cura]] che non si creino doppi redirects o redirects interrotti.
+I link alla vecchia pagina non saranno aggiornati (e punteranno quindi al redirect);
+accertati di controllare con cura che non si creino doppi redirects o redirects interrotti.
 Resta nella tua responsabilità di accertarti che i link continuino a puntare verso dove devono dirigersi.
 
-Nota bene: la pagina '''non''' sarà spostata se vi fosse già un articolo con il nuovo nome, a meno che non sia una pagina vuota o un redirect e che non abbia cronologia. Questo significa che, se commetti un errore, puoi nuovamente rinominare una pagina col vecchio titolo, ma non puoi sovrascrivere una pagina già esistente.
+Nota bene: la pagina '''non''' sarà spostata se vi fosse già un articolo con il nuovo nome, a meno che non sia una pagina vuota o un redirect e che non abbia cronologia.
+Questo significa che, se commetti un errore, puoi nuovamente rinominare una pagina col vecchio titolo, ma non puoi sovrascrivere una pagina già esistente.
 
-<b>ATTENZIONE!</b>
+'''ATTENZIONE!'''
 Questo cambiamento drastico potrebbe creare inattesi contrattempi, specialmente se si tratta di una pagina molto visitata. Accertati di aver ben valutato le conseguenze dello spostamento, prima di procedere. Nel dubbio, contatta un Amministratore.",
 'movepagetalktext' => "La corrispondente pagina di discussione, se esiste, sarà spostata automaticamente insieme all'articolo, '''tranne che nei seguenti casi:'''
 *Spostamento della pagina fra i namespaces,
@@ -548,7 +527,7 @@ Questo cambiamento drastico potrebbe creare inattesi contrattempi, specialmente
 In questi casi, se lo ritieni opportuno, dovrai spostare o aggiungere manualmente la pagina di discussione.",
 'movearticle'      => 'Rinomina articolo',
 'movenologin'      => 'Non hai effettuato il login',
-'movenologintext'  => 'Devi essere un Utente registrato ed aver effettuato il [[Special:Userlogin|login]]
+'movenologintext'  => 'Devi essere un Utente registrato ed aver effettuato il [[Special:UserLogin|login]]
 per poter spostare una pagina.',
 'newtitle'         => 'Al nuovo titolo di',
 'movepagebtn'      => 'Sposta questa pagina',
@@ -558,7 +537,13 @@ Scegli, per cortesia, un titolo diverso per l'articolo.",
 'talkexists'       => "La pagina è stata spostata correttamente, ma la pagina di dicussione non poteva essere spostata perché ne esiste già un'altra con il nuovo titolo. Per favore, modifica manualmente i contenuti delle due pagine discussione, così da mantenerle entrambe per non perdere potenzialmente interessanti riflessioni.",
 'movedto'          => 'spostata a',
 'movetalk'         => 'Sposta anche la corrispondente pagina "discussione", se possibile.',
-'talkpagemoved'    => 'Anche la corrispondente pagina di discussione è stata spostata.',
-'talkpagenotmoved' => 'La corrispondente pagina di discussione <strong>non è stata spostata</strong>.',
+
+# Special:NewFiles
+'imagelisttext' => 'Qui di seguito una lista di $1 immagini, ordinate per $2.',
+'ilsubmit'      => 'Cerca',
+'bydate'        => 'data',
+
+# Special:SpecialPages
+'specialpages' => 'Pagine speciali',
 
 );
