@@ -56,8 +56,6 @@ $messages = array(
 'underline-never'   => 'Diixepe',
 'underline-default' => 'AutoBrowser',
 
-'skinpreview' => '(Cuáxiit)',
-
 # Dates
 'sunday'        => 'Dajmino',
 'monday'        => 'Luncino',
@@ -136,7 +134,7 @@ $messages = array(
 'mytalk'         => 'Heczaxö',
 'anontalk'       => 'Czaxöde IP',
 'navigation'     => 'Navigacion',
-'and'            => 'ö',
+'and'            => '&#32;ö',
 
 # Metadata in edit box
 'metadata_help' => 'Datade Meta:',
@@ -197,8 +195,6 @@ $messages = array(
 # All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
 'aboutsite'            => '{{SITENAME}} mii',
 'aboutpage'            => 'Project:Miilà',
-'bugreports'           => 'Iitómde bug',
-'bugreportspage'       => 'Project:Iitómde bug',
 'copyright'            => 'Contentua coitáamb $1 tan.',
 'copyrightpagename'    => 'Copyright {{SITENAME}}',
 'copyrightpage'        => '{{ns:project}}:Copyrightám',
@@ -221,8 +217,6 @@ $messages = array(
 
 'badaccess'        => 'Römjde permicion',
 'badaccess-group0' => 'Menepermicion executan accion z hecocmíiit.',
-'badaccess-group1' => 'Accion hecocmíiit coccebj diilimáat czo $1.',
-'badaccess-group2' => "Accion hecocmíiit coccebj diilimáat czo'd $1.",
 'badaccess-groups' => "Accion hecocmíiit coccebj diilimáat czo'd $1.",
 
 'versionrequired'     => 'Vercion $1 MediaWiki pal',
@@ -310,7 +304,6 @@ Sysop zo locköx zo xuniim jan rae': $1",
 'badtitle'             => 'Ahisharliit',
 'badtitletext'         => 'Zo páhina coccebj ahisharliit zo.
 Jan pos-coccebj plusöxde 1 jöx 1 characterám jan nepos-coccebj usadas titlenám iti.',
-'perfdisabled'         => 'Sorry! Jan part coccebj disablenöxde temp. Zo minöxde cáipyde database ponit zo iti nectám pos-usadad wiki zo.',
 'perfcached'           => 'Jan data coccebj cache ö necoccebj updatenom.',
 'perfcachedts'         => "Jan data coccebj cache ö coccebjöx updatenom $1 'de.",
 'querypage-no-updates' => 'Updatenámde jan páhina coccebj disablenöx cmaa. Jan data necanj cmaa.',
@@ -344,7 +337,6 @@ Mecaitom coccebj creatöx. Quiix hequáatlaácde {{SITENAME}} pos-poop.",
 'remembermypassword'         => 'Qualtiinii he quimx canj jan ordinator iti',
 'yourdomainname'             => 'Hedomino:',
 'externaldberror'            => 'Pos-römjde authenticacionde database extername jöx me necoccebj permiccionde updatan mecaitom externom.',
-'loginproblem'               => '<b>Problemam mecaápo miimisoj.</b><br />Vancaápo!',
 'login'                      => 'Caápo',
 'nav-login-createaccount'    => 'Caápo / xuatl',
 'loginprompt'                => 'Henáabliicookám caápo {{SITENAME}}.',
@@ -414,11 +406,13 @@ confirmom account zo coccebj de'me.",
 'resetpass'               => "Account quimx canj'reset",
 'resetpass_announce'      => "Me caápo code temp e-iitomöx mii. Fini caápo, me reset' hunquimx canj cmaadexepe:",
 'resetpass_header'        => "Reset'quimx canj",
+'oldpassword'             => 'Janquimx canj:',
+'newpassword'             => 'Hunquimx canj:',
+'retypenew'               => 'Vanhunquimx canj:',
 'resetpass_submit'        => 'Vanquimx canj ö caápo',
 'resetpass_success'       => 'Me quimx canj coccebj quiixde success! Caápo cmaa...',
 'resetpass_bad_temporary' => "Quimx canj temp invalidanj. Me coccebj reset' quimx canjde success jöx requestan hunquimx canj temp pac.",
 'resetpass_forbidden'     => 'Quimx cánj nereset jan wiki iti',
-'resetpass_missing'       => 'Formdata fan.',
 
 # Edit page toolbar
 'bold_sample'     => 'Text ccomca',
@@ -443,8 +437,8 @@ confirmom account zo coccebj de'me.",
 'hr_tip'          => 'I horizont (seperatman)',
 
 # Edit pages
-'summary'                   => 'Abvuatl',
-'subject'                   => 'Subject/ccanzam',
+'summary'                   => 'Abvuatl:',
+'subject'                   => 'Subject/ccanzam:',
 'minoredit'                 => 'Jan coccebj editám z bajlöxám',
 'watchthis'                 => 'Cáminot jan páhina',
 'savearticle'               => 'Xuniim páhina',
@@ -456,8 +450,8 @@ confirmom account zo coccebj de'me.",
 'missingsummary'            => "'''Attencion:''' Me necoccebj providöx abvuatlde ticpatlöx zo. Clicköx 'Xuniim páhina' xuniim meticpatlöx sans abvuatlde ticpatlöx.",
 'missingcommenttext'        => 'Enterom commentua !-cmaa.',
 'missingcommentheader'      => "'''Attencion:''' Me necoccebj providöx subjectua/corridor zode jan commentua. Clickom 'Xuniim páhina' xuniim meticpatlöx sans subjectua/corridor zo.",
-'summary-preview'           => 'Cuáxiitde abvuatl',
-'subject-preview'           => 'Cuáxiitde subjectua/corridor',
+'summary-preview'           => 'Cuáxiitde abvuatl:',
+'subject-preview'           => 'Cuáxiitde subjectua/corridor:',
 'blockedtitle'              => 'Caitom blockámit',
 'blockedtext'               => "<big>'''Hexuatl jöx adressade IP cáablockom.'''</big>
 
@@ -533,7 +527,7 @@ Jan lajxepe occuram me usadad proxy service anon web-based buggy.'''",
 'longpagewarning'           => "'''ATTENCION: Jan páhina coccebj $1 kilobynám; browserám pac pos-coccebj problemámde ticpatlöx páhinám necade jöx plusöxde 32 kb.
 Cahöx ticpatlöx jan páhina minöx seccion iti.'''",
 'longpageerror'             => "'''RÖMJ: Textua zo mexuniim coccebj $1 kilobytenám, jan coccebj plusöxde maxde $2 kilobytenám. Zo necoccebj xuniim.'''",
-'readonlywarning'           => "<strong>ATTENCION: Database zo coccebj lockomde kyépöx, zo necoccebj posde xuniim meticpatlöx cmaa. Me coccebj considerom ''cut-n-paste'' textua zo ciúchande textua iti ö xuniimde diijömdexepe.</strong>",
+'readonlywarning'           => "'''ATTENCION: Database zo coccebj lockomde kyépöx, zo necoccebj posde xuniim meticpatlöx cmaa. Me coccebj considerom ''cut-n-paste'' textua zo ciúchande textua iti ö xuniimde diijömdexepe.'''",
 'protectedpagewarning'      => "'''ATTENCION: Jan páhina coccebj lockomde sysopám coccebj ticpatlöx zo permiccional.'''",
 'semiprotectedpagewarning'  => "'''Notificacion:''' Jan páhina coccebj lockom caitom registrar coccebj ticpatlöx zo.",
 'cascadeprotectedwarning'   => "'''Attencion:''' Jan páhina coccebj lockom jan coccebj ticpatlöxde caitom sysopán permiccion mii, zo coccebj includöx jan {{PLURAL:$1|cascade-páhina|cascade-páhinám}} hun:",
@@ -563,11 +557,9 @@ Rae' zo xuniim $3 mii coccebj ''$2''",
 # History pages
 'viewpagelogs'        => 'Cohuatlöx logámde jan páhina',
 'nohistory'           => 'Jan páhina necoccebj históriade ticpatlöx.',
-'revnotfound'         => 'Revicion neyahöx',
-'revnotfoundtext'     => 'Janrevicion zode páhina zo me yahöx necoccebj yahöxom. Controlar URL zo me usadadde accesom jan páhina.',
 'currentrev'          => 'Revicion cmaa',
 'revisionasof'        => 'Revicionde $1',
-'revision-info'       => "Revicionde $1 'de $2",
+'revision-info'       => "Revicionde $1 'de $2", # Additionally available: $3: revision id
 'previousrevision'    => '←Janrevicion',
 'nextrevision'        => 'Hunrevicion→',
 'currentrevisionlink' => 'Revicion currentuanon',
@@ -624,6 +616,7 @@ Informacion: (curt) = quiíxde vercion currentua,
 'prevn'                 => 'jan $1',
 'nextn'                 => 'hun $1',
 'viewprevnext'          => 'Cohuatlöx ($1) ($2) ($3)',
+'searchhelp-url'        => 'Help:Caálixötöj',
 'powersearch'           => 'Yahöx',
 
 # Preferences page
@@ -636,6 +629,7 @@ Informacion: (curt) = quiíxde vercion currentua,
 'qbsettings-none'       => 'Nepartám',
 'changepassword'        => "Reset'quimx canj",
 'skin'                  => 'Zuláugaum',
+'skin-preview'          => 'Cuáxiit',
 'math'                  => 'HTML-cuat',
 'dateformat'            => 'Formatumde datum',
 'datedefault'           => 'Diiquáatlaac',
@@ -650,9 +644,6 @@ Informacion: (curt) = quiíxde vercion currentua,
 'prefs-misc'            => 'Jömc',
 'saveprefs'             => 'Xuniim',
 'resetprefs'            => "Reset'",
-'oldpassword'           => 'Janquimx canj:',
-'newpassword'           => 'Hunquimx canj:',
-'retypenew'             => 'Vanhunquimx canj:',
 'textboxsize'           => 'Ticpatlöx',
 'rows'                  => 'Rowám:',
 'columns'               => 'Columnám:',
@@ -766,17 +757,17 @@ Informacion: (curt) = quiíxde vercion currentua,
 'nolicense'         => 'Seleccion coccebj hun',
 'license-nopreview' => '(Necuáxiit)',
 
-# Special:ImageList
-'imagelist_search_for'  => 'Yahöxde IDde ciúchan:',
+# Special:ListFiles
+'listfiles_search_for'  => 'Yahöxde IDde ciúchan:',
 'imgfile'               => 'ciúchan',
-'imagelist'             => 'Listade ciúchán',
-'imagelist_date'        => 'Datum',
-'imagelist_name'        => 'Nom',
-'imagelist_user'        => 'Caitom',
-'imagelist_size'        => 'Bajlip',
-'imagelist_description' => 'Discripcion',
+'listfiles'             => 'Listade ciúchán',
+'listfiles_date'        => 'Datum',
+'listfiles_name'        => 'Nom',
+'listfiles_user'        => 'Caitom',
+'listfiles_size'        => 'Bajlip',
+'listfiles_description' => 'Discripcion',
 
-# Image description page
+# File description page
 'filehist'                  => 'Historiade ciúchan',
 'filehist-deleteall'        => 'delatom jömde man',
 'filehist-deleteone'        => 'delatom jande man',
@@ -826,9 +817,8 @@ Informacion: (curt) = quiíxde vercion currentua,
 'randomredirect-nopages' => 'Zo necoccebj meniitomöx jan ipartuatl iti.',
 
 # Statistics
-'statistics' => 'Statisticám',
-'sitestats'  => '{{SITENAME}} statisticám',
-'userstats'  => 'Caitom statisticám',
+'statistics'              => 'Statisticám',
+'statistics-header-users' => 'Caitom statisticám',
 
 'doubleredirects' => 'Meniitomöx daj ti zon',
 
@@ -867,8 +857,6 @@ Informacion: (curt) = quiíxde vercion currentua,
 'speciallogtitlelabel' => 'Titlenam:',
 'log'                  => 'Logám',
 'all-logs-page'        => 'Jömde logám',
-'log-search-legend'    => 'Yahöxde logám',
-'log-search-submit'    => 'Caátemöx',
 
 # Special:AllPages
 'allpages'          => 'Jöxde páhinám',
@@ -910,26 +898,20 @@ iitom e-iitomde diijömde caitóm.',
 'emailsenttext'   => 'Hene-iitom coccebj e-iitomöx.',
 
 # Watchlist
-'watchlist'            => 'He listade cáminot',
-'mywatchlist'          => 'He listade cáminot',
-'watchlistfor'         => "('''$1''' mii)",
-'nowatchlist'          => 'Hecoccebj 0 itémii helistade cáminot iti.',
-'watchnologin'         => 'Necaápo',
-'watchnologintext'     => 'Zo coccebj Neces [[Special:UserLogin|caápo]] ticpatlöx helistade cáminot.',
-'addedwatch'           => 'Plusöxaj listade cáminot',
-'removedwatch'         => 'Delatajde he listade cáminot',
-'removedwatchtext'     => 'Páhina zo "[[:$1]]" coccebj delataj me listade cáminot.',
-'watch'                => 'Cáminot',
-'watchthispage'        => 'Cáminot jan páhina',
-'unwatch'              => 'Diicáminot',
-'unwatchthispage'      => 'Diicáminot jan páhina',
-'wlshowlast'           => 'Cohuatlöx hun $1 ixáap quij iitax $2 ixáap $3',
-'watchlist-show-bots'  => 'Cohuatlöx editám cibotám',
-'watchlist-hide-bots'  => 'Cíiitám editám cibotám',
-'watchlist-show-own'   => 'Cohuatlöx  hániideditám',
-'watchlist-hide-own'   => 'Cíiitám hániideditám',
-'watchlist-show-minor' => 'Cohuatlöx editám bajlöxám',
-'watchlist-hide-minor' => 'Cíiitám editám bajlöxám',
+'watchlist'        => 'He listade cáminot',
+'mywatchlist'      => 'He listade cáminot',
+'watchlistfor'     => "('''$1''' mii)",
+'nowatchlist'      => 'Hecoccebj 0 itémii helistade cáminot iti.',
+'watchnologin'     => 'Necaápo',
+'watchnologintext' => 'Zo coccebj Neces [[Special:UserLogin|caápo]] ticpatlöx helistade cáminot.',
+'addedwatch'       => 'Plusöxaj listade cáminot',
+'removedwatch'     => 'Delatajde he listade cáminot',
+'removedwatchtext' => 'Páhina zo "[[:$1]]" coccebj delataj me listade cáminot.',
+'watch'            => 'Cáminot',
+'watchthispage'    => 'Cáminot jan páhina',
+'unwatch'          => 'Diicáminot',
+'unwatchthispage'  => 'Diicáminot jan páhina',
+'wlshowlast'       => 'Cohuatlöx hun $1 ixáap quij iitax $2 ixáap $3',
 
 # Displayed when you click the "watch" button and it is in the process of watching
 'watching'   => 'Cáminot...',
@@ -941,9 +923,12 @@ iitom e-iitomde diijömde caitóm.',
 'created'                      => 'creacöx',
 'enotif_anon_editor'           => 'caitom anoniimom $1',
 
-# Delete/protect/revert
+# Delete
 'deletepage' => 'Delatar páhina',
-'pagesize'   => '(bytenám)',
+
+# Protect
+'prot_1movedto2' => '[[$1]] yacomöxde [[$2]]',
+'pagesize'       => '(bytenám)',
 
 # Restrictions (nouns)
 'restriction-edit' => 'Ticpatlöx',
@@ -968,7 +953,6 @@ iitom e-iitomde diijömde caitóm.',
 'sp-contributions-submit'   => 'Yahöx',
 
 # What links here
-'linklistsub'         => '(Listade linkám)',
 'istemplate'          => 'incluciónaj',
 'whatlinkshere-links' => '← linkám',
 
@@ -1011,6 +995,7 @@ iitom e-iitomde diijömde caitóm.',
 # Move page
 'move-page-legend' => 'Yacom páhina',
 'movearticle'      => 'Yacom páhina:',
+'movenologin'      => 'Necaápo',
 'move-watch'       => 'Cáminot jan páhina',
 'movepagebtn'      => 'Yacom páhina',
 'movedto'          => 'yacomöxde',
@@ -1031,6 +1016,7 @@ iitom e-iitomde diijömde caitóm.',
 # Special:Import
 'import'                  => 'Importóm páhinóm',
 'import-interwiki-submit' => 'Importom',
+'import-comment'          => 'Commentua:',
 'importstart'             => 'Importom páhinám...',
 'importfailed'            => 'Römjde import: $1',
 
@@ -1073,7 +1059,7 @@ iitom e-iitomde diijömde caitóm.',
 # Media information
 'widthheightpage' => '$1×$2, $3 páhinám',
 
-# Special:NewImages
+# Special:NewFiles
 'showhidebots' => '($1 botám)',
 'ilsubmit'     => 'Yahöx',
 'bydate'       => 'de datum',
