@@ -1,11 +1,11 @@
 <?php
 /** Swati (SiSwati)
  *
- * @addtogroup Language
+ * @ingroup Language
+ * @file
  *
- * @author MF-Warburg
  * @author Jatrobat
- * @author Siebrand
+ * @author MF-Warburg
  */
 
 $messages = array(
@@ -42,26 +42,32 @@ $messages = array(
 'november-gen'  => 'Lídvúba',
 'december-gen'  => 'íNgongóni',
 
-'qbfind' => 'Kúkhándza',
-'qbedit' => 'Kúhlela',
+'qbfind'         => 'Kúkhándza',
+'qbedit'         => 'Kúhlela',
+'qbspecialpages' => 'Emakhasi labalulekile',
 
-'help'          => 'Kúsíta',
-'search'        => 'Kucálata',
-'searchbutton'  => 'kucálata',
-'go'            => 'Kúhámba',
-'searcharticle' => 'Kúhámba',
-'history_short' => 'Umlandvo',
-'print'         => 'Kucindzetêla',
-'edit'          => 'kúhlela',
-'talk'          => 'Kúcoca',
-'jumptosearch'  => 'kucálata',
+'help'             => 'Kúsíta',
+'search'           => 'Kucálata',
+'searchbutton'     => 'kucálata',
+'go'               => 'Kúhámba',
+'searcharticle'    => 'Kúhámba',
+'history_short'    => 'Umlandvo',
+'print'            => 'Kucindzetêla',
+'edit'             => 'kúhlela',
+'talkpagelinktext' => 'Kúcoca',
+'talk'             => 'Kúcoca',
+'jumptosearch'     => 'kucálata',
 
 # All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
-'portal'     => 'Likhefi leinthanethi',
-'portal-url' => 'Project:Likhefi leinthanethi',
+'mainpage'             => 'Likhasi Lelikhulu',
+'mainpage-description' => 'Likhasi Lelikhulu',
+'portal'               => 'Likhefi leinthanethi',
+'portal-url'           => 'Project:Likhefi leinthanethi',
 
-'editsection' => 'kúhlela',
-'editold'     => 'kúhlela',
+'youhavenewmessages' => 'Ube $1 ($2).',
+'editsection'        => 'kúhlela',
+'editold'            => 'kúhlela',
+'viewdeleted'        => 'Kúfúna $1?',
 
 # Short words for each namespace, by default used in the namespace tab in monobook
 'nstab-main' => 'Intfo',
@@ -79,26 +85,78 @@ $messages = array(
 # Preferences page
 'searchresultshead' => 'Kucálata',
 
-# Image list
-'ilsubmit'          => 'Kucálata',
+# Special:ListFiles
+'listfiles_date' => 'Lusuku',
+'listfiles_name' => 'Ligama',
+'listfiles_user' => 'Umuntfu',
+
+# File description page
 'filehist-datetime' => 'Lusuku/Síkhatsí',
 'filehist-user'     => 'Umuntfu',
 
+'brokenredirects-edit' => '(kúhlela)',
+
+'withoutinterwiki-submit' => 'Kúfúna',
+
 # Miscellaneous special pages
 'move' => 'Kúgojotîsa',
 
+# Book sources
+'booksources-go' => 'Kúhámba',
+
 # Special:Log
 'specialloguserlabel' => 'Umuntfu:',
 
-# Special:Allpages
+# Special:AllPages
 'allpagessubmit' => 'Kúhámba',
 
+# Special:LinkSearch
+'linksearch-ok' => 'Kucálata',
+
+# Special:ListUsers
+'listusers-submit' => 'Kúfúna',
+
+# Watchlist
+'watch'   => 'Gadza',
+'unwatch' => 'Yekela kugadza',
+
 # Restrictions (nouns)
 'restriction-edit'   => 'Kúhlela',
 'restriction-move'   => 'Kúgojotîsa',
 'restriction-create' => 'Kúdála',
 
+# Undelete
+'undelete-search-submit' => 'Kucálata',
+
+'sp-contributions-submit' => 'Kucálata',
+
+# Block/unblock
+'ipblocklist-submit' => 'Kucálata',
+'proxyblocksuccess'  => 'Ngiénta.',
+
+# Move page
+'movelogpage' => 'Kúgojotîsa log',
+
+# Namespace 8 related
+'allmessagesname' => 'Ligama',
+
 # Tooltip help for the actions
 'tooltip-search' => 'Kucálata {{SITENAME}}',
+'tooltip-p-logo' => 'Likhasi Lelikhulu',
+
+# Special:NewFiles
+'ilsubmit' => 'Kucálata',
+
+# Multipage image navigation
+'imgmultigo' => 'Kúhámba!',
+
+# Table pager
+'table_pager_limit_submit' => 'Kúhámba',
+
+# Special:Version
+'version-specialpages' => 'Emakhasi labalulekile',
+
+# Special:SpecialPages
+'specialpages' => 'Emakhasi labalulekile',
 
 );
