@@ -17,6 +17,11 @@
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 # http://www.gnu.org/copyleft/gpl.html
 
+/**
+ * @file
+ * @ingroup Maintenance
+ */
+
 $options = array( 'fix', 'suffix', 'help' );
 
 /** */
@@ -190,7 +195,7 @@ class NamespaceConflictChecker {
 
 	function reportConflict( $row, $suffix ) {
 		$newTitle = Title::makeTitleSafe( $row->namespace, $row->title );
-		if( !$newTitle ) {
+		if( is_null($newTitle) || !$newTitle->canExist() ) {
 			// Title is also an illegal title...
 			// For the moment we'll let these slide to cleanupTitles or whoever.
 			printf( "... %d (0,\"%s\")\n",
