@@ -23,9 +23,9 @@
  * Then, kill the poor widows and orphans.
  * Man this is depressing.
  *
+ * @file
  * @author <brion@pobox.com>
- * @package MediaWiki
- * @subpackage Maintenance
+ * @ingroup Maintenance
  */
 
 $options = array( 'fix' );
@@ -41,7 +41,7 @@ checkSeparation( isset( $options['fix'] ) );
 # ------
 
 function checkOrphans( $fix ) {
-	$dbw =& wfGetDB( DB_MASTER );
+	$dbw = wfGetDB( DB_MASTER );
 	$page = $dbw->tableName( 'page' );
 	$revision = $dbw->tableName( 'revision' );
 
@@ -92,7 +92,7 @@ function checkOrphans( $fix ) {
  *       but valid revisions do exist)
  */
 function checkWidows( $fix ) {
-	$dbw =& wfGetDB( DB_MASTER );
+	$dbw = wfGetDB( DB_MASTER );
 	$page = $dbw->tableName( 'page' );
 	$revision = $dbw->tableName( 'revision' );
 
@@ -135,7 +135,7 @@ function checkWidows( $fix ) {
 
 
 function checkSeparation( $fix ) {
-	$dbw =& wfGetDB( DB_MASTER );
+	$dbw = wfGetDB( DB_MASTER );
 	$page     = $dbw->tableName( 'page' );
 	$revision = $dbw->tableName( 'revision' );
 	$text     = $dbw->tableName( 'text' );
@@ -204,4 +204,3 @@ function checkSeparation( $fix ) {
 	}
 }
 
-?>
\ No newline at end of file
