@@ -34,7 +34,7 @@ $conds = '';
 if ($type !== false)
 	$conds = "job_cmd = " . $dbw->addQuotes($type);
 
-while ( $dbw->selectField( 'job', 'count(*)', $conds, 'runJobs.php' ) ) {
+while ( $dbw->selectField( 'job', 'job_id', $conds, 'runJobs.php' ) ) {
 	$offset=0;
 	for (;;) {
 		$job = ($type == false) ?
