@@ -4,5 +4,5 @@ CREATE TABLE /*$wgDBprefix*/blobs (
 	blob_id integer UNSIGNED NOT NULL AUTO_INCREMENT,
 	blob_text longblob,
 	PRIMARY KEY  (blob_id)
-) TYPE=MyISAM MAX_ROWS=1000000 AVG_ROW_LENGTH=1000000;
+) ENGINE=MyISAM MAX_ROWS=1000000 AVG_ROW_LENGTH=1000000;
 
